@@ -48,8 +48,8 @@ extern char* get_array_sub_type(CSOUND* csound, char*);
 extern char* convert_external_to_internal(CSOUND* csound, char* arg);
 
 
-TREE* create_boolean_expression(CSOUND*, TREE*, int, int, TYPE_TABLE*);
-TREE * create_expression(CSOUND *, TREE *, int, int, TYPE_TABLE*);
+static TREE *create_boolean_expression(CSOUND*, TREE*, int, int, TYPE_TABLE*);
+static TREE *create_expression(CSOUND *, TREE *, int, int, TYPE_TABLE*);
 char *check_annotated_type(CSOUND* csound, OENTRIES* entries,
                            char* outArgTypes);
 
@@ -108,7 +108,7 @@ char * get_boolean_arg(CSOUND *csound, TYPE_TABLE* typeTable, int type)
     return s;
 }
 
-TREE *create_empty_token(CSOUND *csound)
+static TREE *create_empty_token(CSOUND *csound)
 {
     TREE *ans;
     ans = (TREE*)csound->Malloc(csound, sizeof(TREE));
@@ -129,7 +129,7 @@ TREE *create_empty_token(CSOUND *csound)
     return ans;
 }
 
-TREE *create_minus_token(CSOUND *csound)
+static TREE *create_minus_token(CSOUND *csound)
 {
     TREE *ans;
     ans = (TREE*)csound->Malloc(csound, sizeof(TREE));
@@ -148,7 +148,7 @@ TREE *create_minus_token(CSOUND *csound)
     return ans;
 }
 
-TREE * create_opcode_token(CSOUND *csound, char* op)
+static TREE * create_opcode_token(CSOUND *csound, char* op)
 {
     TREE *ans = create_empty_token(csound);
 
@@ -159,7 +159,7 @@ TREE * create_opcode_token(CSOUND *csound, char* op)
     return ans;
 }
 
-TREE * create_ans_token(CSOUND *csound, char* var)
+static TREE * create_ans_token(CSOUND *csound, char* var)
 {
     TREE *ans = create_empty_token(csound);
 
@@ -171,7 +171,7 @@ TREE * create_ans_token(CSOUND *csound, char* var)
 
 }
 
-TREE * create_goto_token(CSOUND *csound, char * booleanVar,
+static TREE * create_goto_token(CSOUND *csound, char * booleanVar,
                          TREE * gotoNode, int type)
 {
     /*     TREE *ans = create_empty_token(csound); */
@@ -186,9 +186,12 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
       strncpy(op, "cigoto", 8);
       break;
     case ITHEN_TOKEN:
+    icase:
       strncpy(op, "cingoto", 8);
       break;
     case THEN_TOKEN:
+      if (csound->inZero) goto icase;
+      /* fall through */
     case KTHEN_TOKEN:
       strncpy(op, "cngoto", 8);
       break;
@@ -197,7 +200,8 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
       case 1: strncpy(op, "ckgoto", 8); break;
       case 0x8001: strncpy(op, "cnkgoto", 8); break;
       case 0: strncpy(op, "cggoto", 8); break;
-      case 0x8000: strncpy(op, "cngoto", 8); break;
+      case 0x8000:
+        strncpy(op,csound->inZero?"cingoto":"cngoto", 8); break;
       default: printf("Whooops %d\n", type);
       }
     }
@@ -217,11 +221,12 @@ TREE * create_goto_token(CSOUND *csound, char * booleanVar,
 
 /* THIS PROBABLY NEEDS TO CHANGE TO RETURN DIFFERENT GOTO
    TYPES LIKE IGOTO, ETC */
-TREE *create_simple_goto_token(CSOUND *csound, TREE *label, int type)
+static TREE *create_simple_goto_token(CSOUND *csound, TREE *label, int type)
 {
     char* op = (char *)csound->Calloc(csound, 6);
     TREE * opTree;
     char *gt[3] = {"kgoto", "igoto", "goto"};
+    if (csound->inZero && type==2) type = 1;
     strncpy(op, gt[type],6);       /* kgoto, igoto, goto ?? */
     opTree = create_opcode_token(csound, op);
     opTree->left = NULL;
@@ -275,6 +280,7 @@ int is_boolean_expression_node(TREE *node)
     case S_LT:
     case S_AND:
     case S_OR:
+    case S_UNOT:
       return 1;
     }
     return 0;
@@ -349,8 +355,8 @@ static TREE *create_cond_expression(CSOUND *csound,
     return anchor;
 }
 
-char* create_out_arg_for_expression(CSOUND* csound, char* op, TREE* left,
-                                    TREE* right, TYPE_TABLE* typeTable) {
+static char* create_out_arg_for_expression(CSOUND* csound, char* op, TREE* left,
+                                           TREE* right, TYPE_TABLE* typeTable) {
     char* outType;
 
     OENTRIES* opentries = find_opcode2(csound, op);
@@ -368,7 +374,7 @@ char* create_out_arg_for_expression(CSOUND* csound, char* op, TREE* left,
     csound->Free(csound, rightArgType);
     csound->Free(csound, opentries);
 
-    if(outType == NULL) return NULL;
+    if (outType == NULL) return NULL;
 
     outType = convert_external_to_internal(csound, outType);
     return create_out_arg(csound, outType,
@@ -379,8 +385,8 @@ char* create_out_arg_for_expression(CSOUND* csound, char* op, TREE* left,
  * Create a chain of Opcode (OPTXT) text from the AST node given. Called from
  * create_opcode when an expression node has been found as an argument
  */
-TREE * create_expression(CSOUND *csound, TREE *root, int line, int locn,
-                         TYPE_TABLE* typeTable)
+static TREE *create_expression(CSOUND *csound, TREE *root, int line, int locn,
+                               TYPE_TABLE* typeTable)
 {
     char op[80], *outarg = NULL;
     TREE *anchor = NULL, *last;
@@ -480,7 +486,7 @@ TREE * create_expression(CSOUND *csound, TREE *root, int line, int locn,
           csound->Message(csound, "Found OP: %s\n", op);
 
         opentries = find_opcode2(csound, root->value->lexeme);
-        if (opentries->count == 0) {
+        if (UNLIKELY(opentries->count == 0)) {
           csound->Warning(csound,
                           Str("error: function %s not found, "
                               "line %d \n"),
@@ -501,7 +507,7 @@ TREE * create_expression(CSOUND *csound, TREE *root, int line, int locn,
 
         csound->Free(csound, opentries);
 
-        if (outtype == NULL) {
+        if (UNLIKELY(outtype == NULL)) {
           csound->Warning(csound,
                           Str("error: opcode %s with output type %s not found, "
                               "line %d"),
@@ -600,6 +606,9 @@ TREE * create_expression(CSOUND *csound, TREE *root, int line, int locn,
           char* rightArgType = get_arg_string_from_tree(csound, root->right,
                                                         typeTable);
 
+          leftArgType =csound->ReAlloc(csound, leftArgType, strlen(leftArgType) +
+                                       strlen(rightArgType) + 1);
+
           char* argString = strcat(leftArgType, rightArgType);
 
           char* outype = resolve_opcode_get_outarg(csound, opentries,
@@ -656,8 +665,8 @@ TREE * create_expression(CSOUND *csound, TREE *root, int line, int locn,
  * Create a chain of Opcode (OPTXT) text from the AST node given. Called from
  * create_opcode when an expression node has been found as an argument
  */
-TREE * create_boolean_expression(CSOUND *csound, TREE *root, int line, int locn,
-                                 TYPE_TABLE* typeTable)
+static TREE *create_boolean_expression(CSOUND *csound, TREE *root,
+                                       int line, int locn, TYPE_TABLE* typeTable)
 {
     char *op, *outarg;
     TREE *anchor = NULL, *last;
@@ -741,6 +750,9 @@ TREE * create_boolean_expression(CSOUND *csound, TREE *root, int line, int locn,
 
     op = csound->Calloc(csound, 80);
     switch(root->type) {
+    case S_UNOT:
+      strncpy(op, "!", 80);
+      break;
     case S_EQ:
       strncpy(op, "==", 80);
       break;
@@ -767,18 +779,28 @@ TREE * create_boolean_expression(CSOUND *csound, TREE *root, int line, int locn,
       break;
     }
 
-    if (UNLIKELY(PARSER_DEBUG))
-      csound->Message(csound, "Operator Found: %s (%c %c)\n", op,
-                      argtyp2( root->left->value->lexeme),
-                      argtyp2( root->right->value->lexeme));
-
-    outarg = get_boolean_arg(
-                 csound,
-                 typeTable,
-                 argtyp2( root->left->value->lexeme) =='k' ||
-                 argtyp2( root->right->value->lexeme)=='k' ||
-                 argtyp2( root->left->value->lexeme) =='B' ||
-                 argtyp2( root->right->value->lexeme)=='B');
+    if (UNLIKELY(PARSER_DEBUG)) {
+      if (root->type == S_UNOT)
+        csound->Message(csound, "Operator Found: %s (%c)\n", op,
+                        argtyp2( root->left->value->lexeme));
+      else
+        csound->Message(csound, "Operator Found: %s (%c %c)\n", op,
+                        argtyp2( root->left->value->lexeme),
+                        argtyp2( root->right->value->lexeme));
+    }
+    if (root->type == S_UNOT) {
+      outarg = get_boolean_arg(csound,
+                               typeTable,
+                               argtyp2( root->left->value->lexeme) =='k' ||
+                               argtyp2( root->left->value->lexeme) =='B');
+    }
+    else
+      outarg = get_boolean_arg(csound,
+                               typeTable,
+                               argtyp2( root->left->value->lexeme) =='k' ||
+                               argtyp2( root->right->value->lexeme)=='k' ||
+                               argtyp2( root->left->value->lexeme) =='B' ||
+                               argtyp2( root->right->value->lexeme)=='B');
 
     add_arg(csound, outarg, typeTable);
     opTree = create_opcode_token(csound, op);
@@ -815,7 +837,7 @@ static TREE *create_synthetic_ident(CSOUND *csound, int32 count)
     return make_leaf(csound, -1, 0, T_IDENT, token);
 }
 
-TREE *create_synthetic_label(CSOUND *csound, int32 count)
+static TREE *create_synthetic_label(CSOUND *csound, int32 count)
 {
     char *label = (char *)csound->Calloc(csound, 20);
     ORCTOKEN *token;
@@ -827,7 +849,8 @@ TREE *create_synthetic_label(CSOUND *csound, int32 count)
     return make_leaf(csound, -1, 0, LABEL_TOKEN, token);
 }
 
-void handle_negative_number(CSOUND* csound, TREE* root) {
+void handle_negative_number(CSOUND* csound, TREE* root)
+{
   if (root->type == S_UMINUS &&
       (root->right->type == INTEGER_TOKEN || root->right->type == NUMBER_TOKEN)) {
     int len = strlen(root->right->value->lexeme);
@@ -843,7 +866,9 @@ void handle_negative_number(CSOUND* csound, TREE* root) {
 }
 
 
-void collapse_last_assigment(CSOUND* csound, TREE* anchor, TYPE_TABLE* typeTable) {
+static void collapse_last_assigment(CSOUND* csound, TREE* anchor,
+                                    TYPE_TABLE* typeTable)
+{
     TREE *a, *b, *temp;
     temp = anchor;
 
@@ -878,7 +903,8 @@ void collapse_last_assigment(CSOUND* csound, TREE* anchor, TYPE_TABLE* typeTable
    expressions into statements prior to the original statement line,
    and LHS expressions (array sets) after the original statement
    line */
-TREE* expand_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable) {
+TREE* expand_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable)
+{
      /* This is WRONG in optional argsq */
     TREE* anchor = NULL;
     TREE* originalNext = current->next;
@@ -889,16 +915,16 @@ TREE* expand_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable) {
     current->next = NULL;
 
     if (UNLIKELY(PARSER_DEBUG))
-        csound->Message(csound, "Found Statement.\n");
+      csound->Message(csound, "Found Statement.\n");
     while (currentArg != NULL) {
-        TREE* last;
-        TREE *nextArg;
-        TREE *newArgTree;
-        TREE *expressionNodes;
-        int is_bool = 0;
-        handle_negative_number(csound, currentArg);
-        if (is_expression_node(currentArg) ||
-            (is_bool = is_boolean_expression_node(currentArg))) {
+      TREE* last;
+      TREE *nextArg;
+      TREE *newArgTree;
+      TREE *expressionNodes;
+      int is_bool = 0;
+      handle_negative_number(csound, currentArg);
+      if (is_expression_node(currentArg) ||
+          (is_bool = is_boolean_expression_node(currentArg))) {
             char * newArg;
             if (UNLIKELY(PARSER_DEBUG))
               csound->Message(csound, "Found Expression.\n");
@@ -960,7 +986,7 @@ TREE* expand_statement(CSOUND* csound, TREE* current, TYPE_TABLE* typeTable) {
     if (strcmp("init", current->value->lexeme)==0) {
       //print_tree(csound, "init",current);
       init = 1;
-      }
+    }
     while (currentArg != NULL) {
       TREE* temp;
 
@@ -1085,9 +1111,9 @@ TREE* expand_if_statement(CSOUND* csound,
       last->next = gotoToken;
       gotoToken->next = current->next;
     }
-    else if (right->type == THEN_TOKEN ||
-             right->type == ITHEN_TOKEN ||
-             right->type == KTHEN_TOKEN) {
+    else if (LIKELY(right->type == THEN_TOKEN ||
+                    right->type == ITHEN_TOKEN ||
+                    right->type == KTHEN_TOKEN)) {
       int endLabelCounter = -1;
       TREE *tempLeft;
       TREE *tempRight;
@@ -1189,7 +1215,7 @@ TREE* expand_if_statement(CSOUND* csound,
     }
     else {
       csound->Message(csound,
-                      "ERROR: Neither if-goto or if-then found on line %d!!!",
+                      Str("ERROR: Neither if-goto or if-then found on line %d!!!"),
                       right->line);
     }
 
