@@ -55,8 +55,8 @@ typedef struct memAllocBlock_s {
 
 static void memdie(CSOUND *csound, size_t nbytes)
 {
-    csound->ErrorMsg(csound, Str("memory allocate failure for %lu"),
-                             (uint32) nbytes);
+    csound->ErrorMsg(csound, Str("memory allocate failure for %zu"),
+                             nbytes);
     csound->LongJmp(csound, CSOUND_MEMORY);
 }
 
@@ -94,7 +94,7 @@ void *mmalloc(CSOUND *csound, size_t size)
 void *mmallocDebug(CSOUND *csound, size_t size, char *file, int line)
 {
     void *ans = mmalloc(csound,size);
-    printf("Alloc %p (%ld) %s:%d\n", ans, size, file, line);
+    printf("Alloc %p (%zu) %s:%d\n", ans, size, file, line);
     return ans;
 }
 
@@ -132,7 +132,7 @@ void *mcalloc(CSOUND *csound, size_t size)
 void *mcallocDebug(CSOUND *csound, size_t size, char *file, int line)
 {
     void *ans = mcalloc(csound,size);
-    printf("Alloc %p (%ld) %s:%d\n", ans, size, file, line);
+    printf("Alloc %p (%zu) %s:%d\n", ans, size, file, line);
     return ans;
 }
 
@@ -241,7 +241,7 @@ void *mrealloc(CSOUND *csound, void *oldp, size_t size)
 void *mreallocDebug(CSOUND *csound, void *oldp, size_t size, char *file, int line)
 {
     void *p = mrealloc(csound, oldp, size);
-    printf("Realloc %p->%p (%ld) %s:%d\n", oldp, p, size, file, line);
+    printf("Realloc %p->%p (%zu) %s:%d\n", oldp, p, size, file, line);
     return p;
 }
 
