@@ -44,9 +44,18 @@ static int Load_Het_File_(CSOUND *csound, const char *filnam,
     char buffer[16];
     //void *dummy = 0;
     f = fopen(filnam, "r");
+    if (f==NULL) {
+      csound->Warning(csound, Str("failed to open file %s\n"), filnam);
+      return NOTOK;
+    }
     csoundNotifyFileOpened(csound, filnam, CSFTYPE_HETRO, 0, 0);
     all = (char *)csound->Malloc(csound, (size_t) length);
-    for (i=0; i<6; i++) fgetc(f); /* Skip HETRO */
+    if (6!=fread(buffer, 1, 6, f)) { /* Skip HETRO */
+      csound->Warning(csound, Str("failed to read file %s\n"), filnam);
+      fclose(f);
+      return NOTOK;
+    }
+    //for (i=0; i<6; i++) getc(f); /* Skip HETRO */
     /*dummy =*/ (void)fgets(buffer, 10, f);         /* number of partials */
     x = atoi(buffer);
     memcpy(&all[0], &x, sizeof(int16));
@@ -61,7 +70,7 @@ static int Load_Het_File_(CSOUND *csound, const char *filnam,
       }
       buffer[p]='\0';
       /* Expand as necessary */
-      if (i>=length-4) all = csound->ReAlloc(csound, all, length+=1024);
+      if (UNLIKELY(i>=length-4)) all = csound->ReAlloc(csound, all, length+=1024);
       x = atoi(buffer);
       memcpy(&all[i], &x, sizeof(int16));
     }
@@ -136,7 +145,7 @@ static int Load_CV_File_(CSOUND *csound, const char *filnam,
     /* dummy =*/ (void)fgets(buff, 120, f); /* Skip CVANAL */
     cvh.magic = CVMAGIC;
     p = fgets(buff, 120, f);
-    if (p==NULL) {
+    if (UNLIKELY(p==NULL)) {
       fclose(f);
       return csoundInitError(csound, Str("Ill-formed CV file\n"));
     }
@@ -158,7 +167,7 @@ static int Load_CV_File_(CSOUND *csound, const char *filnam,
     /* Read data until end, pack as MYFLTs */
     for (i=sizeof(CVSTRUCT);;i+=sizeof(MYFLT)) {
       /* Expand as necessary */
-      if (i>=length-sizeof(MYFLT)-4) {
+      if (UNLIKELY(i>=length-sizeof(MYFLT)-4)) {
         //printf("expanding from %p[%d] to\n", all, length);
         all = csound->ReAlloc(csound, all, length+=4096);
         //printf("i=%d                     %p[%d]\n", i, all, length);
@@ -191,8 +200,8 @@ static int Load_LP_File_(CSOUND *csound, const char *filnam,
     csoundNotifyFileOpened(csound, filnam, CSFTYPE_LPC, 0, 0);
     all = (char *)csound->Malloc(csound, (size_t) length);
     for (i=0; i<6; i++) fgetc(f); /* Skip LPANAL */
-    if (4!=fscanf(f, "%d %d %d %d\n",
-                  &lph.headersize, &lph.lpmagic, &lph.npoles, &lph.nvals)) {
+    if (UNLIKELY(4!=fscanf(f, "%d %d %d %d\n",
+                       &lph.headersize, &lph.lpmagic, &lph.npoles, &lph.nvals))) {
       fclose(f);
       return csound->InitError(csound, Str("Ill-formed LPC file\n"));
     }
@@ -217,7 +226,7 @@ static int Load_LP_File_(CSOUND *csound, const char *filnam,
     /* Read data until end, pack as MYFLTs */
     for (i=lph.headersize;;i+=sizeof(MYFLT)) {
       /* Expand as necessary */
-      if (i>=length-sizeof(MYFLT)-8) {
+      if (UNLIKELY(i>=length-sizeof(MYFLT)-8)) {
         //printf("expanding from %p[%d] to\n", all, length);
         all = csound->ReAlloc(csound, all, length+=4096);
         //printf("i=%d                     %p[%d]\n", i, all, length);
@@ -517,7 +526,7 @@ int PVOCEX_LoadFile(CSOUND *csound, const char *fname, PVOCEX_MEMFILE *p)
                                      "after %d frames"), fname, i);
     }
     pp->srate = (MYFLT) fmt.nSamplesPerSec;
-    if (pp->srate != csound->esr) {             /* & chk the data */
+    if (UNLIKELY(pp->srate != csound->esr)) {             /* & chk the data */
       csound->Warning(csound, Str("%s's srate = %8.0f, orch's srate = %8.0f"),
                               fname, pp->srate, csound->esr);
     }
@@ -545,7 +554,7 @@ int PVOCEX_LoadFile(CSOUND *csound, const char *fname, PVOCEX_MEMFILE *p)
 
     /* link into PVOC-EX memfile chain */
     csound->pvx_memfiles = pp;
-    csound->Message(csound, Str("file %s (%ld bytes) loaded into memory\n"),
+    csound->Message(csound, Str("file %s (%d bytes) loaded into memory\n"),
                             fname, (int32) mem_wanted);
 
     memcpy(p, pp, sizeof(PVOCEX_MEMFILE));
@@ -654,8 +663,8 @@ SNDMEMFILE *csoundLoadSoundFile(CSOUND *csound, const char *fileName, void *sfi)
         p->scaleFac = pow(10.0, (double) lpd.gain * 0.05);
       }
     }
-    if ((size_t) sf_readf_float(sf, &(p->data[0]), (sf_count_t) p->nFrames)
-        != p->nFrames) {
+    if (UNLIKELY((size_t) sf_readf_float(sf, &(p->data[0]), (sf_count_t) p->nFrames)
+                 != p->nFrames)) {
       csound->FileClose(csound, fd);
       csound->Free(csound, p->name);
       csound->Free(csound, p->fullName);
@@ -666,11 +675,11 @@ SNDMEMFILE *csoundLoadSoundFile(CSOUND *csound, const char *fileName, void *sfi)
     }
     p->data[p->nFrames] = 0.0f;
     csound->FileClose(csound, fd);
-    csound->Message(csound, Str("File '%s' (sr = %d Hz, %d channel(s), %lu "
+    csound->Message(csound, Str("File '%s' (sr = %d Hz, %d channel(s), %lld "
                                 "sample frames) loaded into memory\n"),
                             p->fullName, (int) sfinfo->samplerate,
                             (int) sfinfo->channels,
-                            (uint32) sfinfo->frames);
+                            sfinfo->frames);
 
     /* link into database */
     cs_hash_table_put(csound, csound->sndmemfiles, (char*)fileName, p);
