@@ -33,10 +33,11 @@ int check_instr_name(char *s)
 {
     char    *c = s;
 
-    if (!*c) return 0;  /* empty */
-    if (!isalpha(*c) && *c != '_') return 0;    /* chk if 1st char is valid */
+    if (UNLIKELY(!*c)) return 0;  /* empty */
+    if (UNLIKELY(!isalpha(*c) &&
+                 *c != '_')) return 0;    /* chk if 1st char is valid */
     while (*++c)
-      if (!isalnum(*c) && *c != '_') return 0;
+      if (UNLIKELY(!isalnum(*c) && *c != '_')) return 0;
     return 1;   /* no errors */
 }
 
@@ -160,8 +161,9 @@ int32 strarg2opcno(CSOUND *csound, void *p, int is_string, int force_opcode)
 /*   return value:                                              */
 /*      pointer to the output string; if 's' is not NULL, it is */
 /*      always the same as 's', otherwise it is allocated with  */
-/*      csound->Malloc() and the caller is responsible for freeing the */
-/*      allocated memory with csound->Free() or csound->Free()         */
+/*      csound->Malloc() and the caller is responsible for      */
+/*      freeing the allocated memory with csound->Free() or     */
+/*      csound->Free()                                          */
 
 char *strarg2name(CSOUND *csound, char *s, void *p, const char *baseName,
                                   int is_string)
@@ -230,7 +232,7 @@ PUBLIC int csoundCreateGlobalVariable(CSOUND *csound,
 {
     void* p;
     /* create new empty database if it does not exist yet */
-    if (csound->namedGlobals == NULL) {
+    if (UNLIKELY(csound->namedGlobals == NULL)) {
       csound->namedGlobals = cs_hash_table_create(csound);
       if (UNLIKELY(csound->namedGlobals == NULL))
         return CSOUND_MEMORY;
@@ -264,8 +266,8 @@ PUBLIC void *csoundQueryGlobalVariable(CSOUND *csound, const char *name)
     if (csound->namedGlobals == NULL) return NULL;
 
     /* check for a valid name */
-    if (name == NULL) return NULL;
-    if (name[0] == '\0') return NULL;
+    if (UNLIKELY(name == NULL)) return NULL;
+    if (UNLIKELY(name[0] == '\0')) return NULL;
 
     return cs_hash_table_get(csound, csound->namedGlobals, (char*) name);
 }
