@@ -102,7 +102,6 @@
 
 #include "csoundCore.h"
 #include "midiops.h"
-#include "oload.h"
 #include "midifile.h"
 
 #define MGLOB(x) (csound->midiGlobals->x)
@@ -114,7 +113,7 @@ static const MYFLT dsctl_map[12] = {
     FL(1.0), FL(0.0), FL(1.0), FL(0.0), FL(1.0), FL(0.0)
 };
 
-static const short datbyts[8] = { 2, 2, 2, 2, 1, 1, 2, 0 };
+static const int16 datbyts[8] = { 2, 2, 2, 2, 1, 1, 2, 0 };
 
 /* open a Midi event stream for reading, alloc bufs */
 /*     callable once from main.c                    */
@@ -125,7 +124,7 @@ void MidiOpen(CSOUND *csound)
     OPARMS  *O = csound->oparms;
     int     err;
     /* First set up buffers. */
-    p->Midevtblk = (MEVENT*) mcalloc(csound, sizeof(MEVENT));
+    p->Midevtblk = (MEVENT*) csound->Calloc(csound, sizeof(MEVENT));
     p->sexp = 0;
     /* Then open device... */
     if (O->Midiin) {
@@ -173,7 +172,7 @@ static void sustsoff(CSOUND *csound, MCHNBLK *chn)
 
 /* reset all controllers for this channel */
 
-void midi_ctl_reset(CSOUND *csound, short chan)
+void midi_ctl_reset(CSOUND *csound, int16 chan)
 {
     MCHNBLK *chn;
     int     i;
@@ -193,9 +192,9 @@ void midi_ctl_reset(CSOUND *csound, short chan)
     chn->pbensens = FL(2.0);                    /*   pitch bend range */
     chn->datenabl = 0;
     /* reset aftertouch to max value - added by Istvan Varga, May 2002 */
-    chn->aftouch = FL(127.0);
+    chn->aftouch = csound->aftouch;
     for (i = 0; i < 128; i++)
-      chn->polyaft[i] = FL(127.0);
+      chn->polyaft[i] = csound->aftouch;
     /* controller 64 has just been set to zero: terminate any held notes */
     if (chn->ksuscnt && !MGLOB(rawControllerMode))
       sustsoff(csound, chn);
@@ -209,7 +208,7 @@ void midi_ctl_reset(CSOUND *csound, short chan)
 void m_chanmsg(CSOUND *csound, MEVENT *mep)
 {
     MCHNBLK *chn = csound->m_chnbp[mep->chan];
-    short   n;
+    int16   n;
     MYFLT   *fp;
 
     switch (mep->type) {
@@ -217,9 +216,10 @@ void m_chanmsg(CSOUND *csound, MEVENT *mep)
       chn->pgmno = mep->dat1;
       if (chn->insno <= 0)              /* ignore if channel is muted */
         break;
-      n = (short) chn->pgm2ins[mep->dat1];      /* program change -> INSTR  */
-      if (n > 0 && n <= csound->maxinsno &&     /* if corresp instr exists  */
-          csound->instrtxtp[n] != NULL) {       /*     assign as insno      */
+      n = (int16) chn->pgm2ins[mep->dat1];      /* program change -> INSTR  */
+      if (n > 0 &&
+          n <= csound->engineState.maxinsno &&  /* if corresp instr exists  */
+          csound->engineState.instrtxtp[n] != NULL) {   /* assign as insno  */
         chn->insno = n;                         /* else ignore prog. change */
         csound->Message(csound, Str("midi channel %d now using instr %d\n"),
                                 mep->chan + 1, chn->insno);
@@ -282,12 +282,11 @@ void m_chanmsg(CSOUND *csound, MEVENT *mep)
             if (parnum == 0)
               fval = (MYFLT) (mep->dat2 - 64);
             else fval = mep->dat2;
-            if (dsctl_map != NULL) {
-              fp = (MYFLT*) &(dsctl_map[parnum*2]);
-              if (*fp != FL(0.0)) {
-                MYFLT xx = (fval * *fp++);
-                fval = xx + *fp;                /* optionally map */
-              }
+            //            if (dsctl_map != NULL) { always true
+            fp = (MYFLT*) &(dsctl_map[parnum*2]);
+            if (*fp != FL(0.0)) {
+              MYFLT xx = (fval * *fp++);
+              fval = xx + *fp;                /* optionally map */
             }
             csound->Message(csound, Str("CHAN %d DRUMKEY %d not in keylst, "
                                         "PARAM %d NOT UPDATED\n"),
@@ -325,7 +324,7 @@ void m_chanmsg(CSOUND *csound, MEVENT *mep)
       else if (n == 126) {                      /* MONO mode */
         if (chn->monobas == NULL) {
           MONPCH *mnew, *mend;
-          chn->monobas = (MONPCH *)mcalloc(csound, (long)sizeof(MONPCH) * 8);
+          chn->monobas = (MONPCH *)csound->Calloc(csound, (long)sizeof(MONPCH) * 8);
           mnew = chn->monobas;  mend = mnew + 8;
           do {
             mnew->pch = -1;
@@ -335,7 +334,7 @@ void m_chanmsg(CSOUND *csound, MEVENT *mep)
       }
       else if (n == 127) {                      /* POLY mode */
         if (chn->monobas != NULL) {
-          mfree(csound, (char *)chn->monobas);
+          csound->Free(csound, (char *)chn->monobas);
           chn->monobas = NULL;
         }
         chn->mono = 0;
@@ -370,30 +369,34 @@ void m_chn_init_all(CSOUND *csound)
 {                               /* alloc a midi control blk for a midi chnl */
     MCHNBLK *chn;               /*  & assign corr instr n+1, else a default */
     int     defaultinsno, n;
-    short   chan;
+    int16   chan;
 
     defaultinsno = 0;
-    while (++defaultinsno <= (int) csound->maxinsno &&
-           csound->instrtxtp[defaultinsno] == NULL);
-    if (defaultinsno > (int) csound->maxinsno)
+    while (csound->engineState.instrtxtp &&
+           ++defaultinsno <= (int) csound->engineState.maxinsno &&
+           csound->engineState.instrtxtp[defaultinsno] == NULL);
+    if (defaultinsno > (int) csound->engineState.maxinsno)
       defaultinsno = 0;         /* no instruments */
-    for (chan = (short) 0; chan < (short) 16; chan++) {
+    for (chan = (int16) 0; chan < (int16) 16; chan++) {
       /* alloc a midi control blk for midi channel */
       /*  & assign default instrument number       */
-      csound->m_chnbp[chan] = chn = (MCHNBLK*) mcalloc(csound, sizeof(MCHNBLK));
+      csound->m_chnbp[chan] =
+        chn = (MCHNBLK*) csound->Calloc(csound, sizeof(MCHNBLK));
       n = (int) chan + 1;
       /* if corresponding instrument exists, assign as insno, */
-      if (n <= (int) csound->maxinsno && csound->instrtxtp[n] != NULL)
-        chn->insno = (short) n;
+      if (csound->engineState.instrtxtp &&
+          n <= (int) csound->engineState.maxinsno &&
+          csound->engineState.instrtxtp[n] != NULL)
+        chn->insno = (int16) n;
       else if (defaultinsno > 0)
-        chn->insno = (short) defaultinsno;
+        chn->insno = (int16) defaultinsno;
       else
-        chn->insno = (short) -1;        /* else mute channel */
+        chn->insno = (int16) -1;        /* else mute channel */
       /* reset all controllers */
       chn->pgmno = -1;
       midi_ctl_reset(csound, chan);
       for (n = 0; n < 128; n++)
-        chn->pgm2ins[n] = (short) (n + 1);
+        chn->pgm2ins[n] = (int16) (n + 1);
       if (csound->oparms->Midiin || csound->oparms->FMidiin) {
         if (chn->insno > 0)
           csound->Message(csound, Str("midi channel %d using instr %d\n"),
@@ -420,24 +423,25 @@ int m_chinsno(CSOUND *csound, int chan, int insno, int reset_ctls)
       csound->Message(csound, Str("MIDI channel %d muted\n"), chan + 1);
     }
     else {
-      if (insno > csound->maxinsno || csound->instrtxtp[insno] == NULL) {
+      if (insno > csound->engineState.maxinsno ||
+          csound->engineState.instrtxtp[insno] == NULL) {
         csound->Message(csound, Str("Insno = %d\n"), insno);
         return csound->InitError(csound, Str("unknown instr"));
       }
-      chn->insno = (short) insno;
+      chn->insno = (int16) insno;
       csound->Message(csound, Str("chnl %d using instr %d\n"),
                               chan + 1, chn->insno);
       /* check for program change: will override massign if enabled */
       if (chn->pgmno >= 0) {
         mev.type = PROGRAM_TYPE;
-        mev.chan = (short) chan;
+        mev.chan = (int16) chan;
         mev.dat1 = chn->pgmno;
         mev.dat2 = 0;
         m_chanmsg(csound, &mev);
       }
     }
     if (reset_ctls)
-      midi_ctl_reset(csound, (short) chan);
+      midi_ctl_reset(csound, (int16) chan);
     return OK;
 }
 
@@ -476,7 +480,7 @@ int sensMidi(CSOUND *csound)
     MEVENT  *mep = p->Midevtblk;
     OPARMS  *O = csound->oparms;
     int     n;
-    short   c, type;
+    int16   c, type;
 
  nxtchr:
     if (p->bufp >= p->endatp) {
@@ -503,7 +507,7 @@ int sensMidi(CSOUND *csound)
     if ((c = *(p->bufp++)) & 0x80) {    /* STATUS byte:         */
       type = c & 0xF0;
       if (type == SYSTEM_TYPE) {
-        short lo3 = (c & 0x07);
+        int16 lo3 = (c & 0x07);
         if (c & 0x08)                   /* sys_realtime:        */
           switch (lo3) {                /*   dispatch now       */
           case 0: /* m_clktim++; */     /* timing clock         */
@@ -544,7 +548,7 @@ int sensMidi(CSOUND *csound)
         goto nxtchr;
       }
       else {                            /* other status types:  */
-        short chan;
+        int16 chan;
         p->sexp = 0;                    /* also implies sys_exclus end */
         chan = c & 0xF;
         mep->type = type;               /* & begin new event    */
@@ -587,6 +591,10 @@ void MidiClose(CSOUND *csound)
     MGLOBAL *p = csound->midiGlobals;
     int     retval;
 
+    if (p==NULL) {
+      printf("No MIDI\n");
+      return;
+    }
     if (p->MidiInCloseCallback != NULL) {
       retval = p->MidiInCloseCallback(csound, p->midiInUserData);
       if (retval != 0)
@@ -611,4 +619,3 @@ void MidiClose(CSOUND *csound)
       p->midiOutFileData = NULL;
     }
 }
-
