@@ -21,14 +21,9 @@
     02111-1307 USA
 */
 
-#ifdef MSVC
 #include <windows.h>
-#endif
 #include "csdl.h"
 #include "soundio.h"
-#ifndef MSVC
-#include <windows.h>
-#endif
 
 #ifdef MAXBUFFERS
 #undef MAXBUFFERS
@@ -101,13 +96,13 @@ static int allocate_buffers(CSOUND *csound, rtWinMMDevice *dev,
       dev->nBuffers = 2;
     if (dev->enable_buf_timer)
       dev->nBuffers *= 2;
-    if (dev->nBuffers > MAXBUFFERS) {
+    if (UNLIKELY(dev->nBuffers > MAXBUFFERS)) {
       dev->nBuffers = 0;
       return err_msg(csound, Str("too many buffers"));
     }
     for (i = 0; i < dev->nBuffers; i++) {
       ptr = GlobalAlloc(GMEM_MOVEABLE | GMEM_SHARE, (SIZE_T) bufBytes);
-      if (ptr == (HGLOBAL) NULL) {
+      if (UNLIKELY(ptr == (HGLOBAL) NULL)) {
         dev->nBuffers = i;
         return err_msg(csound, Str("memory allocation failure"));
       }
@@ -122,7 +117,7 @@ static int allocate_buffers(CSOUND *csound, rtWinMMDevice *dev,
         err = (int) waveInPrepareHeader(dev->inDev,
                                         (LPWAVEHDR) &(dev->buffers[i]),
                                         sizeof(WAVEHDR));
-      if (err != MMSYSERR_NOERROR)
+      if (UNLIKELY(err != MMSYSERR_NOERROR))
         return err_msg(csound, Str("failed to prepare buffers"));
       dev->buffers[i].dwFlags |= WHDR_DONE;
     }
@@ -161,14 +156,49 @@ static void MYFLT_to_short(int nSmps, MYFLT *inBuf, int16_t *outBuf, int *seed)
 {
     MYFLT   tmp_f;
     int     tmp_i;
-    while (nSmps--) {
-      (*seed) = (((*seed) * 15625) + 1) & 0xFFFF;
-      tmp_f = (MYFLT) ((*seed) - 0x8000) * (FL(1.0) / (MYFLT) 0x10000);
-      tmp_f += *(inBuf++) * (MYFLT) 0x8000;
+    int n;
+    for (n=0; n<nSmps; n++){
+      int rnd = (((*seed) * 15625) + 1) & 0xFFFF;
+      *seed = (((rnd) * 15625) + 1) & 0xFFFF;
+      rnd += *seed;           /* triangular distribution */
+      tmp_f = (MYFLT) ((rnd>>1) - 0x8000) * (FL(1.0) / (MYFLT) 0x10000);
+      tmp_f += inBuf[n] * (MYFLT) 0x8000;
       tmp_i = (int) MYFLT2LRND(tmp_f);
       if (tmp_i < -0x8000) tmp_i = -0x8000;
       if (tmp_i > 0x7FFF) tmp_i = 0x7FFF;
-      *(outBuf++) = (int16_t) tmp_i;
+      outBuf[n] = (int16_t) tmp_i;
+    }
+}
+
+static void MYFLT_to_short_u(int nSmps, MYFLT *inBuf, int16_t *outBuf, int *seed)
+{
+    MYFLT   tmp_f;
+    int     tmp_i;
+    int n;
+    for (n=0; n<nSmps; n++) {
+      int rnd = (((*seed) * 15625) + 1) & 0xFFFF;
+      *seed = rnd;
+      tmp_f = (MYFLT) (rnd - 0x8000) * (FL(1.0) / (MYFLT) 0x10000);
+      tmp_f += inBuf[n] * (MYFLT) 0x8000;
+      tmp_i = (int) MYFLT2LRND(tmp_f);
+      if (tmp_i < -0x8000) tmp_i = -0x8000;
+      if (tmp_i > 0x7FFF) tmp_i = 0x7FFF;
+      outBuf[n] = (int16_t) tmp_i;
+    }
+}
+
+static void MYFLT_to_short_no_dither(int nSmps, MYFLT *inBuf,
+                                     int16_t *outBuf, int *seed)
+{
+    MYFLT   tmp_f;
+    int     tmp_i;
+    int n;
+    for (n=0; n<nSmps; n++){
+      tmp_f = inBuf[n] * (MYFLT) 0x8000;
+      tmp_i = (int) MYFLT2LRND(tmp_f);
+      if (tmp_i < -0x8000) tmp_i = -0x8000;
+      if (tmp_i > 0x7FFF) tmp_i = 0x7FFF;
+      outBuf[n] = (int16_t) tmp_i;
     }
 }
 
@@ -177,21 +207,23 @@ static void MYFLT_to_long(int nSmps, MYFLT *inBuf, int32_t *outBuf, int *seed)
     MYFLT   tmp_f;
     int64_t tmp_i;
     (void) seed;
-    while (nSmps--) {
-      tmp_f = *(inBuf++) * (MYFLT) 0x80000000UL;
+    int n;
+    for (n=0; n<nSmps; n++) {
+      tmp_f = inBuf[n] * (MYFLT) 0x80000000UL;
       tmp_i = (int64_t) (tmp_f + (tmp_f < FL(0.0) ? FL(-0.5) : FL(0.5)));
       if (tmp_i < -((int64_t) 0x80000000UL))
         tmp_i = -((int64_t) 0x80000000UL);
       if (tmp_i > (int64_t) 0x7FFFFFFF) tmp_i = (int64_t) 0x7FFFFFFF;
-      *(outBuf++) = (int32_t) tmp_i;
+      outBuf[n] = (int32_t) tmp_i;
     }
 }
 
 static void MYFLT_to_float(int nSmps, MYFLT *inBuf, float *outBuf, int *seed)
 {
     (void) seed;
-    while (nSmps--)
-      *(outBuf++) = (float) *(inBuf++);
+    int n;
+    for (n=0; n<nSmps; n++)
+      outBuf[n] = (float) inBuf[n];
 }
 
 /* sample conversion routines for recording */
@@ -204,14 +236,16 @@ static void short_to_MYFLT(int nSmps, int16_t *inBuf, MYFLT *outBuf)
 
 static void long_to_MYFLT(int nSmps, int32_t *inBuf, MYFLT *outBuf)
 {
-    while (nSmps--)
-      *(outBuf++) = (MYFLT) *(inBuf++) * (FL(1.0) / (MYFLT) 0x80000000UL);
+    int n;
+    for (n=0; n<nSmps; n++)
+      outBuf[n] = (MYFLT) inBuf[n] * (FL(1.0) / (MYFLT) 0x80000000UL);
 }
 
 static void float_to_MYFLT(int nSmps, float *inBuf, MYFLT *outBuf)
 {
-    while (nSmps--)
-      *(outBuf++) = (MYFLT) *(inBuf++);
+    int n;
+    for (n=0; n<nSmps; n++)
+      outBuf[n] = (MYFLT) inBuf[n];
 }
 
 static int open_device(CSOUND *csound,
@@ -224,7 +258,7 @@ static int open_device(CSOUND *csound,
     int             i, ndev, devNum, conv_idx;
     DWORD           openFlags = CALLBACK_NULL;
 
-    if (parm->devName != NULL)
+    if (UNLIKELY(parm->devName != NULL))
       return err_msg(csound, Str("Must specify a device number, not a name"));
     if (set_format_params(csound, &wfx, parm) != 0)
       return -1;
@@ -241,9 +275,9 @@ static int open_device(CSOUND *csound,
                            sizeof(WAVEOUTCAPSA));
         csound->Message(csound, Str("%3d: %s\n"), i, (char*) caps.szPname);
       }
-      if (ndev < 1)
+      if (UNLIKELY(ndev < 1))
         return err_msg(csound, Str("No output device is available"));
-      if (devNum < 0 || devNum >= ndev) {
+      if (UNLIKELY(devNum < 0 || devNum >= ndev)) {
         return err_msg(csound, Str("Device number is out of range"));
       }
       waveOutGetDevCapsA((unsigned int) devNum, (LPWAVEOUTCAPSA) &caps,
@@ -260,9 +294,9 @@ static int open_device(CSOUND *csound,
                           sizeof(WAVEINCAPSA));
         csound->Message(csound, Str("%3d: %s\n"), i, (char*) caps.szPname);
       }
-      if (ndev < 1)
+      if (UNLIKELY(ndev < 1))
         return err_msg(csound, Str("no input device is available"));
-      if (devNum < 0 || devNum >= ndev) {
+      if (UNLIKELY(devNum < 0 || devNum >= ndev)) {
         return err_msg(csound, Str("device number is out of range"));
       }
       waveInGetDevCapsA((unsigned int) devNum, (LPWAVEINCAPSA) &caps,
@@ -272,25 +306,34 @@ static int open_device(CSOUND *csound,
     }
     p = (rtWinMMGlobals*)
           csound->QueryGlobalVariable(csound, "_rtwinmm_globals");
-    dev = (rtWinMMDevice*) malloc(sizeof(rtWinMMDevice));
-    if (dev == NULL)
+    dev = (rtWinMMDevice*) csound->Malloc(csound, sizeof(rtWinMMDevice));
+    if (UNLIKELY(dev == NULL))
       return err_msg(csound, Str("memory allocation failure"));
     memset(dev, 0, sizeof(rtWinMMDevice));
     conv_idx = (parm->sampleFormat == AE_SHORT ?
                 0 : (parm->sampleFormat == AE_LONG ? 1 : 2));
     if (is_playback) {
       p->outDev = dev;
-      csound->rtPlay_userdata = (void*) dev;
+     *(csound->GetRtPlayUserData(csound)) = (void*) dev;
       dev->enable_buf_timer = p->enable_buf_timer;
-      if (waveOutOpen((LPHWAVEOUT) &(dev->outDev), (unsigned int) devNum,
-                      (LPWAVEFORMATEX) &wfx, 0, 0,
-                      openFlags) != MMSYSERR_NOERROR) {
+      if (UNLIKELY(waveOutOpen((LPHWAVEOUT) &(dev->outDev), (unsigned int) devNum,
+                               (LPWAVEFORMATEX) &wfx, 0, 0,
+                               openFlags) != MMSYSERR_NOERROR)) {
         dev->outDev = (HWAVEOUT) 0;
         return err_msg(csound, Str("failed to open device"));
       }
       switch (conv_idx) {
-        case 0: dev->playconv =
-                  (void (*)(int, MYFLT*, void*, int*)) MYFLT_to_short;  break;
+        case 0:
+          if (csound->GetDitherMode(csound)==1)
+            dev->playconv =
+                  (void (*)(int, MYFLT*, void*, int*)) MYFLT_to_short;
+          else if (csound->GetDitherMode(csound)==2)
+            dev->playconv =
+                  (void (*)(int, MYFLT*, void*, int*)) MYFLT_to_short_u;
+          else
+            dev->playconv =
+                  (void (*)(int, MYFLT*, void*, int*)) MYFLT_to_short_no_dither;
+          break;
         case 1: dev->playconv =
                   (void (*)(int, MYFLT*, void*, int*)) MYFLT_to_long;   break;
         case 2: dev->playconv =
@@ -299,12 +342,12 @@ static int open_device(CSOUND *csound,
     }
     else {
       p->inDev = dev;
-      csound->rtRecord_userdata = (void*) dev;
+      *(csound->GetRtRecordUserData(csound)) = (void*) dev;
       /* disable playback timer in full-duplex mode */
       dev->enable_buf_timer = p->enable_buf_timer = 0;
-      if (waveInOpen((LPHWAVEIN) &(dev->inDev), (unsigned int) devNum,
-                     (LPWAVEFORMATEX) &wfx, 0, 0,
-                     openFlags) != MMSYSERR_NOERROR) {
+      if (UNLIKELY(waveInOpen((LPHWAVEIN) &(dev->inDev), (unsigned int) devNum,
+                              (LPWAVEFORMATEX) &wfx, 0, 0,
+                              openFlags) != MMSYSERR_NOERROR)) {
         dev->inDev = (HWAVEIN) 0;
         return err_msg(csound, Str("failed to open device"));
       }
@@ -317,7 +360,7 @@ static int open_device(CSOUND *csound,
                   (void (*)(int, void*, MYFLT*)) float_to_MYFLT;  break;
       }
     }
-    if (allocate_buffers(csound, dev, parm, is_playback) != 0)
+    if (UNLIKELY(allocate_buffers(csound, dev, parm, is_playback) != 0))
       return -1;
     if (!is_playback)
       waveInStart(dev->inDev);
@@ -347,7 +390,7 @@ static int playopen_(CSOUND *csound, const csRtAudioParams *parm)
 
 static int rtrecord_(CSOUND *csound, MYFLT *inBuf, int nbytes)
 {
-    rtWinMMDevice   *dev = (rtWinMMDevice*) csound->rtRecord_userdata;
+    rtWinMMDevice   *dev = (rtWinMMDevice*) *(csound->GetRtRecordUserData(csound));
     WAVEHDR         *buf = &(dev->buffers[dev->cur_buf]);
     volatile DWORD  *dwFlags = &(buf->dwFlags);
 
@@ -376,7 +419,7 @@ static int rtrecord_(CSOUND *csound, MYFLT *inBuf, int nbytes)
 
 static void rtplay_(CSOUND *csound, const MYFLT *outBuf, int nbytes)
 {
-    rtWinMMDevice   *dev = (rtWinMMDevice*) csound->rtPlay_userdata;
+    rtWinMMDevice   *dev = (rtWinMMDevice*) *(csound->GetRtPlayUserData(csound));
     WAVEHDR         *buf = &(dev->buffers[dev->cur_buf]);
     volatile DWORD  *dwFlags = &(buf->dwFlags);
     LARGE_INTEGER   pp;
@@ -408,7 +451,7 @@ static void rtplay_(CSOUND *csound, const MYFLT *outBuf, int nbytes)
     timeWait = dev->bufTime;
     timeWait *= (((float) nbufs / (float) dev->nBuffers) * 0.25f + 0.875f);
     timeWait -= timeDiff;
-    i = (int) MYFLT2LRND((MYFLT) timeWait);
+    i = MYFLT2LRND(timeWait);
     if (i > 0)
       Sleep((DWORD) i);
 }
@@ -419,8 +462,8 @@ static void rtclose_(CSOUND *csound)
     rtWinMMDevice   *inDev, *outDev;
     int             i;
 
-    csound->rtPlay_userdata = NULL;
-    csound->rtRecord_userdata = NULL;
+    *(csound->GetRtPlayUserData(csound))  = NULL;
+    *(csound->GetRtRecordUserData(csound))  = NULL;
     pp = (rtWinMMGlobals*) csound->QueryGlobalVariable(csound,
                                                        "_rtwinmm_globals");
     if (pp == NULL)
@@ -438,7 +481,7 @@ static void rtclose_(CSOUND *csound)
         GlobalFree((HGLOBAL) inDev->buffers[i].lpData);
       }
       waveInClose(inDev->inDev);
-      free(inDev);
+      csound->Free(csound,inDev);
     }
     if (outDev != NULL) {
       volatile DWORD  *dwFlags = &(outDev->buffers[outDev->cur_buf].dwFlags);
@@ -453,7 +496,7 @@ static void rtclose_(CSOUND *csound)
         GlobalFree((HGLOBAL) outDev->buffers[i].lpData);
       }
       waveOutClose(outDev->outDev);
-      free(outDev);
+      csound->Free(csound,outDev);
     }
 }
 
@@ -484,13 +527,13 @@ static int midi_in_open(CSOUND *csound, void **userData, const char *devName)
 
     *userData = NULL;
     ndev = (int) midiInGetNumDevs();
-    if (ndev < 1) {
+    if (UNLIKELY(ndev < 1)) {
       csound->ErrorMsg(csound, Str("rtmidi: no input devices are available"));
       return -1;
     }
     if (devName != NULL && devName[0] != '\0' &&
         strcmp(devName, "default") != 0) {
-      if (devName[0] < '0' || devName[0] > '9') {
+      if (UNLIKELY(devName[0] < '0' || devName[0] > '9')) {
         csound->ErrorMsg(csound, Str("rtmidi: must specify a device number, "
                                      "not a name"));
         return -1;
@@ -502,13 +545,14 @@ static int midi_in_open(CSOUND *csound, void **userData, const char *devName)
       midiInGetDevCaps((unsigned int) i, &caps, sizeof(MIDIINCAPS));
       csound->Message(csound, "%3d: %s\n", i, &(caps.szPname[0]));
     }
-    if (devnum < 0 || devnum >= ndev) {
+    if (UNLIKELY(devnum < 0 || devnum >= ndev)) {
       csound->ErrorMsg(csound,
                        Str("rtmidi: input device number is out of range"));
       return -1;
     }
-    p = (RTMIDI_MME_GLOBALS*) calloc((size_t) 1, sizeof(RTMIDI_MME_GLOBALS));
-    if (p == NULL) {
+    p = (RTMIDI_MME_GLOBALS*) csound->Calloc(csound,
+                                             (size_t) sizeof(RTMIDI_MME_GLOBALS));
+    if (UNLIKELY(p == NULL)) {
       csound->ErrorMsg(csound, Str("rtmidi: memory allocation failure"));
       return -1;
     }
@@ -517,9 +561,9 @@ static int midi_in_open(CSOUND *csound, void **userData, const char *devName)
     midiInGetDevCaps((unsigned int) devnum, &caps, sizeof(MIDIINCAPS));
     csound->Message(csound, Str("Opening MIDI input device %d (%s)\n"),
                             devnum, &(caps.szPname[0]));
-    if (midiInOpen(&(p->inDev), (unsigned int) devnum,
-                   (DWORD) midi_in_handler, (DWORD) p, CALLBACK_FUNCTION)
-        != MMSYSERR_NOERROR) {
+    if (UNLIKELY(midiInOpen(&(p->inDev), (unsigned int) devnum,
+                            (DWORD) midi_in_handler, (DWORD) p, CALLBACK_FUNCTION)
+                 != MMSYSERR_NOERROR)) {
       p->inDev = (HMIDIIN) 0;
       csound->ErrorMsg(csound, Str("rtmidi: could not open input device"));
       return -1;
@@ -575,26 +619,26 @@ static int midi_in_close(CSOUND *csound, void *userData)
       midiInClose(p->inDev);
     }
     DeleteCriticalSection(&(p->threadLock));
-    free(p);
+    csound->Free(csound,p);
 
     return 0;
 }
 
 static int midi_out_open(CSOUND *csound, void **userData, const char *devName)
 {
-  int         i, ndev, devnum = 0;
+    int         i, ndev, devnum = 0;
     MIDIOUTCAPS caps;
     HMIDIOUT    outDev = (HMIDIOUT) 0;
 
     *userData = NULL;
     ndev = (int) midiOutGetNumDevs();
-    if (ndev < 1) {
+    if (UNLIKELY(ndev < 1)) {
       csound->ErrorMsg(csound, Str("rtmidi: no output devices are available"));
       return -1;
     }
     if (devName != NULL && devName[0] != '\0' &&
         strcmp(devName, "default") != 0) {
-      if (devName[0] < '0' || devName[0] > '9') {
+      if (UNLIKELY(devName[0] < '0' || devName[0] > '9')) {
         csound->ErrorMsg(csound, Str("rtmidi: must specify a device number, "
                                      "not a name"));
         return -1;
@@ -606,7 +650,7 @@ static int midi_out_open(CSOUND *csound, void **userData, const char *devName)
       midiOutGetDevCaps((unsigned int) i, &caps, sizeof(MIDIOUTCAPS));
       csound->Message(csound, "%3d: %s\n", i, &(caps.szPname[0]));
     }
-    if (devnum < 0 || devnum >= ndev) {
+    if (UNLIKELY(devnum < 0 || devnum >= ndev)) {
       csound->ErrorMsg(csound,
                        Str("rtmidi: output device number is out of range"));
       return -1;
@@ -614,8 +658,9 @@ static int midi_out_open(CSOUND *csound, void **userData, const char *devName)
     midiOutGetDevCaps((unsigned int) devnum, &caps, sizeof(MIDIOUTCAPS));
     csound->Message(csound, Str("Opening MIDI output device %d (%s)\n"),
                             devnum, &(caps.szPname[0]));
-    if (midiOutOpen(&outDev, (unsigned int) devnum,
-                    (DWORD) 0, (DWORD) 0, CALLBACK_NULL) != MMSYSERR_NOERROR) {
+    if (UNLIKELY(midiOutOpen(&outDev, (unsigned int) devnum,
+                             (DWORD) 0, (DWORD) 0,
+                             CALLBACK_NULL) != MMSYSERR_NOERROR)) {
       csound->ErrorMsg(csound, Str("rtmidi: could not open output device"));
       return -1;
     }
@@ -672,13 +717,15 @@ static int midi_out_close(CSOUND *csound, void *userData)
 PUBLIC int csoundModuleCreate(CSOUND *csound)
 {
     rtWinMMGlobals  *pp;
+    OPARMS oparms;
+     csound->GetOParms(csound, &oparms);
 
-    if (csound->oparms->msglevel & 0x400)
+    if (UNLIKELY(oparms.msglevel & 0x400))
       csound->Message(csound, Str("Windows MME real time audio and MIDI module "
                                   "for Csound by Istvan Varga\n"));
 
-    if (csound->CreateGlobalVariable(csound, "_rtwinmm_globals",
-                                   sizeof(rtWinMMGlobals)) != 0)
+    if (UNLIKELY(csound->CreateGlobalVariable(csound, "_rtwinmm_globals",
+                                              sizeof(rtWinMMGlobals)) != 0))
       return err_msg(csound, Str("could not allocate global structure"));
     pp = (rtWinMMGlobals*) csound->QueryGlobalVariable(csound,
                                                        "_rtwinmm_globals");
@@ -711,7 +758,7 @@ static CS_NOINLINE int check_name(const char *s)
 PUBLIC int csoundModuleInit(CSOUND *csound)
 {
     if (check_name((char*) csound->QueryGlobalVariable(csound, "_RTAUDIO"))) {
-      csound->Message(csound, "rtaudio: WinMM module enabled\n");
+      csound->Message(csound, Str("rtaudio: WinMM module enabled\n"));
       csound->SetPlayopenCallback(csound, playopen_);
       csound->SetRecopenCallback(csound, recopen_);
       csound->SetRtplayCallback(csound, rtplay_);
@@ -719,7 +766,7 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
       csound->SetRtcloseCallback(csound, rtclose_);
     }
     if (check_name((char*) csound->QueryGlobalVariable(csound, "_RTMIDI"))) {
-      csound->Message(csound, "rtmidi: WinMM module enabled\n");
+      csound->Message(csound, Str("rtmidi: WinMM module enabled\n"));
       csound->SetExternalMidiInOpenCallback(csound, midi_in_open);
       csound->SetExternalMidiReadCallback(csound, midi_in_read);
       csound->SetExternalMidiInCloseCallback(csound, midi_in_close);
@@ -734,4 +781,3 @@ PUBLIC int csoundModuleInfo(void)
 {
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int) sizeof(MYFLT));
 }
-
