@@ -467,10 +467,10 @@ static int diskin2_init_(CSOUND *csound, DISKIN2 *p, int stringname)
       if (UNLIKELY((csound->oparms_.msglevel & 7) == 7)) {
         csound->Message(csound, Str("diskin2: opened (asynchronously) '%s':\n"
                                     "         %d Hz, %d channel(s), "
-                                    "%ld sample frames\n"),
+                                    "%lld sample frames\n"),
                         csound->GetFileName(fd),
-                        (int)sfinfo.samplerate, (int)sfinfo.channels,
-                        (int32) sfinfo.frames);
+                        sfinfo.samplerate, sfinfo.channels,
+                        sfinfo.frames);
       }
     }
     else {
@@ -481,10 +481,10 @@ static int diskin2_init_(CSOUND *csound, DISKIN2 *p, int stringname)
       if (UNLIKELY((csound->oparms_.msglevel & 7) == 7)) {
         csound->Message(csound, Str("diskin2: opened '%s':\n"
                                     "         %d Hz, %d channel(s), "
-                                    "%ld sample frames\n"),
+                                    "%lld sample frames\n"),
                         csound->GetFileName(fd),
-                        (int)sfinfo.samplerate, (int)sfinfo.channels,
-                        (int32) sfinfo.frames);
+                        sfinfo.samplerate, sfinfo.channels,
+                        sfinfo.frames);
       }
     }
 
@@ -1725,8 +1725,10 @@ static int diskin2_init_array(CSOUND *csound, DISKIN2_ARRAY *p, int stringname)
                                         "DISKIN_THREAD_START_ARRAY")) == 0) {
         uintptr_t diskin_io_thread_array(void *p);
         // TOFIX: this variable (thread) is not referenced
+        #if 0
         void **thread = csound->QueryGlobalVariable(csound,
                                                        "DISKIN_PTHREAD_ARRAY");
+        #endif
         *start = 1;
         csound->CreateThread(diskin_io_thread_array, *top);
       }
@@ -1739,10 +1741,10 @@ static int diskin2_init_array(CSOUND *csound, DISKIN2_ARRAY *p, int stringname)
       if (UNLIKELY((csound->oparms_.msglevel & 7) == 7)) {
         csound->Message(csound, Str("diskin2: opened (asynchronously) '%s':\n"
                                     "         %d Hz, %d channel(s), "
-                                    "%ld sample frames\n"),
+                                    "%lld sample frames\n"),
                         csound->GetFileName(fd),
-                        (int)sfinfo.samplerate, (int)sfinfo.channels,
-                        (int32) sfinfo.frames);
+                        sfinfo.samplerate, sfinfo.channels,
+                        sfinfo.frames);
       }
     }
     else {
@@ -1753,10 +1755,10 @@ static int diskin2_init_array(CSOUND *csound, DISKIN2_ARRAY *p, int stringname)
       if (UNLIKELY((csound->oparms_.msglevel & 7) == 7)) {
         csound->Message(csound, Str("diskin2: opened '%s':\n"
                                     "         %d Hz, %d channel(s), "
-                                    "%ld sample frames\n"),
+                                    "%lld sample frames\n"),
                         csound->GetFileName(fd),
-                        (int)sfinfo.samplerate, (int)sfinfo.channels,
-                        (int32) sfinfo.frames);
+                        sfinfo.samplerate, sfinfo.channels,
+                        sfinfo.frames);
       }
     }
 
