@@ -30,9 +30,6 @@
 #ifdef MSVC                   /* Thanks to Richard Dobson */
 # define hypot _hypot
 #endif
-#if defined(__WATCOMC__) || defined(__ncc)
-extern double hypot(double, double);
-#endif
 
 int printv(CSOUND *csound, PRINTV *p)
 {
@@ -41,7 +38,7 @@ int printv(CSOUND *csound, PRINTV *p)
     MYFLT  **valp = p->iargs;
 
     csound->MessageS(csound, CSOUNDMSG_ORCH,
-                     "instr %d:", (int) p->h.insdshead->p1);
+                     "instr %d:", (int) p->h.insdshead->p1.value);
     while (nargs--) {
       csound->MessageS(csound, CSOUNDMSG_ORCH,
                        "  %s = %5.3f", *txtp++, **valp++);
@@ -53,13 +50,15 @@ int printv(CSOUND *csound, PRINTV *p)
 int fdspset(CSOUND *csound, FSIGDISP *p){
     char strmsg[256];
     p->size = p->fin->N/2 + 1;
-    if (*p->points && (p->size > *p->points)) p->size = *p->points;
-
-  if (p->fdata.auxp == NULL || p->fdata.size < p->size*sizeof(MYFLT))
+    if ((*p->points != (MYFLT) 0) && (p->size > (int) *p->points)) {
+      p->size = *p->points;
+    }
+    if ((p->fdata.auxp == NULL) ||
+        (p->fdata.size < (unsigned int) (p->size*sizeof(MYFLT)))) {
       csound->AuxAlloc(csound, p->size*sizeof(MYFLT), &p->fdata);
-
-    sprintf(strmsg, Str("instr %d, pvs-signal %s:"),
-      (int) p->h.insdshead->p1, p->h.optext->t.inlist->arg[0]);
+    }
+    snprintf(strmsg, 256, Str("instr %d, pvs-signal %s:"),
+            (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
     dispset(csound, &p->dwindow, (MYFLT*) p->fdata.auxp, p->size, strmsg,
                     (int) *p->flag, Str("display"));
     p->lastframe = 0;
@@ -67,34 +66,35 @@ int fdspset(CSOUND *csound, FSIGDISP *p){
 
 }
 
-int fdsplay(CSOUND *csound, FSIGDISP *p){
+int fdsplay(CSOUND *csound, FSIGDISP *p)
+{
     float *fin   = p->fin->frame.auxp;
     MYFLT *pdata = p->fdata.auxp;
     int i,k, end = p->size;
 
-   if (p->lastframe < p->fin->framecount) {
-    for (i=0, k=0; k < end; i+=2,k++) pdata[k] = fin[i];
-     display(csound, &p->dwindow);
+    if (p->lastframe < p->fin->framecount) {
+      for (i=0, k=0; k < end; i+=2,k++) pdata[k] = fin[i];
+      display(csound, &p->dwindow);
       p->lastframe = p->fin->framecount;
-   }
-   return OK;
+    }
+    return OK;
  }
 
 int dspset(CSOUND *csound, DSPLAY *p)
 {
-    long   npts, nprds, bufpts, totpts;
+    int32  npts, nprds, bufpts, totpts;
     char   *auxp;
     char   strmsg[256];
 
     if (p->h.optext->t.intype == 'k')
-      npts = (long)(*p->iprd * csound->ekr);
-    else npts = (long)(*p->iprd * csound->esr);
-    if (npts <= 0) {
-      return csound->InitError(csound, Str("illegal iprd"));
+      npts = (int32)(*p->iprd * CS_EKR);
+    else npts = (int32)(*p->iprd * csound->esr);
+    if (UNLIKELY(npts <= 0)) {
+      return csound->InitError(csound, Str("illegal iprd in display"));
 
     }
-    if ((nprds = (long)*p->inprds) <= 1) {
-      nprds = 0;
+    if ((nprds = (int32)*p->inprds) <= 1) {
+      nprds  = 0;
       bufpts = npts;
       totpts = npts;
     }
@@ -104,20 +104,20 @@ int dspset(CSOUND *csound, DSPLAY *p)
     }
     if ((auxp = p->auxch.auxp) == NULL || totpts != p->totpts) {
       csound->AuxAlloc(csound, totpts * sizeof(MYFLT), &p->auxch);
-      auxp = p->auxch.auxp;
-      p->begp = (MYFLT *) auxp;
-      p->endp = p->begp + bufpts;
-      p->npts = npts;
-      p->nprds = nprds;
+      auxp      = p->auxch.auxp;
+      p->begp   = (MYFLT *) auxp;
+      p->endp   = p->begp + bufpts;
+      p->npts   = npts;
+      p->nprds  = nprds;
       p->bufpts = bufpts;
       p->totpts = totpts;
     }
     p->nxtp = (MYFLT *) auxp;
     p->pntcnt = npts;
-    sprintf(strmsg, Str("instr %d, signal %s:"),
-                    (int) p->h.insdshead->p1, p->h.optext->t.inlist->arg[0]);
+    snprintf(strmsg, 256, Str("instr %d, signal %s:"),
+             (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
     dispset(csound, &p->dwindow, (MYFLT*) auxp, bufpts, strmsg,
-                    (int) *p->iwtflg, Str("display"));
+            (int) *p->iwtflg, Str("display"));
     return OK;
 }
 
@@ -125,9 +125,7 @@ int kdsplay(CSOUND *csound, DSPLAY *p)
 {
     MYFLT  *fp = p->nxtp;
 
-    if (p->auxch.auxp==NULL) { /* RWD fix */
-      return csound->PerfError(csound, Str("display: not initialised"));
-    }
+    if (UNLIKELY(p->auxch.auxp==NULL)) goto err1; /* RWD fix */
     if (!p->nprds) {
       *fp++ = *p->signal;
       if (fp >= p->endp) {
@@ -151,16 +149,22 @@ int kdsplay(CSOUND *csound, DSPLAY *p)
     }
     p->nxtp = fp;
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("display: not initialised"));
 }
 
 int dsplay(CSOUND *csound, DSPLAY *p)
 {
     MYFLT  *fp = p->nxtp, *sp = p->signal, *endp = p->endp;
-    int    n, nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
 
+    nsmps -= early;
     if (!p->nprds) {
-      for (n=0; n<nsmps; n++) {
-        fp[n] = sp[n];
+      for (n=offset; n<nsmps; n++) {
+        *fp++ = sp[n];
         if (fp >= endp) {
           fp = p->begp;
           display(csound, &p->dwindow);
@@ -169,7 +173,7 @@ int dsplay(CSOUND *csound, DSPLAY *p)
     }
     else {
       MYFLT *fp2 = fp + p->bufpts;
-      for (n=0; n<nsmps; n++) {
+      for (n=offset; n<nsmps; n++) {
         *fp++ = sp[n];
         *fp2++ = sp[n];
         if (!(--p->pntcnt)) {
@@ -188,11 +192,11 @@ int dsplay(CSOUND *csound, DSPLAY *p)
 }
 
 /* Write window coefs into buffer, don't malloc */
-static void FillHalfWin(MYFLT *wBuf, long size, MYFLT max, int hannq)
+static void FillHalfWin(MYFLT *wBuf, int32 size, MYFLT max, int hannq)
     /* 1 => hanning window else hamming */
 {
     MYFLT       a,b;
-    long        i;
+    int32        i;
 
     if (hannq) {
       a = FL(0.50);
@@ -204,17 +208,19 @@ static void FillHalfWin(MYFLT *wBuf, long size, MYFLT max, int hannq)
     }
 
     if (wBuf!= NULL) {        /* NB: size/2 + 1 long - just indep terms */
+      MYFLT tmp;
       size /= 2;              /* to fix scaling */
+      tmp = PI_F/(MYFLT)size; /* optimisatuon?? */
       for (i=0; i<=size;++i)
-        wBuf[i] = max * (a-b*(MYFLT)cos(PI*(MYFLT)i/(MYFLT)size ) );
+        wBuf[i] = max * (a-b*COS(tmp*(MYFLT)i) );
     }
     return;
 }
 
-static void ApplyHalfWin(MYFLT *buf, MYFLT *win, long len)
+static void ApplyHalfWin(MYFLT *buf, MYFLT *win, int32 len)
 {   /* Window only store 1st half, is symmetric */
-    long    j;
-    long    lenOn2 = (len/2L);
+    int32    j;
+    int32    lenOn2 = (len/2);
 
     for (j=lenOn2+1; j--; )
       *buf++ *= *win++;
@@ -223,37 +229,48 @@ static void ApplyHalfWin(MYFLT *buf, MYFLT *win, long len)
 }
 
 int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
-                                       /* Transform of collected samples and  */
-                                       /* displays coefficients (mag or db)   */
+                                      /* Transform of collected samples and  */
+                                      /* displays coefficients (mag or db)   */
 {
-    long  window_size, step_size;
+    int32 window_size, step_size;
     int   hanning;
     char  strmsg[256];
+    int32  minbin, maxbin;
+    minbin = *p->imin;
+    maxbin = *p->imax;
 
-    window_size = (long)*p->inpts;
-    if (window_size > WINDMAX) {
+    if(p->smpbuf.auxp == NULL)
+      csound->AuxAlloc(csound, sizeof(MYFLT)*WINDMAX, &(p->smpbuf));
+
+    p->sampbuf = (MYFLT *) p->smpbuf.auxp;
+
+    window_size = (int32)*p->inpts;
+    if (UNLIKELY(window_size > WINDMAX)) {
       return csound->InitError(csound, Str("too many points requested"));
     }
-    if (window_size < WINDMIN) {
+    if (UNLIKELY(window_size < WINDMIN)) {
       return csound->InitError(csound, Str("too few points requested"));
     }
-    if (window_size < 1L || (window_size & (window_size - 1L)) != 0L) {
+    if (UNLIKELY(window_size < 1L || (window_size & (window_size - 1L)) != 0L)) {
       return csound->InitError(csound, Str("window size must be power of two"));
     }
     if (p->h.optext->t.intype == 'k')
-      step_size = (long)(*p->iprd * csound->ekr);
-    else step_size = (long)(*p->iprd * csound->esr);
-    if (step_size <= 0) {
-      return csound->InitError(csound, Str("illegal iprd"));
+      step_size = (int32)(*p->iprd * CS_EKR);
+    else step_size = (int32)(*p->iprd * csound->esr);
+    if (UNLIKELY(step_size <= 0)) {
+      return csound->InitError(csound, Str("illegal iprd in ffy display"));
     }
- /* if (inerrcnt) */
- /*   return; */
     hanning = (int)*p->ihann;
     p->dbout   = (int)*p->idbout;
     p->overlap = window_size - step_size;
-    if (window_size != p->windsize
-        || hanning != p->hanning) {             /* if windowing has changed:  */
-      long auxsiz;
+
+
+
+    if ( (maxbin - minbin) != p->npts ||
+         minbin != p->start         ||
+         window_size != p->windsize ||
+         hanning != p->hanning) {             /* if windowing has changed:  */
+      int32 auxsiz;
       MYFLT *hWin;
       p->windsize = window_size;                /* set new parameter values */
       p->hanning = hanning;
@@ -262,26 +279,32 @@ int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
       p->overN   = FL(1.0)/(*p->inpts);
       p->ncoefs  = window_size >>1;
       auxsiz = (window_size/2 + 1) * sizeof(MYFLT);  /* size for half window */
-      csound->AuxAlloc(csound, (long)auxsiz, &p->auxch); /* alloc or realloc */
+      csound->AuxAlloc(csound, (int32)auxsiz, &p->auxch); /* alloc or realloc */
       hWin = (MYFLT *) p->auxch.auxp;
       FillHalfWin(hWin, window_size,
                   FL(1.0), hanning);            /* fill with proper values */
       if (csound->disprep_fftcoefs == NULL) {
         /* room for WINDMAX*2 floats (fft size) */
-        csound->disprep_fftcoefs = (MYFLT*) mmalloc(csound, WINDMAX * 2
+        csound->disprep_fftcoefs = (MYFLT*) csound->Malloc(csound, WINDMAX * 2
                                                             * sizeof(MYFLT));
       }
-      sprintf(strmsg, Str("instr %d, signal %s, fft (%s):"),
-                      (int) p->h.insdshead->p1, p->h.optext->t.inlist->arg[0],
+      snprintf(strmsg, 256, Str("instr %d, signal %s, fft (%s):"),
+                      (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0],
                       p->dbout ? Str("db") : Str("mag"));
-      dispset(csound, &p->dwindow, csound->disprep_fftcoefs, p->ncoefs, strmsg,
-                      (int) *p->iwtflg, Str("fft"));
-    }
+      if(maxbin == 0) maxbin = p->ncoefs;
+      if(minbin > maxbin) minbin = 0;
+      p->npts = maxbin - minbin;
+      p->start = minbin;
+      dispset(csound, &p->dwindow,
+              csound->disprep_fftcoefs+p->start, p->npts, strmsg,
+              (int) *p->iwtflg, Str("fft"));
+       }
+
     return OK;
 }
 
 /* pack re,im,re,im into re,re */
-static void PackReals(MYFLT *buffer, long size)
+static void PackReals(MYFLT *buffer, int32 size)
 {
     MYFLT   *b2 = buffer;
 
@@ -293,49 +316,50 @@ static void PackReals(MYFLT *buffer, long size)
 }
 
 /* Convert Real & Imaginary spectra into Amplitude & Phase */
-static void Rect2Polar(MYFLT *buffer, long size)
+static void Rect2Polar(MYFLT *buffer, int32 size, MYFLT scal)
 {
-    long    i;
+    int32   i;
     MYFLT   *real,*imag;
-    double  re,im;
+    MYFLT   re,im;
     MYFLT   mag;
 
     real = buffer;
     imag = buffer+1;
     for (i = 0; i < size; i++) {
-      re = (double)real[i+i];
-      im = (double)imag[i+i];
-      real[2L*i] = mag = (MYFLT)hypot(re,im);
+      re = real[i+i]*scal;
+      im = imag[i+i]*scal;
+      real[2L*i] = mag = HYPOT(re,im);
       if (mag == FL(0.0))
         imag[i+i] = FL(0.0);
       else
-        imag[i+i] = (MYFLT)atan2(im,re);
+        imag[i+i] = ATAN2(im,re);
     }
 }
 
 /* packed buffer ie. reals, not complex */
-static void Lin2DB(MYFLT *buffer, long size)
+static void Lin2DB(MYFLT *buffer, int32 size)
 {
     while (size--) {
-      *buffer = /* FL(20.0)*log10 */ FL(8.68589)*(MYFLT)log(*buffer);
+      if(*buffer > 0.0)
+      *buffer = /* FL(20.0)*log10 */ FL(8.68589)*LOG(*buffer);
       buffer++;
     }
 }
 
 static void d_fft(      /* perform an FFT as reqd below */
   CSOUND *csound,
-  MYFLT *sce,   /* input array - pure packed real */
-  MYFLT *dst,   /* output array - packed magnitude, only half-length */
-  long  size,   /* number of points in input */
-  MYFLT *hWin,  /* hanning window lookup table */
-  int   dbq)    /* flag: 1-> convert output into db */
+  MYFLT  *sce,   /* input array - pure packed real */
+  MYFLT  *dst,   /* output array - packed magnitude, only half-length */
+  int32  size,   /* number of points in input */
+  MYFLT  *hWin,  /* hanning window lookup table */
+  int    dbq, MYFLT scal)    /* flag: 1-> convert output into db */
 {
     memcpy(dst, sce, sizeof(MYFLT) * size);     /* copy into scratch buffer */
     ApplyHalfWin(dst, hWin, size);
     csound->RealFFT(csound, dst, (int) size);   /* perform the FFT */
     dst[size] = dst[1];
     dst[1] = dst[size + 1L] = FL(0.0);
-    Rect2Polar(dst, (size >> 1) + 1);
+    Rect2Polar(dst, (size >> 1) + 1, scal);
     PackReals(dst, (size >> 1) + 1);
     if (dbq)
       Lin2DB(dst, (size >> 1) + 1);
@@ -345,23 +369,25 @@ int kdspfft(CSOUND *csound, DSPFFT *p)
 {
     MYFLT *bufp = p->bufp, *endp = p->endp;
 
-    if (p->auxch.auxp==NULL) { /* RWD fix */
-      return csound->PerfError(csound, Str("dispfft: not initialised"));
-    }
+    if(p->dbout) p->dwindow.polarity = NEGPOL;
+          else p->dwindow.polarity = POSPOL;
+
+    if (UNLIKELY(p->auxch.auxp==NULL)) goto err1; /* RWD fix */
     if (bufp < p->sampbuf)          /* skip any spare samples */
       bufp++;
     else {                          /* then start collecting  */
       *bufp++ = *p->signal;
       if (bufp >= endp) {           /* when full, do fft:     */
-        MYFLT *tp, *tplim;
+        MYFLT *tp;
+        //MYFLT *tplim;
         MYFLT *hWin = (MYFLT *) p->auxch.auxp;
         d_fft(csound, p->sampbuf, csound->disprep_fftcoefs,
-              p->windsize, hWin, p->dbout);
+              p->windsize, hWin, p->dbout, p->overN);
         tp = csound->disprep_fftcoefs;
-        tplim = tp + p->ncoefs;
-        do {
-          *tp *= p->overN;            /* scale 1/N */
-        } while (++tp < tplim);
+        //tplim = tp + p->ncoefs;
+        //do {
+        // *tp *= p->overN;            /* scale 1/N */
+        //} while (++tp < tplim);
         display(csound, &p->dwindow); /* & display */
         if (p->overlap > 0) {
           bufp = p->sampbuf;
@@ -375,32 +401,44 @@ int kdspfft(CSOUND *csound, DSPFFT *p)
     }
     p->bufp = bufp;
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("dispfft: not initialised"));
 }
 
 int dspfft(CSOUND *csound, DSPFFT *p)
 {
     MYFLT *sigp = p->signal, *bufp = p->bufp, *endp = p->endp;
-    int   nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
 
-    if (p->auxch.auxp==NULL) {
-      return csound->PerfError(csound, Str("dispfft: not initialised"));
+    if(p->dbout){
+       p->dwindow.polarity = NEGPOL;
+       p->dwindow.absflag = 1;
     }
-    do {
+          else p->dwindow.polarity = POSPOL;
+
+    if (UNLIKELY(p->auxch.auxp==NULL)) goto err1;
+    nsmps -= early;
+    for (n=offset; n<nsmps; n++) {
       if (bufp < p->sampbuf) {            /* skip any spare samples */
         bufp++; sigp++;
       }
       else {                              /* then start collecting  */
         *bufp++ = *sigp++;
         if (bufp >= endp) {               /* when full, do fft:     */
-          MYFLT *tp, *tplim;
+          MYFLT *tp;
+          //MYFLT *tplim;
           MYFLT *hWin = (MYFLT *) p->auxch.auxp;
           d_fft(csound, p->sampbuf, csound->disprep_fftcoefs,
-                p->windsize, hWin, p->dbout);
+                p->windsize, hWin, p->dbout, p->overN);
           tp = csound->disprep_fftcoefs;
-          tplim = tp + p->ncoefs;
-          do {
-            *tp *= p->overN;              /* scale 1/N */
-          } while (++tp < tplim);
+          //tplim = tp + p->ncoefs;
+          //do {
+          //  *tp *= p->overN;              /* scale 1/N */
+          //} while (++tp < tplim);
+
           display(csound, &p->dwindow);   /* & display */
           if (p->overlap > 0) {
             bufp = p->sampbuf;
@@ -412,9 +450,12 @@ int dspfft(CSOUND *csound, DSPFFT *p)
           else bufp = p->sampbuf + p->overlap;
         }
       }
-    } while (--nsmps);
+    }
     p->bufp = bufp;
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("dispfft: not initialised"));
 }
 
 #define NTERMS  4
@@ -428,26 +469,28 @@ int tempeset(CSOUND *csound, TEMPEST *p)
     MYFLT b, iperiod = *p->iprd;
     char  strmsg[256];
 
-    if ((p->timcount = (int)(csound->ekr * iperiod)) <= 0)
+    if (UNLIKELY((p->timcount = (int)(CS_EKR * iperiod)) <= 0))
       return csound->InitError(csound, Str("illegal iperiod"));
-    if ((p->dtimcnt = (int)(csound->ekr * *p->idisprd)) < 0)
+    if (UNLIKELY((p->dtimcnt = (int)(CS_EKR * *p->idisprd)) < 0))
       return csound->InitError(csound, Str("illegal idisprd"));
-    if ((p->tweek = *p->itweek) <= 0)
+    if (UNLIKELY((p->tweek = *p->itweek) <= 0))
       return csound->InitError(csound, Str("illegal itweek"));
     if (iperiod != FL(0.0)) {
-      if ((minlam = (int)(*p->imindur/iperiod)) <= 0)
+      if (UNLIKELY((minlam = (int)(*p->imindur/iperiod)) <= 0))
         return csound->InitError(csound, Str("illegal imindur"));
-      if ((npts = (int)(*p->imemdur / iperiod)) <= 0)
+      if (UNLIKELY((npts = (int)(*p->imemdur / iperiod)) <= 0))
         return csound->InitError(csound, Str("illegal imemdur"));
     }
-    if (*p->ihtim <= FL(0.0))
+    if (UNLIKELY(*p->ihtim <= FL(0.0)))
       return csound->InitError(csound, Str("illegal ihtim"));
-    if (*p->istartempo <= FL(0.0))
+    if (UNLIKELY(*p->istartempo <= FL(0.0)))
       return csound->InitError(csound, Str("illegal startempo"));
     ftp = csound->FTFind(csound, p->ifn);
-    if (ftp != NULL && *ftp->ftable == FL(0.0))
+    if (UNLIKELY(ftp != NULL && *ftp->ftable == FL(0.0)))
       return csound->InitError(csound, Str("ifn table begins with zero"));
-    if (ftp==NULL) return NOTOK;
+    if (UNLIKELY(ftp==NULL)) return NOTOK;
+
+    if (npts==0) return NOTOK;
 
     nptsm1 = npts - 1;
     if (npts != p->npts || minlam != p->minlam) {
@@ -456,31 +499,31 @@ int tempeset(CSOUND *csound, TEMPEST *p)
       p->maxlam = maxlam = nptsm1/(NTERMS-1);
       lamspan = maxlam - minlam + 1;          /* alloc 8 bufs: 2 circ, 6 lin */
       auxsiz = (npts * 5 + lamspan * 3) * sizeof(MYFLT);
-      csound->AuxAlloc(csound, (long)auxsiz, &p->auxch);
+      csound->AuxAlloc(csound, (int32)auxsiz, &p->auxch);
       fltp = (MYFLT *) p->auxch.auxp;
-      p->hbeg = fltp;     fltp += npts;
-      p->hend = fltp;
-      p->xbeg = fltp;     fltp += npts;
-      p->xend = fltp;
+      p->hbeg   = fltp;   fltp += npts;
+      p->hend   = fltp;
+      p->xbeg   = fltp;   fltp += npts;
+      p->xend   = fltp;
       p->stmemp = fltp;   fltp += npts;
       p->linexp = fltp;   fltp += npts;
       p->ftable = fltp;   fltp += npts;
       p->xscale = fltp;   fltp += lamspan;
       p->lmults = fltp;   fltp += lamspan;
-      p->lambdas = (short *) fltp;
+      p->lambdas = (int16 *) fltp;
       p->stmemnow = p->stmemp + nptsm1;
     }
     if (p->dtimcnt && !(p->dwindow.windid)) {  /* init to display stmem & exp */
-      sprintf(strmsg, "instr %d tempest:", (int) p->h.insdshead->p1);
-      dispset(csound, &p->dwindow, p->stmemp, (long)npts * 2, strmsg, 0,
+      snprintf(strmsg, 256, "instr %d tempest:", (int) p->h.insdshead->p1.value);
+      dispset(csound, &p->dwindow, p->stmemp, (int32)npts * 2, strmsg, 0,
                       Str("tempest"));
       p->dwindow.danflag = 1;                    /* for mid-scale axis */
     }
     {
       MYFLT *funp = ftp->ftable;
-      long phs = 0;
-      long inc = (long)PHMASK / npts;
-      long nn, lobits = ftp->lobits;
+      int32 phs = 0;
+      int32 inc = (int32)PHMASK / npts;
+      int32 nn, lobits = ftp->lobits;
       for (fltp=p->hbeg, nn=npts*4; nn--; )   /* clr 2 circ & 1st 2 lin bufs */
         *fltp++ = FL(0.0);
       for (fltp=p->ftable+npts, nn=npts; nn--; ) {  /* now sample the ftable  */
@@ -490,8 +533,8 @@ int tempeset(CSOUND *csound, TEMPEST *p)
     }
     {
       MYFLT *tblp, sumraw, sumsqr;      /* calc the CROSS prod scalers */
-      long terms;
-      long lambda, maxlam;
+      int32 terms;
+      int32 lambda, maxlam;
       MYFLT crossprods, RMS, *endtable = p->ftable + nptsm1;
    /* MYFLT coef, log001 = -6.9078; */
       MYFLT *xscale = p->xscale;
@@ -508,18 +551,18 @@ int tempeset(CSOUND *csound, TEMPEST *p)
           sumsqr += *tblp * *tblp;
         } while (--terms);
         crossprods = sumraw * sumraw - sumsqr;
-        RMS = (MYFLT) sqrt(crossprods / p->ncross);
+        RMS = SQRT(crossprods / p->ncross);
     /*  coef = exp(log001 * lambda / npts);
         *xscale++ = coef / RMS / (NTERMS - 1);  */
         *xscale++ = FL(0.05)/ RMS / lambda;
       }
     }
     /* calc input lo-pass filter coefs */
-    b = FL(2.0) - (MYFLT)cos((*p->ihp * 6.28318 * csound->onedkr));
-    p->coef1 = b - (MYFLT)sqrt(b * b - 1.0);
+    b = FL(2.0) - COS((*p->ihp * 6.28318 * CS_ONEDKR));
+    p->coef1 = b - SQRT(b * b - FL(1.0));
     p->coef0 = FL(1.0) - p->coef1;
     p->yt1 = FL(0.0);
-    p->fwdcoef = (MYFLT)pow(0.5, p->timcount*csound->onedkr/(*p->ihtim));
+    p->fwdcoef = POWER(FL(0.5), p->timcount*CS_ONEDKR/(*p->ihtim));
     p->fwdmask = FL(0.0);
 #ifdef DEBUG
     csound->Message(csound,
@@ -528,7 +571,7 @@ int tempeset(CSOUND *csound, TEMPEST *p)
 #endif
     p->thresh = *p->ithresh;            /* record incoming loudness threshold */
     p->xfdbak = *p->ixfdbak;            /*    & expectation feedback fraction */
-    p->tempscal = FL(60.0) * csound->ekr / p->timcount;
+    p->tempscal = FL(60.0) * CS_EKR / p->timcount;
     p->avglam = p->tempscal / *p->istartempo;       /* init the tempo factors */
     p->tempo = FL(0.0);
     p->hcur = p->hbeg;                              /* init the circular ptrs */
@@ -553,12 +596,10 @@ int tempest(CSOUND *csound, TEMPEST *p)
 {
     p->yt1 = p->coef0 * *p->kin + p->coef1 * p->yt1; /* get lo-pass of kinput */
 
-    if (p->auxch.auxp==NULL) { /* RWD fix */
-      return csound->PerfError(csound, Str("tempest: not initialised"));
-    }
-    if (!(--p->countdown)) {                        /* then on countdown:    */
+    if (UNLIKELY(p->auxch.auxp==NULL)) goto err1; /* RWD fix */
+    if (!(--p->countdown)) {                         /* then on countdown:    */
       MYFLT *memp;
-      MYFLT kin, expect, *xcur = p->xcur;           /* xcur from prv pass    */
+      MYFLT kin, expect, *xcur = p->xcur;            /* xcur from prv pass    */
       MYFLT lamtot = FL(0.0), weightot = FL(0.0);
 
       p->countdown = p->timcount;           /* reset the countdown            */
@@ -566,17 +607,17 @@ int tempest(CSOUND *csound, TEMPEST *p)
       *xcur++ = FL(0.0);                    /*    & clear the loc it occupied */
       if (xcur >= p->xend) xcur = p->xbeg;  /* xcur now points to cur xarray  */
       p->xcur = xcur;
-      #ifdef DEBUG
+#ifdef DEBUG
       csound->Message(csound, "**kin -> %f (%f,%f)\n",
                       *p->kin - p->yt1, *p->kin, p->yt1);
-      #endif
+#endif
       if ((kin = *p->kin - p->yt1) < FL(0.0))
         kin = FL(0.0);
       { /* ignore input below lopass */
         MYFLT *hcur = p->hcur;
         MYFLT *hend = p->hend;
         MYFLT *tblp = p->ftable;
-        long  wrap;
+        int32  wrap;
         *hcur++ = kin + expect * p->xfdbak;   /* join insample & expect val */
         if (hcur < hend)  p->hcur = hcur;     /* stor pntr for next insamp  */
         else p->hcur = p->hbeg;
@@ -590,14 +631,14 @@ int tempest(CSOUND *csound, TEMPEST *p)
       if (p->yt1 > p->thresh        /* if lo-pass of kinput now significant */
           && kin > p->fwdmask) {    /*    & kin > masking due to prev kin */
         MYFLT sumraw, sumsqr;
-        long lambda, minlam, maxlam;
+        int32 lambda, minlam, maxlam;
         int  terms, nn, npts = p->npts;
         MYFLT mult, crossprods, RMScross, RMStot, unilam, rd;
         MYFLT *xend = p->xend;
    /*   MYFLT *xscale = p->xscale;   */
         const MYFLT *mults, *fracs;
         MYFLT *mulp;
-        short minlen, maxlen, *lenp, *endlens;
+        int16 minlen, maxlen, *lenp, *endlens;
 
         for (memp=p->stmemp,nn=npts,sumsqr=FL(0.0); nn--; memp++)
           sumsqr += *memp * *memp;
@@ -614,8 +655,8 @@ int tempest(CSOUND *csound, TEMPEST *p)
         nn = NMULTS;
         do {
           mult = *mults++;
-          minlen = (short)(p->avglam * *fracs++); /* & the current avglam  */
-          maxlen = (short)(p->avglam * *fracs++);
+          minlen = (int16)(p->avglam * *fracs++); /* & the current avglam  */
+          maxlen = (int16)(p->avglam * *fracs++);
           if (minlen >= minlam && maxlen <= maxlam)
             do {
               *lenp++ = minlen++;         /*   creat lst of lambda lens */
@@ -636,8 +677,8 @@ int tempest(CSOUND *csound, TEMPEST *p)
             sumsqr += *memp * *memp;
           } while (--terms);
           crossprods = sumraw * sumraw - sumsqr;
-          if(crossprods >= 0)
-            RMScross = (MYFLT)sqrt(crossprods / p->ncross);
+          if (crossprods >= 0)
+            RMScross = SQRT(crossprods / p->ncross);
           else
             RMScross = FL(0.0);
           if (RMScross < FL(1.4) * RMStot)    /* if RMScross significant:   */
@@ -684,7 +725,7 @@ int tempest(CSOUND *csound, TEMPEST *p)
       MYFLT *linp = p->linexp;
       MYFLT *xcur = p->xcur;
       MYFLT *xend = p->xend;
-      long wrap = xcur - p->xbeg;
+      int32 wrap = xcur - p->xbeg;
       while (xcur < xend)                   /* lineariz the circ xbuf */
         *linp++ = *xcur++;                  /*  into linexp buf       */
       for (xcur=p->xbeg; wrap--; )
@@ -695,5 +736,7 @@ int tempest(CSOUND *csound, TEMPEST *p)
 /*  if (p->tempo != 0.0)  */
     *p->kout = p->tempo;                    /* put current tempo */
     return OK;
+ err1:
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("tempest: not initialised"));
 }
-
