@@ -824,7 +824,7 @@ extern "C" {
         0,
         3,
         (char*)"",
-        (char*)"kJP",
+        (char*)"ikJP",
         (SUBR) link_beat_request_t::init_,
         (SUBR) link_beat_request_t::kontrol_,
         0,
@@ -836,7 +836,7 @@ extern "C" {
         0,
         3,
         (char*)"",
-        (char*)"kJP",
+        (char*)"ikJP",
         (SUBR) link_beat_force_t::init_,
         (SUBR) link_beat_force_t::kontrol_,
         0,
