@@ -21,15 +21,15 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
     02111-1307 USA
 */
-
-#include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
 #include <math.h>
 
 typedef struct {
     OPDS    h;                                      /* required header */
     MYFLT   *mw, *mx, *my, *mz, *mr, *ms, *mt, *mu, *mv, *mk,
             *ml, *mm, *mn, *mo, *mp, *mq;           /* addr outarg */
-  MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
+    MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
     /* private dataspace */
     double  w, x, y, z, r, s, t, u, v, k, l, m, n, o, p, q;
 } AMBIC;
@@ -45,6 +45,8 @@ typedef struct {
 
 static int iambicode(CSOUND *csound, AMBIC *p)
 {
+    csound->Warning(csound,
+                    Str("bformenc is deprecated; use bformenc1 instead\n"));
     /* check correct number of input and output arguments */
     switch (p->OUTOCOUNT) {
       case 4:
@@ -100,7 +102,7 @@ static void ambicode_set_coefficients(AMBIC *p)
     /* calculate ambisonic coefficients (Furse-Malham-set) */
 
     /* 0th order */
-    p->w = FL(1.0) / sqrt(FL(2.0));
+    p->w = 0.707106781186547524400844362104849 /* (1.0 / sqrt(2.0)) */ ;
 
     /* 1st order */
     {
@@ -129,7 +131,9 @@ static void ambicode_set_coefficients(AMBIC *p)
 
 static int aambicode(CSOUND *csound, AMBIC *p)
 {
-    int nn = csound->ksmps;  /* array size from orchestra */
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS; /* array size from orchestra */
 
     /* init input array pointer */
     MYFLT *inptp = p->asig;
@@ -161,78 +165,122 @@ static int aambicode(CSOUND *csound, AMBIC *p)
     /* update coefficients */
     ambicode_set_coefficients(p);
 
+    if (UNLIKELY(offset)) {
+      memset(rsltp_w, '\0', offset*sizeof(MYFLT));
+      memset(rsltp_x, '\0', offset*sizeof(MYFLT));
+      memset(rsltp_y, '\0', offset*sizeof(MYFLT));
+      memset(rsltp_z, '\0', offset*sizeof(MYFLT));
+    }
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&rsltp_w[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&rsltp_x[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&rsltp_y[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&rsltp_z[nsmps], '\0', early*sizeof(MYFLT));
+    }
     if (p->OUTOCOUNT == 4 && p->INOCOUNT >= 5) {
       /* 1st order */
-      do {
+      for (n=offset; n<nsmps; n++) {
         /* 0th order */
-        *rsltp_w++ = *inptp * p->w * *p->kin[0];
+        rsltp_w[n] = *inptp * p->w * *p->kin[0];
 
         /* 1st order */
-        *rsltp_x++ = *inptp * p->x * *p->kin[1];
-        *rsltp_y++ = *inptp * p->y * *p->kin[1];
-        *rsltp_z++ = *inptp * p->z * *p->kin[1];
-
-        /* increment input pointer */
-        inptp++;
+        rsltp_x[n] = inptp[n] * p->x * *p->kin[1];
+        rsltp_y[n] = inptp[n] * p->y * *p->kin[1];
+        rsltp_z[n] = inptp[n] * p->z * *p->kin[1];
       }
-      while (--nn);
     }
     else if (p->OUTOCOUNT == 9 && p->INOCOUNT >= 6) {
       /* 2nd order */
 
-      do {
+      if (UNLIKELY(offset)) {
+        memset(rsltp_r, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_s, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_t, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_u, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_v, '\0', offset*sizeof(MYFLT));
+      }
+      if (UNLIKELY(early)) {
+        memset(&rsltp_r[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_s[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_t[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_u[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_v[nsmps], '\0', early*sizeof(MYFLT));
+      }
+      for (n=offset; n<nsmps; n++) {
         /* 0th order */
-        *rsltp_w++ = *inptp * p->w * *p->kin[0];
+        rsltp_w[n] = inptp[n] * p->w * *p->kin[0];
 
         /* 1st order */
-        *rsltp_x++ = *inptp * p->x * *p->kin[1];
-        *rsltp_y++ = *inptp * p->y * *p->kin[1];
-        *rsltp_z++ = *inptp * p->z * *p->kin[1];
+        rsltp_x[n] = inptp[n] * p->x * *p->kin[1];
+        rsltp_y[n] = inptp[n] * p->y * *p->kin[1];
+        rsltp_z[n] = inptp[n] * p->z * *p->kin[1];
 
         /* 2nd order */
-        *rsltp_r++ = *inptp * p->r * *p->kin[2];
-        *rsltp_s++ = *inptp * p->s * *p->kin[2];
-        *rsltp_t++ = *inptp * p->t * *p->kin[2];
-        *rsltp_u++ = *inptp * p->u * *p->kin[2];
-        *rsltp_v++ = *inptp * p->v * *p->kin[2];
+        rsltp_r[n] = inptp[n] * p->r * *p->kin[2];
+        rsltp_s[n] = inptp[n] * p->s * *p->kin[2];
+        rsltp_t[n] = inptp[n] * p->t * *p->kin[2];
+        rsltp_u[n] = inptp[n] * p->u * *p->kin[2];
+        rsltp_v[n] = inptp[n] * p->v * *p->kin[2];
 
-        /* increment input pointer */
-        inptp++;
       }
-      while (--nn);
     }
     else if (p->OUTOCOUNT == 16 && p->INOCOUNT >= 7) {
       /* 3rd order */
 
-      do {
+      if (UNLIKELY(offset)) {
+        memset(rsltp_r, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_s, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_t, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_u, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_v, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_k, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_l, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_m, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_n, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_o, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_p, '\0', offset*sizeof(MYFLT));
+        memset(rsltp_q, '\0', offset*sizeof(MYFLT));
+      }
+      if (UNLIKELY(early)) {
+        memset(&rsltp_r[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_s[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_t[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_u[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_v[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_k[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_l[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_m[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_n[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_o[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_p[nsmps], '\0', early*sizeof(MYFLT));
+        memset(&rsltp_q[nsmps], '\0', early*sizeof(MYFLT));
+      }
+      for (n=offset; n<nsmps; n++) {
         /* 0th order */
-        *rsltp_w++ = *inptp * p->w * *p->kin[0];
+        rsltp_w[n] = inptp[n] * p->w * *p->kin[0];
 
         /* 1st order */
-        *rsltp_x++ = *inptp * p->x * *p->kin[1];
-        *rsltp_y++ = *inptp * p->y * *p->kin[1];
-        *rsltp_z++ = *inptp * p->z * *p->kin[1];
+        rsltp_x[n] = inptp[n] * p->x * *p->kin[1];
+        rsltp_y[n] = inptp[n] * p->y * *p->kin[1];
+        rsltp_z[n] = inptp[n] * p->z * *p->kin[1];
 
         /* 2nd order */
-        *rsltp_r++ = *inptp * p->r * *p->kin[2];
-        *rsltp_s++ = *inptp * p->s * *p->kin[2];
-        *rsltp_t++ = *inptp * p->t * *p->kin[2];
-        *rsltp_u++ = *inptp * p->u * *p->kin[2];
-        *rsltp_v++ = *inptp * p->v * *p->kin[2];
+        rsltp_r[n] = inptp[n] * p->r * *p->kin[2];
+        rsltp_s[n] = inptp[n] * p->s * *p->kin[2];
+        rsltp_t[n] = inptp[n] * p->t * *p->kin[2];
+        rsltp_u[n] = inptp[n] * p->u * *p->kin[2];
+        rsltp_v[n] = inptp[n] * p->v * *p->kin[2];
 
         /* 3rd order */
-        *rsltp_k++ = *inptp * p->k * *p->kin[3];
-        *rsltp_l++ = *inptp * p->l * *p->kin[3];
-        *rsltp_m++ = *inptp * p->m * *p->kin[3];
-        *rsltp_n++ = *inptp * p->n * *p->kin[3];
-        *rsltp_o++ = *inptp * p->o * *p->kin[3];
-        *rsltp_p++ = *inptp * p->p * *p->kin[3];
-        *rsltp_q++ = *inptp * p->q * *p->kin[3];
-
-        /* increment input pointer */
-        inptp++;
+        rsltp_k[n] = inptp[n] * p->k * *p->kin[3];
+        rsltp_l[n] = inptp[n] * p->l * *p->kin[3];
+        rsltp_m[n] = inptp[n] * p->m * *p->kin[3];
+        rsltp_n[n] = inptp[n] * p->n * *p->kin[3];
+        rsltp_o[n] = inptp[n] * p->o * *p->kin[3];
+        rsltp_p[n] = inptp[n] * p->p * *p->kin[3];
+        rsltp_q[n] = inptp[n] * p->q * *p->kin[3];
       }
-      while (--nn);
     }
     return OK;
 }
@@ -281,16 +329,20 @@ static void ambideco_set_coefficients(AMBID *p, double alpha, double beta,
 static int iambideco(CSOUND *csound, AMBID *p)
 {
     int setup = (int)*p->isetup;
+    csound->Warning(csound,
+                    Str("bformdec is deprecated; use bformdec1 instead\n"));
     if (setup<0) setup = -setup;
     /* check correct number of input arguments */
-    if ((p->INOCOUNT != 5) && (p->INOCOUNT != 10) && (p->INOCOUNT != 17)) {
+    if (UNLIKELY((p->INOCOUNT != 5)  &&
+                 (p->INOCOUNT != 10) &&
+                 (p->INOCOUNT != 17))) {
       return csound->InitError(csound, Str("Wrong number of input arguments!"));
     }
 
     switch (setup) {
       case 1:
         {
-          if (p->OUTOCOUNT != 2) {
+          if (UNLIKELY(p->OUTOCOUNT != 2)) {
             return csound->InitError(csound,
                                      Str("Wrong number of output cells! "
                                          "There must be 2 output cells."));
@@ -328,14 +380,14 @@ static int iambideco(CSOUND *csound, AMBID *p)
               p->o[i] = 0.0;
               p->p[i] = 0.0;
               p->q[i] = 0.0;
-            } 
+            }
           }
           break;
         }
 
       case 2:
         {
-          if (p->OUTOCOUNT != 4) {
+          if (UNLIKELY(p->OUTOCOUNT != 4)) {
             return csound->InitError(csound,
                                      Str("Wrong number of output cells! "
                                          "There must be 4 output cells."));
@@ -374,13 +426,13 @@ static int iambideco(CSOUND *csound, AMBID *p)
               p->o[i] = 0.0;
               p->p[i] = 0.0;
               p->q[i] = 0.0;
-            } 
+            }
           }
           break;
         }
 
       case 3: {
-        if (p->OUTOCOUNT != 5) {
+        if (UNLIKELY(p->OUTOCOUNT != 5)) {
           return csound->InitError(csound,
                                    Str("Wrong number of output cells! "
                                        "There must be 5 output cells."));
@@ -422,14 +474,14 @@ static int iambideco(CSOUND *csound, AMBID *p)
             p->o[i] = 0.0;
             p->p[i] = 0.0;
             p->q[i] = 0.0;
-          } 
+          }
         }
         break;
       }
 
       case 4:
         {
-          if (p->OUTOCOUNT != 8) {
+          if (UNLIKELY(p->OUTOCOUNT != 8)) {
             return csound->InitError(csound,
                                      Str("Wrong number of output cells! "
                                          "There must be 8 output cells."));
@@ -446,15 +498,20 @@ static int iambideco(CSOUND *csound, AMBID *p)
           }
           else {
             int i;
-            static double w[] = {0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768, 0.1768};
-            static double x[] = {0.1591, 0.0659,-0.0659,-0.1591,-0.1591,-0.0659, 0.0659, 0.1591};
-            static double y[] = {0.0659, 0.1591, 0.1591, 0.0659,-0.0659,-0.1591,-0.1591,-0.0659};
+            static double w[] = {0.1768, 0.1768, 0.1768, 0.1768,
+                                 0.1768, 0.1768, 0.1768, 0.1768};
+            static double x[] = {0.1591, 0.0659, -0.0659,-0.1591,
+                                 -0.1591,-0.0659, 0.0659, 0.1591};
+            static double y[] = {0.0659,  0.1591, 0.1591, 0.0659,
+                                 -0.0659,-0.1591,-0.1591,-0.0659};
 /*             static double z[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double r[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double s[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
 /*             static double t[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double u[] = {0.0342,-0.0342,-0.0342, 0.0342, 0.0342,-0.0342,-0.0342, 0.0342};
-            static double v[] = {0.0342, 0.0342,-0.0342,-0.0342, 0.0342, 0.0342,-0.0342,-0.0342};
+            static double u[] = {0.0342,-0.0342,-0.0342, 0.0342,
+                                 0.0342,-0.0342,-0.0342, 0.0342};
+            static double v[] = {0.0342, 0.0342,-0.0342,-0.0342,
+                                 0.0342, 0.0342,-0.0342,-0.0342};
             for (i=0; i<8; i++) {
               p->w[i] = w[i];
               p->x[i] = x[i];
@@ -472,14 +529,14 @@ static int iambideco(CSOUND *csound, AMBID *p)
               p->o[i] = 0.0;
               p->p[i] = 0.0;
               p->q[i] = 0.0;
-            } 
+            }
           }
           break;
         }
 
       case 5:
         {
-          if (p->OUTOCOUNT != 8) {
+          if (UNLIKELY(p->OUTOCOUNT != 8)) {
             return csound->InitError(csound,
                                      Str("Wrong number of output cells! "
                                          "There must be 8 output cells."));
@@ -496,15 +553,22 @@ static int iambideco(CSOUND *csound, AMBID *p)
           }
           else {
             int i;
-            static double w[] = {0.1768,0.1768,0.1768,0.1768,0.1768,0.1768,0.1768,0.1768};
-            static double x[] = {0.1140, 0.1140,-0.1140,-0.1140, 0.1140, 0.1140,-0.1140,-0.1140};
-            static double y[] = {0.1140,-0.1140,-0.1140, 0.1140, 0.1140,-0.1140,-0.1140, 0.1140};
-            static double z[] = {-0.1140,-0.1140,-0.1140,-0.1140, 0.1140, 0.1140, 0.1140, 0.1140};
+            static double w[] = {0.1768,0.1768,0.1768,0.1768,
+                                 0.1768,0.1768,0.1768,0.1768};
+            static double x[] = {0.1140, 0.1140,-0.1140,-0.1140,
+                                 0.1140, 0.1140,-0.1140,-0.1140};
+            static double y[] = {0.1140,-0.1140,-0.1140, 0.1140,
+                                 0.1140,-0.1140,-0.1140, 0.1140};
+            static double z[] = {-0.1140,-0.1140,-0.1140,-0.1140,
+                                 0.1140, 0.1140, 0.1140, 0.1140};
 /*             static double r[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double s[] = {-0.0369,-0.0369, 0.0369, 0.0369, 0.0369, 0.0369,-0.0369,-0.0369};
-            static double t[] = {-0.0369, 0.0369, 0.0369,-0.0369, 0.0369,-0.0369,-0.0369, 0.0369};
+            static double s[] = {-0.0369,-0.0369, 0.0369, 0.0369,
+                                 0.0369, 0.0369,-0.0369,-0.0369};
+            static double t[] = {-0.0369, 0.0369, 0.0369,-0.0369,
+                                 0.0369,-0.0369,-0.0369, 0.0369};
 /*             static double u[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}; */
-            static double v[] = { 0.0369,-0.0369, 0.0369,-0.0369, 0.0369,-0.0369, 0.0369,-0.0369};
+            static double v[] = { 0.0369,-0.0369, 0.0369,-0.0369,
+                                  0.0369,-0.0369, 0.0369,-0.0369};
             for (i=0; i<8; i++) {
               p->w[i] = w[i];
               p->x[i] = x[i];
@@ -522,22 +586,22 @@ static int iambideco(CSOUND *csound, AMBID *p)
               p->o[i] = 0.0;
               p->p[i] = 0.0;
               p->q[i] = 0.0;
-            } 
+            }
           }
          break;
         }
       case 6: {
-        if (p->OUTOCOUNT != 5) {
+        if (UNLIKELY(p->OUTOCOUNT != 5)) {
           return csound->InitError(csound,
                                    Str("Wrong number of output cells! "
                                        "There must be 5 output cells."));
         }
                 /*  These are Wiggins' cpefficients */
-/*  L    30    {0.4724,  0.7143,  0.7258,  0.0000,  0.3456}
-    R   -30    {0.4724,  0.7143, -0.7258,  0.0000, -0.3456}
-    C   0      {0.3226,  0.7719,  0.0000,  0.0000,  0.4724}
-   LS   110    {0.9101, -0.7834,  0.9562, -0.0806,  0.0000}
-   RS   -110   {0.9101, -0.7834, -0.9562, -0.0806,  0.0000}  */
+/*  L    30°    {0.4724,  0.7143,  0.7258,  0.0000,  0.3456}
+    R   -30°    {0.4724,  0.7143, -0.7258,  0.0000, -0.3456}
+    C   0°      {0.3226,  0.7719,  0.0000,  0.0000,  0.4724}
+   LS   110°    {0.9101, -0.7834,  0.9562, -0.0806,  0.0000}
+   RS   -110°   {0.9101, -0.7834, -0.9562, -0.0806,  0.0000}  */
         {
           int i;
           static double w[] = {0.4724, 0.4724, 0.3226, 0.9101, 0.9101};
@@ -562,21 +626,22 @@ static int iambideco(CSOUND *csound, AMBID *p)
             p->o[i] = 0.0;
             p->p[i] = 0.0;
             p->q[i] = 0.0;
-          } 
+          }
         }
         break;
       }
 
       default:
-          return csound->InitError(csound, "Not supported setup number!");
+        return csound->InitError(csound, Str("Not supported setup number!"));
     }
     return OK;
 }
 
 static int aambideco(CSOUND *csound, AMBID *p)
 {
-    int nn = csound->ksmps;  /* array size from orchestra */
-    int i = 0;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i=0, n, nsmps = CS_KSMPS;
 
     /* init input array pointer 0th order */
     MYFLT *inptp_w = p->aw;
@@ -613,96 +678,54 @@ static int aambideco(CSOUND *csound, AMBID *p)
     rsltp[5] = p->m5;
     rsltp[6] = p->m6;
     rsltp[7] = p->m7;
+    if (UNLIKELY(offset)) for (i = 0; i < p->OUTOCOUNT; i++)
+                  memset(rsltp[i], '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      for (i = 0; i < p->OUTOCOUNT; i++)
+        memset(&rsltp[i][nsmps], '\0', early*sizeof(MYFLT));
+    }
     /* L = 0.5 * (0.9397*W + 0.1856*X - j*0.342*W + j*0.5099*X + 0.655*Y)
 
        R = 0.5 * (0.9397*W+ 0.1856*X + j*0.342*W - j*0.5099*X - 0.655*Y) */
     if (p->INOCOUNT == 5) {
-      do {
+      for (n=offset; n<nsmps; n++) {
         /* 1st order */
         for (i = 0; i < p->OUTOCOUNT; i++) {
           /* calculate output for every used loudspeaker */
-          *rsltp[i]++ = *inptp_w * p->w[i] + *inptp_x * p->x[i] +
-                        *inptp_y * p->y[i] + *inptp_z * p->z[i];
+          rsltp[i][n] = inptp_w[n] * p->w[i] + inptp_x[n] * p->x[i] +
+                        inptp_y[n] * p->y[i] + inptp_z[n] * p->z[i];
         }
-
-        /* increment input array pointer 0th order */
-        inptp_w++;
-
-        /* increment input array pointer 1st order */
-        inptp_x++;
-        inptp_y++;
-        inptp_z++;
-
-      } while (--nn);
+      }
     }
     else if (p->INOCOUNT == 10) {
-      do {
+      for (n=offset; n<nsmps; n++) {
         /* 2nd order */
         for (i = 0; i < p->OUTOCOUNT; i++) {
           /* calculate output for every used loudspeaker */
-          *rsltp[i]++ = *inptp_w * p->w[i] + *inptp_x * p->x[i] +
-                        *inptp_y * p->y[i] + *inptp_z * p->z[i] +
-                        *inptp_r * p->r[i] + *inptp_s * p->s[i] +
-                        *inptp_t * p->t[i] + *inptp_u * p->u[i] +
-                        *inptp_v * p->v[i];
+          rsltp[i][n] = inptp_w[n] * p->w[i] + inptp_x[n] * p->x[i] +
+                        inptp_y[n] * p->y[i] + inptp_z[n] * p->z[i] +
+                        inptp_r[n] * p->r[i] + inptp_s[n] * p->s[i] +
+                        inptp_t[n] * p->t[i] + inptp_u[n] * p->u[i] +
+                        inptp_v[n] * p->v[i];
         }
-
-        /* increment input array pointer 0th order */
-        inptp_w++;
-
-        /* increment input array pointer 1st order */
-        inptp_x++;
-        inptp_y++;
-        inptp_z++;
-
-        /* increment input array pointer 2nd order */
-        inptp_r++;
-        inptp_s++;
-        inptp_t++;
-        inptp_u++;
-        inptp_v++;
-
-      } while (--nn);
+      }
     }
     else if (p->INOCOUNT == 17) {
-      do {
+      for (n=offset; n<nsmps; n++) {
         /* 3rd order */
         for (i = 0; i < p->OUTOCOUNT; i++) {
           /* calculate output for every used loudspeaker */
-          *rsltp[i]++ = *inptp_w * p->w[i] + *inptp_x * p->x[i] +
-                        *inptp_y * p->y[i] + *inptp_z * p->z[i] + 
-                        *inptp_r * p->r[i] + *inptp_s * p->s[i] +
-                        *inptp_t * p->t[i] + *inptp_u * p->u[i] +
-                        *inptp_v * p->v[i] + *inptp_k * p->k[i] + 
-                        *inptp_l * p->l[i] + *inptp_m * p->m[i] +
-                        *inptp_n * p->n[i] + *inptp_o * p->o[i] +
-                        *inptp_p * p->p[i] + *inptp_q * p->q[i];
+          rsltp[i][n] = inptp_w[n] * p->w[i] + inptp_x[n] * p->x[i] +
+                        inptp_y[n] * p->y[i] + inptp_z[n] * p->z[i] +
+                        inptp_r[n] * p->r[i] + inptp_s[n] * p->s[i] +
+                        inptp_t[n] * p->t[i] + inptp_u[n] * p->u[i] +
+                        inptp_v[n] * p->v[i] + inptp_k[n] * p->k[i] +
+                        inptp_l[n] * p->l[i] + inptp_m[n] * p->m[i] +
+                        inptp_n[n] * p->n[i] + inptp_o[n] * p->o[i] +
+                        inptp_p[n] * p->p[i] + inptp_q[n] * p->q[i];
         }
-
-        /* increment input array pointer 0th order */
-        inptp_w++;
-
-        /* increment input array pointer 1st order */
-        inptp_x++;
-        inptp_y++;
-        inptp_z++;
-
-        /* increment input array pointer 2nd order */
-        inptp_r++;
-        inptp_s++;
-        inptp_t++;
-        inptp_u++;
-        inptp_v++;
-
-        /* increment input array pointer 3rd order */
-        inptp_k++;
-        inptp_l++;
-        inptp_m++;
-        inptp_n++;
-        inptp_o++;
-        inptp_p++;
-        inptp_q++;
-      } while (--nn);
+      }
     }
     return OK;
 }
@@ -710,9 +733,9 @@ static int aambideco(CSOUND *csound, AMBID *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-  { "bformenc", S(AMBIC), 5, "mmmmmmmmmmmmmmmm", "akkPPPP",
+  { "bformenc", S(AMBIC), _QQ, 5, "mmmmmmmmmmmmmmmm", "akkPPPP",
                             (SUBR)iambicode, NULL, (SUBR)aambicode },
-  { "bformdec", S(AMBID), 5, "mmmmmmmm", "iaaay",
+  { "bformdec", S(AMBID), _QQ, 5, "mmmmmmmm", "iaaay",
                             (SUBR)iambideco, NULL, (SUBR)aambideco }
 };
 
@@ -721,4 +744,3 @@ int ambicode_init_(CSOUND *csound)
     return csound->AppendOpcodes(csound, &(localops[0]),
                                  (int) (sizeof(localops) / sizeof(OENTRY)));
 }
-
