@@ -51,7 +51,7 @@
  * Davide Rocchesso (rocchesso@sci.univr.it) and
  * Nicola Bernardini (nicb@axnet.it)
  *
- * $Id: babo.c,v 1.25 2007/12/25 13:42:56 jpff Exp $
+ * $Id$
  *
  ***************************************************************************/
 
@@ -63,14 +63,14 @@
  */
 
 /*
- *In general, (x,y,z) are coordinates in a three-dimensional space, either
- *of the sound source or of the pickup point (we use a pair of omnidi-
- *rectional pickups aligned with the x axis).
- *When the diffusion is maximal, each row of the matrix contains a
- *maximum-length sequence of +1 and -1. When the diffusion is minimal, the
- *matrix is diagonal. The continuous control of diffusion is done by moving
- *the eigenvalues along the unit circle and taking the inverse discrete fourier
- *transform of them [2,3].
+ * In general, (x,y,z) are coordinates in a three-dimensional space, either
+ * of the sound source or of the pickup point (we use a pair of omnidi-
+ * rectional pickups aligned with the x axis).
+ * When the diffusion is maximal, each row of the matrix contains a
+ * maximum-length sequence of +1 and -1. When the diffusion is minimal, the
+ * matrix is diagonal. The continuous control of diffusion is done by moving
+ * the eigenvalues along the unit circle and taking the inverse discrete fourier
+ * transform of them [2,3].
  */
 
 /*------------------------------------------------------------------------*\
@@ -123,9 +123,11 @@ input  |    |------>|
                     Move static fn declarations out of function
  */
 
-#include "csdl.h"
+//#include "csdl.h"
+#include "csoundCore.h"
 #include "babo.h"
 #include <math.h>
+#include "interlocks.h"
 
 #if !defined(FLT_MAX)
 #define FLT_MAX         (1.0e38)
@@ -139,14 +141,6 @@ static const int sound_speed = 330;
 
 #define square(x)   ((x)*(x))
 
-#ifdef never
-static inline long
-bround(MYFLT x)
-{
-    return (long)(x >= 0 ? x + FL(0.5) : x - FL(0.5));
-}
-#endif
-
 /*
  * Memory allocation object methods
  *
@@ -159,9 +153,9 @@ BaboMemory_create(CSOUND *csound, BaboMemory *this, size_t size_in_floats)
 {
     size_t size_in_bytes = size_in_floats * sizeof(MYFLT);
 
-    csound->AuxAlloc(csound, (long) size_in_bytes, &this->memptr);
+    csound->AuxAlloc(csound, size_in_bytes, &this->memptr);
 
-    memset(this->memptr.auxp, 0, size_in_bytes);
+    //memset(this->memptr.auxp, 0, size_in_bytes);
 
     this->samples = size_in_floats;
 
@@ -200,7 +194,7 @@ static void
 _Babo_common_delay_create(CSOUND *csound, BaboDelay *this, MYFLT max_time)
 {
     size_t num_floats =
-      (size_t)MYFLT2LRND((MYFLT)ceil((double)(max_time*csound->esr)));
+      (size_t)MYFLT2LRND((MYFLT)ceil((double)(max_time*CS_ESR)));
 
     BaboMemory_create(csound, &this->core, num_floats);
 }
@@ -254,7 +248,7 @@ BaboDelay_output(const BaboDelay *this)
 static BaboTapline *
 BaboTapline_create(CSOUND *csound, BaboTapline *this, MYFLT x, MYFLT y, MYFLT z)
 {
-    MYFLT max_time = (MYFLT)(2.0 * sqrt((x*x) + (y*y) + (z*z))) / sound_speed;
+    MYFLT max_time = (FL(2.0) * SQRT((x*x) + (y*y) + (z*z))) / sound_speed;
 
     _Babo_common_delay_create(csound, (BaboDelay *) this, max_time);
 
@@ -295,12 +289,11 @@ typedef struct
  * in the first place.
  */
 /* a-rate function */
-static MYFLT BaboTapline_single_output(CSOUND *csound,
-                                       const BaboTapline *this,
+static MYFLT BaboTapline_single_output(const BaboTapline *this,
                                        const BaboTapParameter *pp)
 {
         /*
-         * the assignement right below should be really a floor(p->delay_size),
+         * the assignment right below should be really a floor(p->delay_size),
          * but apparently floor() calls are really expensive on some
          * architectures (notably Pentiums), so we do a simple cast to a
          * size_t instead. This should always work, but I cannot test it on
@@ -312,7 +305,7 @@ static MYFLT BaboTapline_single_output(CSOUND *csound,
     MYFLT fractional    = pp->delay_size - (MYFLT) delay_floor;
     MYFLT *output_floor = this->input - delay_floor;
     MYFLT *output_ceil  = this->input - delay_ceil;
-    MYFLT output = FL(0.0);
+    MYFLT output        = FL(0.0);
 
     if (output_floor <  BaboMemory_start(&this->core))
         output_floor += BaboMemory_samples(&this->core);
@@ -336,14 +329,14 @@ static inline void BaboTapline_preload_parameter(CSOUND *csound,
      *          direct_att=(1/2) when distance is 1 m
      *          direct_att=1     when distance is 0 m.
      */
-    this->delay_size    = (distance / sound_speed) * csound->esr;
+    this->delay_size    = (distance / sound_speed) * CS_ESR;
     this->attenuation   = FL(1.0) / (FL(1.0) + distance);
 }
 
 /* k-rate function */
 static BaboTaplineParameters *
 BaboTapline_precalculate_parameters(
-    CSOUND *csound, const BaboTapline *this, BaboTaplineParameters    *results,
+    CSOUND *csound, BaboTaplineParameters    *results,
     MYFLT r_x, MYFLT r_y, MYFLT r_z,    /* receiver position (i-rate) */
     MYFLT s_x, MYFLT s_y, MYFLT s_z,    /* source   position (k-rate) */
     MYFLT l_x, MYFLT l_y, MYFLT l_z)    /* room     coords   (i-rate) */
@@ -362,23 +355,23 @@ BaboTapline_precalculate_parameters(
     sqr_xy      = sqr_diff_x + sqr_diff_y;
 
     BaboTapline_preload_parameter(csound, &results->direct,
-                                  (MYFLT)sqrt(sqr_diff_x + sqr_yz));
+                                  SQRT(sqr_diff_x + sqr_yz));
 
     BaboTapline_preload_parameter(csound, &results->tap[0],
-                                  (MYFLT)sqrt(square(l_x + r_x + s_x) + sqr_yz));
+                                  SQRT(square(l_x + r_x + s_x) + sqr_yz));
     BaboTapline_preload_parameter(csound, &results->tap[1],
-                                  (MYFLT)sqrt(square(l_x - r_x - s_x) + sqr_yz));
+                                  SQRT(square(l_x - r_x - s_x) + sqr_yz));
     BaboTapline_preload_parameter(csound, &results->tap[2],
-                        (MYFLT)sqrt(sqr_xz + square(l_y - r_y - s_y)));
+                        SQRT(sqr_xz + square(l_y - r_y - s_y)));
     BaboTapline_preload_parameter(csound, &results->tap[3],
-                        (MYFLT)sqrt(sqr_xz + square(l_y + r_y + s_y)));
+                        SQRT(sqr_xz + square(l_y + r_y + s_y)));
 
     BaboTapline_preload_parameter(csound,
                                   &results->tap[4],
-                                  (MYFLT)sqrt(sqr_xy + square(l_z - r_z - s_z)));
+                                  SQRT(sqr_xy + square(l_z - r_z - s_z)));
     BaboTapline_preload_parameter(csound,
                                   &results->tap[5],
-                                  (MYFLT)sqrt(sqr_xy + square(l_z + r_z + s_z)));
+                                  SQRT(sqr_xy + square(l_z + r_z + s_z)));
 
     return results;
 }
@@ -389,10 +382,10 @@ BaboTapline_output(CSOUND *csound, const BaboTapline *this,
                    const BaboTaplineParameters *pars)
 {
     int     i;
-    MYFLT   output = BaboTapline_single_output(csound, this, &pars->direct);
+    MYFLT   output = BaboTapline_single_output(this, &pars->direct);
 
     for (i = 0; i < BABO_TAPS; ++i)
-      output  += BaboTapline_single_output(csound, this, &pars->tap[i]);
+      output  += BaboTapline_single_output(this, &pars->tap[i]);
 
     return output;
 }
@@ -404,8 +397,8 @@ BaboTapline_output(CSOUND *csound, const BaboTapline *this,
 static BaboLowPass *
 BaboLowPass_create(BaboLowPass *this, MYFLT decay, MYFLT hidecay, MYFLT norm)
 {
-    MYFLT real_decay    = (MYFLT)exp(norm * log(decay));
-    MYFLT real_hidecay  = (MYFLT)exp(norm * log(hidecay));
+    MYFLT real_decay    = EXP(norm * LOG(decay));
+    MYFLT real_hidecay  = EXP(norm * LOG(hidecay));
 
     this->a0 = (real_decay + real_hidecay) * FL(0.25);
     this->a1 = (real_decay - real_hidecay) * FL(0.5);
@@ -514,8 +507,8 @@ BaboMatrix_create_FDN(BaboMatrix *this, MYFLT diffusion)
     {
         real_X[i] = imaginary_X[i] = FL(0.0);
         arg_X[i]  = max_diffusion_eigenvalues[i] * diffusion;
-        real_X[i] = (MYFLT)cos(arg_X[i]);
-        imaginary_X[i] = (MYFLT)sin(arg_X[i]);
+        real_X[i] = COS(arg_X[i]);
+        imaginary_X[i] = SIN(arg_X[i]);
     }
 
     /*
@@ -525,8 +518,8 @@ BaboMatrix_create_FDN(BaboMatrix *this, MYFLT diffusion)
 
     for (i = 0; i < BABO_NODES; ++i)
         for (j = 0; j < BABO_NODES; ++j)
-            real_x[j] += (real_X[j] * (MYFLT)cos(_2PI_NODES*i*j)-
-                imaginary_X[j] * (MYFLT)sin(_2PI_NODES*i*j))/BABO_NODES;
+            real_x[j] += (real_X[j] * COS(_2PI_NODES*i*j)-
+                     imaginary_X[j] * SIN(_2PI_NODES*i*j))/BABO_NODES;
 
     for (i = 0; i < BABO_NODES; ++i)
         for (j = 0; j < BABO_NODES; ++j)
@@ -539,7 +532,7 @@ BaboMatrix_calculate_delays(MYFLT delay_time[], MYFLT x, MYFLT y, MYFLT z)
     int i = 0;
     MYFLT min = FL(0.0);
 
-    const static struct babo_diffusion_constants
+    static const struct babo_diffusion_constants
     {
         int x, y, z;
 
@@ -587,7 +580,7 @@ BaboMatrix_calculate_delays(MYFLT delay_time[], MYFLT x, MYFLT y, MYFLT z)
     {
         const struct babo_diffusion_constants *dbdp = &BABO_DIRECTIONS[i];
         delay_time[i] = FL(2.0) / (sound_speed *
-                        (MYFLT)sqrt(((dbdp->x/x) * (dbdp->x/x)) +
+                        SQRT(((dbdp->x/x) * (dbdp->x/x)) +
                              ((dbdp->y/y) * (dbdp->y/y)) +
                              ((dbdp->z/z) * (dbdp->z/z))));
 
@@ -715,7 +708,7 @@ resolve_defaults(BABO *p)
 static inline MYFLT
 load_value_or_default(const FUNC *table, int idx, MYFLT dEfault)
 {
-    MYFLT result = (table != (FUNC *) NULL && idx < table->flen) ?
+    MYFLT result = (table != (FUNC *) NULL && idx < (int32)table->flen) ?
                    table->ftable[idx] : dEfault;
 
     return result;
@@ -728,7 +721,7 @@ set_expert_values(CSOUND *csound, BABO *p)
     int      n      = 0;
 
     if (p->expert_values > 0)
-        ftp = csound->FTFind(csound, &(p->expert_values));
+        ftp = csound->FTnp2Find(csound, &(p->expert_values));
 
     p->decay        = load_value_or_default(ftp, n++, BABO_DEFAULT_DECAY);
     p->hidecay      = load_value_or_default(ftp, n++, BABO_DEFAULT_HIDECAY);
@@ -744,8 +737,10 @@ set_expert_values(CSOUND *csound, BABO *p)
 static void
 verify_coherence(CSOUND *csound, BABO *p)
 {
-    if (*(p->lx) <= FL(0.0) || *(p->ly) <= FL(0.0) || *(p->lz) <= FL(0.0)) {
-      csound->Die(csound, Str("Babo: resonator dimensions are incorrect "
+    if (UNLIKELY(*(p->lx) <= FL(0.0) ||
+                 *(p->ly) <= FL(0.0) ||
+                 *(p->lz) <= FL(0.0))) {
+      csound->Warning(csound, Str("Babo: resonator dimensions are incorrect "
                               "(%.1f, %.1f, %.1f)"),
                   *(p->lx), *(p->ly), *(p->lz));
     }
@@ -778,34 +773,45 @@ static int
 babo(CSOUND *csound, void *entry)
 {
     BABO    *p          = (BABO *) entry;
-    int      nsmps      = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     MYFLT   *outleft    = p->outleft,
             *outright   = p->outright,
             *input      = p->input;
 
     BaboTaplineParameters left = { {FL(0.0)}, {{FL(0.0)}} },
-                         right = { {FL(0.0)}, {{FL(0.0)}} };
+                          right = { {FL(0.0)}, {{FL(0.0)}} };
 
-    BaboTapline_precalculate_parameters(csound, &p->tapline, &left,
-        p->receiver_x - p->inter_receiver_distance,
-        p->receiver_y, p->receiver_z,
-        *(p->ksource_x), *(p->ksource_y), *(p->ksource_z),
-        *(p->lx), *(p->ly), *(p->lz));
+    BaboTapline_precalculate_parameters(csound, &left,
+                                        p->receiver_x - p->inter_receiver_distance,
+                                        p->receiver_y, p->receiver_z,
+                                        *(p->ksource_x), *(p->ksource_y),
+                                        *(p->ksource_z),
+                                        *(p->lx), *(p->ly), *(p->lz));
 
-    BaboTapline_precalculate_parameters(csound, &p->tapline, &right,
+    BaboTapline_precalculate_parameters(csound, &right,
         p->receiver_x + p->inter_receiver_distance,
         p->receiver_y, p->receiver_z,
         *(p->ksource_x), *(p->ksource_y), *(p->ksource_z),
         *(p->lx), *(p->ly), *(p->lz));
 
-    do {                        /* k-time do-while cycle                */
+    if (UNLIKELY(offset)) {
+      memset(outleft,  '\0', offset*sizeof(MYFLT));
+      memset(outright, '\0', offset*sizeof(MYFLT));
+    } if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&outleft[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&outright[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset; n<nsmps; n++) {         /* k-time cycle                */
       MYFLT  left_tapline_out        = FL(0.0),
              right_tapline_out       = FL(0.0),
              delayed_matrix_input    = FL(0.0);
       MYFLT  matrix_outputs[2]       = { FL(0.0) };
 
-      BaboTapline_input(&p->tapline, *input);
-      BaboDelay_input(&p->matrix_delay, *input);
+      BaboTapline_input(&p->tapline, input[n]);
+      BaboDelay_input(&p->matrix_delay, input[n]);
 
       left_tapline_out  = BaboTapline_output(csound, &p->tapline, &left) *
         p->early_diffuse;
@@ -818,21 +824,16 @@ babo(CSOUND *csound, void *entry)
       BaboMatrix_output(&p->matrix, matrix_outputs, delayed_matrix_input,
                         p->diffusion_coeff);
 
-      *outleft  = left_tapline_out  + matrix_outputs[0];
-      *outright = right_tapline_out + matrix_outputs[1];
-
-      ++input;
-      ++outleft;
-      ++outright;
-    } while (--nsmps);
+      outleft[n]  = left_tapline_out  + matrix_outputs[0];
+      outright[n] = right_tapline_out + matrix_outputs[1];
+    }
     return OK;
 }
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-{ "babo",   S(BABO), 5, "aa", "akkkiiijj",(SUBR)baboset, NULL, (SUBR)babo   }
+static OENTRY babo_localops[] = {
+  { "babo",   S(BABO), TR, 5, "aa", "akkkiiijj",(SUBR)baboset, NULL, (SUBR)babo   },
 };
 
-LINKAGE
-
+LINKAGE_BUILTIN(babo_localops)
