@@ -32,8 +32,9 @@
 /* bilinear z-transform.                                       */
 /* April/May 2002 by Erik Spjut                                */
 /***************************************************************/
-#include "csdl.h"
+
 #include <math.h>
+#include "stdopcod.h"
 #include "clfilt.h"
 
 static int clfiltset(CSOUND *csound, CLFILT *p)
@@ -48,23 +49,23 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
     cotfpi = FL(1.0)/tanfpi;
     cotfpi2 = cotfpi*cotfpi;
     p->ilohi = (int)*p->lohi;
-    if ((p->ilohi < 0) || (p->ilohi > 1)) {
+    if (UNLIKELY((p->ilohi < 0) || (p->ilohi > 1))) {
       return csound->InitError(csound,
                                Str("filter type not lowpass or "
                                    "highpass in clfilt"));
     }
     p->ikind = (int)*p->kind;
-    if ((p->ikind < 0) || (p->ikind > 3)) {
+    if (UNLIKELY((p->ikind < 0) || (p->ikind > 3))) {
       return csound->InitError(csound,
                                Str("filter kind, %d, out of range in clfilt"),
                                p->ikind);
     }
-    if ((*p->npol < FL(1.0)) || (*p->npol > 2*CL_LIM)) {
+    if (UNLIKELY((*p->npol < FL(1.0)) || (*p->npol > 2*CL_LIM))) {
       return csound->InitError(csound, Str("number of poles, %f, out of range "
                                            "in clfilt"), *p->npol);
 /*       p->nsec = nsec = 1; */
     }
-    else if (fmod((double)*p->npol,2.0) != 0.0) {
+    else if (UNLIKELY(fmod((double)*p->npol,2.0) != 0.0)) {
       p->nsec = nsec = (int)((*p->npol+FL(1.0))*FL(0.5));
       csound->Warning(csound, Str("odd number of poles chosen in clfilt,"
                                   " rounded to %d"), 2*nsec);
@@ -89,12 +90,12 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
         }
         break;
       case 1: /* Lowpass Chebyshev type I */
-        if ( pbr < FL(0.0) ) {
+        if (UNLIKELY( pbr < FL(0.0) )) {
           pbr = -pbr;
           csound->Warning(csound, Str("passband ripple must be positive "
                                       "in clfilt. Set to %f"), pbr);
         }
-        else if ( pbr == FL(0.0) ) {
+        else if (UNLIKELY( pbr == FL(0.0) )) {
           pbr = FL(1.0);
           csound->Warning(csound, Str("passband ripple must be non-zero in "
                                       "clfilt. Set to %f"), pbr);
@@ -136,12 +137,12 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
         if ( sbr == FL(1.0) ) {
           sbr = FL(-60.0);
         }
-        else if ( sbr > FL(0.0) ) {
+        else if (UNLIKELY( sbr > FL(0.0) )) {
           sbr = -sbr;
           csound->Warning(csound, Str("stopband attenuation must be negative "
                                       "in clfilt. Set to %f"), sbr);
         }
-        else if ( sbr == FL(0.0) ) {
+        else if (UNLIKELY( sbr == FL(0.0) )) {
           sbr = FL(-60.0);
           csound->Warning(csound, Str("stopband attenuation must be non-zero "
                                       "in clfilt. Set to %f"), sbr);
@@ -191,13 +192,13 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
         }
         break;
       case 1: /* Highpass Chebyshev type I */
-        if ( pbr < FL(0.0) ) {
+        if (UNLIKELY( pbr < FL(0.0) )) {
           pbr = -pbr;
           csound->Warning(csound,
                           Str("passband ripple must be positive in clfilt. "
                               "Set to %f"), pbr);
         }
-        else if ( pbr == FL(0.0) ) {
+        else if (UNLIKELY( pbr == FL(0.0) )) {
           pbr = FL(1.0);
           csound->Warning(csound, Str("passband ripple must be non-zero "
                                       "in clfilt. Set to %f"), pbr);
@@ -239,12 +240,12 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
         if ( sbr == FL(1.0) ) {
           sbr = FL(-60.0);
         }
-        else if ( sbr > FL(0.0) ) {
+        else if (UNLIKELY( sbr > FL(0.0) )) {
           sbr = -sbr;
           csound->Warning(csound, Str("stopband attenuation must be negative "
                                       "in clfilt. Set to %f"), sbr);
         }
-        else if ( sbr == FL(0.0) ) {
+        else if (UNLIKELY( sbr == FL(0.0) )) {
           sbr = FL(-60.0);
           csound->Warning(csound, Str("stopband attenuation must be non-zero "
                                       "in clfilt. Set to %f"), sbr);
@@ -289,7 +290,9 @@ static int clfiltset(CSOUND *csound, CLFILT *p)
 
 static int clfilt(CSOUND *csound, CLFILT *p)
 {
-    int n, nsmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     int m, nsec;
     MYFLT *out, *in;
     MYFLT xn[CL_LIM+1], yn[CL_LIM];
@@ -338,11 +341,12 @@ static int clfilt(CSOUND *csound, CLFILT *p)
           }
           break;
         case 3: /* Lowpass Elliptical */
-          return csound->PerfError(csound, Str("Lowpass Elliptical "
+          return csound->PerfError(csound, p->h.insdshead,
+                                   Str("Lowpass Elliptical "
                                                "not implemented yet. Sorry!"));
           break;
         default: /* Because of earlier contditionals, should never get here. */
-          return csound->PerfError(csound,
+          return csound->PerfError(csound, p->h.insdshead,
                                    Str("code error, ikind out of range"));
         }
         break;
@@ -375,22 +379,28 @@ static int clfilt(CSOUND *csound, CLFILT *p)
           }
           break;
         case 3: /* Highpass Elliptical */
-          return csound->PerfError(csound, Str("Highpass Elliptical "
-                                               "not implemented yet. Sorry!"));
+          return csound->PerfError(csound, p->h.insdshead,
+                                   Str("Highpass Elliptical "
+                                       "not implemented yet. Sorry!"));
           break;
         default: /* Because of earlier contditionals, should never get here. */
-          return csound->PerfError(csound,
+          return csound->PerfError(csound, p->h.insdshead,
                                    Str("code error, ikind out of range"));
         }
         break;
       default: /* Because of earlier conditionals, should never get here. */
-        return csound->PerfError(csound, Str("code error, ihilo out of range"));
+        return csound->PerfError(csound, p->h.insdshead,
+                                 Str("code error, ihilo out of range"));
       }
     }
-    nsmps = csound->ksmps;
     in   = p->in;
     out  = p->out;
-    for (n=0; n<nsmps; n++) {
+    if (UNLIKELY(offset)) memset(out, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&out[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n=offset; n<nsmps; n++) {
       xn[0] = in[n];
       for (m=0;m<=nsec-1;m++) {
         yn[m] = (b0[m]*xn[m] + b1[m]*xnm1[m] + b2[m]*xnm2[m] -
@@ -413,7 +423,7 @@ static int clfilt(CSOUND *csound, CLFILT *p)
 #define S sizeof
 
 static OENTRY localops[] = {
-{ "clfilt", S(CLFILT),  5, "a", "akiioppo",(SUBR)clfiltset, NULL, (SUBR)clfilt },
+{ "clfilt", S(CLFILT),  0, 5, "a", "akiioppo",(SUBR)clfiltset, NULL, (SUBR)clfilt },
 };
 
 int clfilt_init_(CSOUND *csound)
