@@ -38,12 +38,14 @@
 #include <pthread.h>
 #include "faust/dsp/llvm-dsp.h"
 #include "faust/gui/UI.h"
+#include <string>
 #if defined(MACOSX) || defined(linux) || defined(HAIKU)
 #include <unistd.h>
 #endif
 
 #define MAXARG 40
 
+
 /**
  * Faust controls class for Csound
  *
@@ -87,6 +89,9 @@ public:
   virtual void openVerticalBox(const char* label) {};
   virtual void closeBox() {};
 
+  virtual void addSoundfile(const char* label, const char* filename,
+                            Soundfile** sf_zone) {};
+
   virtual void addButton(const char* label, FAUSTFLOAT* zone) {
     addctl(label, zone, 0, 0);
   }
@@ -420,7 +425,7 @@ int init_faustaudio(CSOUND *csound, faustgen *p){
     return csound->InitError(csound,
                              Str("no factory available\n"));
   fobj = *fobjp;
-  while(fobj->cnt != factory) {
+  while((int) fobj->cnt != factory) {
     fobj = fobj->nxt;
     if(fobj == NULL)
       return csound->InitError(csound,
@@ -481,7 +486,7 @@ int init_faustaudio(CSOUND *csound, faustgen *p){
   /* memory for sampAccurate offsets */
   csound->GetOParms(csound, &parms);
   if(parms.sampleAccurate){
-    int size;
+    size_t size;
     size = p->engine->getNumInputs()*sizeof(MYFLT *);
     if(p->memin.auxp == NULL ||
        p->memin.size < size)
@@ -502,7 +507,6 @@ void *init_faustgen_thread(void *pp){
   faustgen *p = ((hdata2 *) pp)->p;
   OPARMS parms;
   std::string err_msg;
-  int size;
   int argc = 3;
   const char* argv[argc];
   faustobj  **pfdsp, *fdsp;
@@ -587,7 +591,7 @@ void *init_faustgen_thread(void *pp){
   /* memory for sampAccurate offsets */
   csound->GetOParms(csound, &parms);
   if(parms.sampleAccurate){
-    int size;
+    size_t size;
     size = p->engine->getNumInputs()*sizeof(MYFLT *);
     if(p->memin.auxp == NULL ||
        p->memin.size < size)
@@ -688,7 +692,7 @@ int init_faustctl(CSOUND *csound, faustctl *p){
                              Str("no dsp instances available\n"));
   fobj = *fobjp;
 
-  while(fobj->cnt != instance) {
+  while((int) fobj->cnt != instance) {
     fobj = fobj->nxt;
     if(fobj == NULL)
       return csound->InitError(csound,
