@@ -68,13 +68,13 @@ static int ftable_delete(CSOUND *csound, void *p)
     if (UNLIKELY(err != OK))
       csound->ErrorMsg(csound, Str("Error deleting ftable %d"),
                                ((FTDELETE*) p)->fno);
-    free(p);
+    csound->Free(csound, p);
     return err;
 }
 
 static int register_ftable_delete(CSOUND *csound, void *p, int tableNum)
 {
-    FTDELETE  *op = (FTDELETE*) calloc((size_t) 1, sizeof(FTDELETE));
+  FTDELETE  *op = (FTDELETE*) csound->Calloc(csound, sizeof(FTDELETE));
     if (UNLIKELY(op == NULL))
       return csound->InitError(csound, Str("memory allocation failure"));
     op->h.insdshead = ((OPDS*) p)->insdshead;
@@ -83,7 +83,6 @@ static int register_ftable_delete(CSOUND *csound, void *p, int tableNum)
 }
 
 /* set up and call any GEN routine */
-
 static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
 {
     MYFLT   *fp;
@@ -92,7 +91,7 @@ static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
     int     n;
 
     *p->ifno = FL(0.0);
-    ftevt =(EVTBLK*) malloc(sizeof(EVTBLK)); /* Can use malloc direct as local */
+    ftevt =(EVTBLK*) csound->Malloc(csound, sizeof(EVTBLK));
     ftevt->opcod = 'f';
     ftevt->strarg = NULL;
     fp = &ftevt->p[0];
@@ -108,12 +107,13 @@ static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
         while (named) {
           if (strcmp(named->name, ((STRINGDAT *) p->p4)->data) == 0) {
             /* Look up by name */
-           break;
+            fp[4] = named->genum;
+            break;
           }
           named = named->next;                            /*  and round again   */
         }
         if (UNLIKELY(named == NULL)) {
-          free(ftevt);
+          csound->Free(csound,ftevt);
           return csound->InitError(csound,
                                    Str("Named gen \"%s\" not defined"),
                                    (char *)p->p4);
@@ -135,7 +135,7 @@ static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
           ftevt->strarg = ((STRINGDAT *) p->p5)->data;
           break;
         default:
-          free(ftevt);
+          csound->Free(csound, ftevt);
           return csound->InitError(csound, Str("ftgen string arg not allowed"));
         }
       }
@@ -153,7 +153,7 @@ static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
       } while (--n);
     }
     n = csound->hfgens(csound, &ftp, ftevt, 1);         /* call the fgen */
-    free(ftevt);
+    csound->Free(csound, ftevt);
     if (UNLIKELY(n != 0))
       return csound->InitError(csound, Str("ftgen error"));
     if (ftp != NULL)
@@ -162,19 +162,19 @@ static int ftgen_(CSOUND *csound, FTGEN *p, int istring1, int istring2)
 }
 
 static int ftgen(CSOUND *csound, FTGEN *p) {
-  return ftgen_(csound,p,0,0);
+    return ftgen_(csound,p,0,0);
 }
 
 static int ftgen_S(CSOUND *csound, FTGEN *p) {
-  return ftgen_(csound,p,1,0);
+    return ftgen_(csound,p,1,0);
 }
 
 static int ftgen_iS(CSOUND *csound, FTGEN *p) {
-  return ftgen_(csound,p,0,1);
+    return ftgen_(csound,p,0,1);
 }
 
 static int ftgen_SS(CSOUND *csound, FTGEN *p) {
-  return ftgen_(csound,p,1,1);
+    return ftgen_(csound,p,1,1);
 }
 
 static int ftgentmp(CSOUND *csound, FTGEN *p)
@@ -204,6 +204,32 @@ static int ftgentmp_S(CSOUND *csound, FTGEN *p)
     return register_ftable_delete(csound, p, fno);
 }
 
+static int ftgentmp_Si(CSOUND *csound, FTGEN *p)
+{
+    int   p1, fno;
+
+    if (UNLIKELY(ftgen_(csound, p,1,0) != OK))
+      return NOTOK;
+    p1 = (int) MYFLT2LRND(*p->p1);
+    if (p1)
+      return OK;
+    fno = (int) MYFLT2LRND(*p->ifno);
+    return register_ftable_delete(csound, p, fno);
+}
+
+static int ftgentmp_SS(CSOUND *csound, FTGEN *p)
+{
+    int   p1, fno;
+
+    if (UNLIKELY(ftgen_(csound, p,1,1) != OK))
+      return NOTOK;
+    p1 = (int) MYFLT2LRND(*p->p1);
+    if (p1)
+      return OK;
+    fno = (int) MYFLT2LRND(*p->ifno);
+    return register_ftable_delete(csound, p, fno);
+}
+
 static int ftfree(CSOUND *csound, FTFREE *p)
 {
     int fno = (int) MYFLT2LRND(*p->iftno);
@@ -273,8 +299,11 @@ static int ftload_(CSOUND *csound, FTLOAD *p, int istring)
         if (UNLIKELY(csound->FTAlloc(csound, fno, (int) header.flen) != 0))
           goto err;
         ftp = ft_func(csound, &fno_f);
+        // Do we need to check value of ftp->fflen? #27323
+        if (ftp->flen > 0x40000000)
+          return csound->InitError(csound,Str("table length too long"));
         memcpy(ftp, &header, sizeof(FUNC) - sizeof(MYFLT*) - SSTRSIZ);
-        memset(ftp->ftable, 0, sizeof(MYFLT) * (ftp->flen + 1));
+        memset(ftp->ftable, 0, sizeof(MYFLT) * ((uint64_t) ftp->flen + 1));
         n = fread(ftp->ftable, sizeof(MYFLT), ftp->flen + 1l, file);
         if (UNLIKELY(n!=ftp->flen + 1)) goto err4;
         /* ***** Need to do byte order here ***** */
@@ -587,6 +616,69 @@ static int ftsave_kS(CSOUND *csound, FTLOAD_K *p)
     return OK;
 }
 
+static int ftgen_list(CSOUND *csound, FTGEN *p, int istring)
+{
+    MYFLT   *fp;
+    FUNC    *ftp;
+    EVTBLK  *ftevt;
+    int     n;
+
+    *p->ifno = FL(0.0);
+    ftevt =(EVTBLK*) csound->Malloc(csound, sizeof(EVTBLK));
+    ftevt->opcod = 'f';
+    ftevt->strarg = NULL;
+    fp = &ftevt->p[0];
+    fp[0] = FL(0.0);
+    fp[1] = *p->p1;                                     /* copy p1 - p5 */
+    fp[2] = ftevt->p2orig = FL(0.0);                    /* force time 0 */
+    fp[3] = ftevt->p3orig = *p->p3;
+    fp[4] = *p->p4;
+
+
+      if (istring) {              /* Named gen */
+        NAMEDGEN *named = (NAMEDGEN*) csound->GetNamedGens(csound);
+        while (named) {
+          if (strcmp(named->name, ((STRINGDAT *) p->p4)->data) == 0) {
+            /* Look up by name */
+            fp[4] = named->genum;
+           break;
+          }
+          named = named->next;                            /*  and round again   */
+        }
+        if (UNLIKELY(named == NULL)) {
+          csound->Free(csound,ftevt);
+          return csound->InitError(csound,
+                                   Str("Named gen \"%s\" not defined"),
+                                   (char *)p->p4);
+        }
+        else fp[4] = named->genum;
+      }
+
+      ARRAYDAT *array = (ARRAYDAT*) (p->p5);
+      n = array->sizes[0];
+      ftevt->pcnt = (int16) n+4;
+      int i = 0;
+      memcpy(&fp[5], array->data, n*sizeof(MYFLT));
+      while(i < n){
+        i++;
+      }
+      n = csound->hfgens(csound, &ftp, ftevt, 1);         /* call the fgen */
+     csound->Free(csound,ftevt);
+     if (UNLIKELY(n != 0))
+       return csound->InitError(csound, Str("ftgen error"));
+     if (ftp != NULL)
+       *p->ifno = (MYFLT) ftp->fno;                      /* record the fno */
+    return OK;
+}
+
+static int ftgen_list_S(CSOUND *csound, FTGEN *p){
+    return ftgen_list(csound,p,1);
+}
+
+static int ftgen_list_i(CSOUND *csound, FTGEN *p){
+    return ftgen_list(csound,p,0);
+}
+
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
@@ -594,8 +686,12 @@ static OENTRY localops[] = {
   { "ftgen.S",    S(FTGEN),   TW, 1,  "i",  "iiiSim", (SUBR) ftgen_S, NULL, NULL  },
   { "ftgen.iS",    S(FTGEN),  TW, 1,  "i",  "iiiiSm", (SUBR) ftgen_iS, NULL, NULL },
   { "ftgen.SS",    S(FTGEN),  TW, 1,  "i",  "iiiSSm", (SUBR) ftgen_SS, NULL, NULL },
+  { "ftgen",    S(FTGEN),     TW, 1,  "i",  "iiiii[]", (SUBR) ftgen_list_i, NULL  },
+  { "ftgen",    S(FTGEN),     TW, 1,  "i",  "iiiSi[]", (SUBR) ftgen_list_S, NULL  },
   { "ftgentmp.i", S(FTGEN),   TW, 1,  "i",  "iiiiim", (SUBR) ftgentmp, NULL, NULL },
   { "ftgentmp.iS", S(FTGEN),  TW, 1,  "i",  "iiiiSm", (SUBR) ftgentmp_S, NULL,NULL},
+  { "ftgentmp.Si", S(FTGEN),  TW, 1,  "i",  "iiiSim", (SUBR) ftgentmp_Si,NULL,NULL},
+  { "ftgentmp.SS", S(FTGEN),  TW, 1,  "i",  "iiiSSm", (SUBR) ftgentmp_SS,NULL,NULL},
   { "ftfree",   S(FTFREE),    TW, 1,  "",   "ii",     (SUBR) ftfree, NULL, NULL   },
   { "ftsave",   S(FTLOAD),    TR, 1,  "",   "iim",    (SUBR) ftsave, NULL, NULL   },
   { "ftsave.S",   S(FTLOAD),  TR, 1,  "",   "Sim",    (SUBR) ftsave_S, NULL, NULL },
