@@ -43,7 +43,7 @@ typedef struct {
 {                                                                       \
     unsigned char chan = p->slchan = (unsigned char)((*p->ichan)-1);    \
     char sbuf[120];                                                     \
-    if (chan  > 15)  {                                                  \
+    if (UNLIKELY(chan  > 15))  {                                        \
       return csound->InitError(csound, Str("illegal channel"));         \
     }                                                                   \
     else {                                                              \
@@ -55,14 +55,14 @@ typedef struct {
         FUNC *outftp, **ftp = p->ftp;                                   \
         MYFLT *chanblock = (MYFLT *)  csound->m_chnbp[chan]->ctl_val;   \
                                                                         \
-        if((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)     \
+        if ((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)    \
           p->outTable = outftp->ftable;                                 \
         while (j < 8) {                                                 \
             int t = (int) *sld->ifn;                                    \
             *slnum = (unsigned char) *sld->ictlno;                      \
             value=*sld->initvalue;                                      \
                                                                         \
-            if (*slnum > 127) {                                         \
+            if (UNLIKELY(*slnum > 127)) {                               \
               snprintf(sbuf, 120,                                       \
                         Str("illegal control number at position n.%d"), \
                         j);                                             \
@@ -72,7 +72,7 @@ typedef struct {
             *min=*sld->imin;                                            \
             *max=*sld->imax;                                            \
             if (t !=0  && t != -1) {           /*table indexing */      \
-              if (value >= 1 || value < 0) {                            \
+              if (UNLIKELY(value >= 1 || value < 0)) {                  \
                 snprintf(sbuf, 120,                                     \
                          Str("sliderXtable: illegal initvalue at "      \
                                   "position %d.  When using table "     \
@@ -82,7 +82,7 @@ typedef struct {
                 break;                                                  \
               }                                                         \
             }                                                           \
-            else if (value < *min || value > *max ) {                   \
+            else if (UNLIKELY(value < *min || value > *max )) {         \
               snprintf(sbuf, 120,                                       \
                       Str("illegal initvalue at position n.%d"), j);    \
               return csound->InitError(csound, "%s", sbuf);             \
@@ -94,7 +94,7 @@ typedef struct {
               value =  (*sld->initvalue - *min) / (*max - *min);        \
               break;                                                    \
             case -1: /* EXPONENTIAL */                                  \
-              if (*min == 0 || *max == 0) {                             \
+              if (UNLIKELY(*min == 0 || *max == 0)) {                   \
                 return csound->InitError(csound,                        \
                                          Str("sliderXtable: zero is "   \
                                              "illegal in exponential "  \
@@ -253,7 +253,7 @@ static int sliderTable64(CSOUND *csound, SLIDER64t *p) /* GAB */
   {                                                                     \
     unsigned char chan = p->slchan = (unsigned char)((*p->ichan)-1);    \
     char sbuf[120];                                                     \
-    if (chan  > 15)  {                                                  \
+    if (UNLIKELY(chan  > 15))  {                                        \
       return csound->InitError(csound, Str("illegal channel"));         \
     }                                                                   \
     {                                                                   \
@@ -269,24 +269,24 @@ static int sliderTable64(CSOUND *csound, SLIDER64t *p) /* GAB */
       MYFLT *yt1 = p->yt1, *c1=p->c1, *c2=p->c2;                        \
                                                                         \
                                                                         \
-      if((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)          \
+      if((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)       \
         p->outTable = outftp->ftable;                                   \
       while (j < n) {                                                   \
         int t = (int) *sld->ifn;                                        \
         *slnum = (unsigned char) *sld->ictlno;                          \
         value=*sld->initvalue;                                          \
                                                                         \
-        if (*slnum > 127) {                                             \
+        if (UNLIKELY(*slnum > 127)) {                                   \
           snprintf(sbuf, 120,                                           \
                   Str("illegal control number at position n.%d"), j);   \
-          return csound->InitError(csound, "%s", sbuf);                       \
+          return csound->InitError(csound, "%s", sbuf);                 \
           break;                                                        \
         }                                                               \
-        if (value < (*min=*sld->imin) ||                                \
-            value > (*max=*sld->imax) ) {                               \
+        if (UNLIKELY(value < (*min=*sld->imin) ||                       \
+                     value > (*max=*sld->imax) )) {                     \
           snprintf(sbuf, 120,                                           \
                   Str("illegal initvalue at position n.%d"), j);        \
-          return csound->InitError(csound, "%s", sbuf);                       \
+          return csound->InitError(csound, "%s", sbuf);                 \
           break;                                                        \
         }                                                               \
                                                                         \
@@ -312,19 +312,19 @@ static int sliderTable64(CSOUND *csound, SLIDER64t *p) /* GAB */
           value = value; /* unchanged, value must be in the 0 to 1 range, */ \
           /* representing the phase of the table */                     \
           if (*sld->ifn > 0)   *ftp = csound->FTnp2Find(csound, sld->ifn); \
-          if (value >= 1 || value < 0) {                                \
+          if (UNLIKELY(value >= 1 || value < 0)) {                      \
             snprintf(sbuf, 120,                                         \
                     Str("sliderXtable: illegal initvalue at "           \
                               "position %d. When using table indexing," \
                               " the init range is 0 to 1"), j);         \
-            return csound->InitError(csound, "%s", sbuf);                     \
+            return csound->InitError(csound, "%s", sbuf);               \
           }                                                             \
         }                                                               \
         chanblock[*slnum++] =  (MYFLT)((int)(value * f7bit + FL(0.5))); \
         /*----- init filtering coeffs*/                                 \
         *yt1++ = FL(0.0);                                               \
         b = (MYFLT)(2.0 - cos((double)(*(sld)->ihp *                    \
-                              csound->tpidsr * CS_KSMPS)));        \
+                              csound->tpidsr * CS_KSMPS)));             \
         *c2 = (MYFLT)(b - sqrt((double)(b * b - FL(1.0))));             \
         *c1++ = FL(1.0) - *c2++;                                        \
                                                                         \
@@ -509,8 +509,8 @@ static int sliderKawai_i(CSOUND *csound, SLIDERKAWAI *p)
     MYFLT *min = p->min, *max= p->max;
     FUNC **ftp = p->ftp;
     do  {
-      if ((value=*sld->initvalue) < (*min=*sld->imin) ||
-          value > (*max=*sld->imax) ) {
+      if (UNLIKELY((value=*sld->initvalue) < (*min=*sld->imin) ||
+                   value > (*max=*sld->imax) )) {
         snprintf(sbuf, 120, Str("illegal initvalue at position n.%d"), j);
         return csound->InitError(csound, "%s", sbuf);
       }
@@ -571,7 +571,7 @@ static int ctrl7a_set(CSOUND *csound, CTRL7a *p)
     else p->ctlno = ctlno;
 
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = 0;  /* invalid ftable */
       else p->flag= 1;
     }
