@@ -75,38 +75,44 @@
   row (l->r t->b) so a pixel value in imageData is located at: (w*y+x)*3.
 */
 
+/* #undef CS_KSMPS */
+/* #define CS_KSMPS     (csound->GetKsmps(csound)) */
+
 static Image * __doOpenImage(char * filename, CSOUND *csound)
 {
 #ifdef USE_LIBPNG
+#define HS (8)
     FILE *fp;
     void *fd;
-    const int hs = 8;
-    unsigned char header[8];
+    unsigned char header[HS];
     png_structp png_ptr;
     png_infop info_ptr;
-    png_infop end_ptr;
+    /* png_infop end_ptr; */
     int is_png;
-    unsigned long width, height, rowbytes;
+    png_uint_32 width, height, rowbytes;
     int bit_depth;
     int color_type;
     unsigned char *image_data;
     png_bytepp row_pointers;
-    int i;
+    unsigned int i;
 
     Image *img;
 
     fd = csound->FileOpen2(csound, &fp, CSFILE_STD, filename, "rb",
                            "SFDIR;SSDIR", CSFTYPE_IMAGE_PNG, 0);
-    if (fd == NULL) {
+    if (UNLIKELY(fd == NULL)) {
       csound->InitError(csound,
                         Str("imageload: cannot open image %s.\n"), filename);
       return NULL;
     }
 
-    fread(header, 1, hs, fp);
-    is_png = !png_sig_cmp(header, 0, hs);
+    if (UNLIKELY(HS!=fread(header, 1, HS, fp)))
+      csound->InitError(csound,
+                        Str("imageload: file %s is not in PNG format.\n"),
+                        filename);
+    is_png = !png_sig_cmp(header, 0, HS);
 
-    if (!is_png) {
+    if (UNLIKELY(!is_png)) {
       csound->InitError(csound,
                         Str("imageload: file %s is not in PNG format.\n"),
                         filename);
@@ -115,34 +121,36 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
     }
 
     png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
-    if (!png_ptr) {
+    if (UNLIKELY(!png_ptr)) {
       csound->InitError(csound, Str("imageload: out of memory.\n"));
       csound->FileClose(csound, fd);
       return NULL;
     }
     info_ptr = png_create_info_struct(png_ptr);
-    if (!info_ptr) {
+    if (UNLIKELY(!info_ptr)) {
       png_destroy_read_struct(&png_ptr, (png_infopp) NULL, (png_infopp) NULL);
       csound->InitError(csound, Str("imageload: out of memory.\n"));
       csound->FileClose(csound, fd);
       return NULL;
     }
 
-    end_ptr = png_create_info_struct(png_ptr);
-    if (!end_ptr) {
-      png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL);
-      csound->InitError(csound, Str("imageload: out of memory.\n"));
-      csound->FileClose(csound, fd);
-      return NULL;
-    }
+    /* end_ptr = png_create_info_struct(png_ptr); */
+    /* if (UNLIKELY(!end_ptr)) { */
+    /*   png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL); */
+    /*   csound->InitError(csound, Str("imageload: out of memory.\n")); */
+    /*   csound->FileClose(csound, fd); */
+    /*   return NULL; */
+    /* } */
 
     png_init_io(png_ptr, fp);
-    png_set_sig_bytes(png_ptr, hs);
+    png_set_sig_bytes(png_ptr, HS);
 
     png_read_info(png_ptr, info_ptr);
-    png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
-                 &color_type, NULL, NULL, NULL);
+    {
 
+      png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
+                   &color_type, NULL, NULL, NULL);
+    }
     if (color_type & PNG_COLOR_MASK_ALPHA)
       png_set_strip_alpha(png_ptr);
     if (bit_depth == 16)
@@ -158,16 +166,17 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
     png_read_update_info(png_ptr, info_ptr);
     rowbytes = png_get_rowbytes(png_ptr, info_ptr);
 
-    if ((image_data = (unsigned char *) malloc(rowbytes * height))==NULL) {
+    if (UNLIKELY((image_data =
+                 (unsigned char *)csound->Malloc(csound,rowbytes*height))==NULL)) {
       png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
       csound->InitError(csound, Str("imageload: out of memory.\n"));
       return NULL;
     }
 
-    row_pointers = (png_bytepp)malloc(height*sizeof(png_bytep));
-    if (row_pointers == NULL) {
+    row_pointers = (png_bytepp) csound->Malloc(csound, height*sizeof(png_bytep));
+    if (UNLIKELY(row_pointers == NULL)) {
       png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-      free(image_data);
+      csound->Free(csound,image_data);
       image_data = NULL;
       csound->InitError(csound, Str("imageload: out of memory.\n"));
       return NULL;
@@ -177,12 +186,13 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
       row_pointers[i] = image_data + i*rowbytes;
 
     png_read_image(png_ptr, row_pointers);
-    free(row_pointers);
+    csound->Free(csound,row_pointers);
     png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
     csound->FileClose(csound, fd);
 
-    img = malloc(sizeof(Image));
-    if (!img) {
+    img = csound->Malloc(csound, sizeof(Image));
+    if (UNLIKELY(!img)) {
+      csound->Free(csound,image_data);
       csound->InitError(csound, Str("imageload: out of memory.\n"));
       return NULL;
     }
@@ -205,11 +215,11 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
     id=Imlib_init(disp);
     im=Imlib_load_image(id, filename);
 
-    img = malloc(sizeof(Image));
+    img = csound->Malloc(csound, sizeof(Image));
     img->w = im->rgb_width;
     img->h = im->rgb_height;
     datasize = img->w*img->h*3 * sizeof(unsigned char);
-    img->imageData = malloc(datasize);
+    img->imageData = csound->Malloc(csound, datasize);
     memcpy(img->imageData, im->rgb_data, datasize);
 
     return img;
@@ -217,37 +227,37 @@ static Image * __doOpenImage(char * filename, CSOUND *csound)
 
     /* SDL */
 /*  Image *img;
-  size_t datasize;
-  SDL_Surface *srfc;
-  int x,y;
-  int bpp;
-  int indcount = 0;
-  Uint32 *pixel;
-  Uint8 r, g, b;
+    size_t datasize;
+    SDL_Surface *srfc;
+    int x,y;
+    int bpp;
+    int indcount = 0;
+    Uint32 *pixel;
+    Uint8 r, g, b;
 
-  srfc = IMG_Load(filename);
-  if(srfc) {
+    srfc = IMG_Load(filename);
+    if (srfc) {
         SDL_LockSurface(srfc);
-        img = malloc(sizeof(Image));
+        img = csound->Malloc(csound, sizeof(Image));
         img->w = srfc->w;
         img->h = srfc->h;
         bpp = srfc->format->BitsPerPixel;
 
         datasize = img->w*img->h*3 * sizeof(unsigned char);
-        img->imageData = malloc(datasize);
+        img->imageData = csound->Malloc(csound, datasize);
 
-        for(y = 0; y < img->h; y++){
-                for(x = 0; x < img->w; x++){
-                        if (bpp<=8) //need to test on other platforms
-                                pixel = srfc->pixels + y * srfc->pitch + x * bpp;
-                        else
-                                pixel = srfc->pixels + y * srfc->pitch + x * bpp / 8;
-                        SDL_GetRGB(*pixel,srfc->format, &r, &g, &b);
-                        img->imageData[indcount]= r;
-                        img->imageData[indcount+1]= g;
-                        img->imageData[indcount+2]= b;
-                        indcount += 3;
-                }
+        for(y = 0; y < img->h; y++) {
+            for(x = 0; x < img->w; x++) {
+                if (bpp<=8) //need to test on other platforms
+                    pixel = srfc->pixels + y * srfc->pitch + x * bpp;
+                else
+                    pixel = srfc->pixels + y * srfc->pitch + x * bpp / 8;
+                SDL_GetRGB(*pixel,srfc->format, &r, &g, &b);
+                img->imageData[indcount]= r;
+                img->imageData[indcount+1]= g;
+                img->imageData[indcount+2]= b;
+                indcount += 3;
+            }
         }
         SDL_UnlockSurface(srfc);
         SDL_FreeSurface ( srfc );
@@ -270,32 +280,30 @@ static int __doSaveImage(Image *image, char *filename, CSOUND *csound)
     unsigned rowbytes;
     int i;
 
-    FILE *fp; 
+    FILE *fp;
     void *fd;
-    
+
     fd = csound->FileOpen2(csound, &fp, CSFILE_STD, filename, "wb",
                            "", CSFTYPE_IMAGE_PNG, 0);
-    if (fd == NULL) {
-      csound->InitError(csound,
-                        Str("imageload: cannot open image %s for writing.\n"),
-                        filename);
-      return 0;
+    if (UNLIKELY(fd == NULL)) {
+      return
+        csound->InitError(csound,
+                          Str("imageload: cannot open image %s for writing.\n"),
+                          filename);
     }
 
     png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
 
-    if (!png_ptr){
-      csound->InitError(csound, Str("imageload: out of memory.\n"));
+    if (UNLIKELY(!png_ptr)){
       csound->FileClose(csound, fd);
-      return 0;
+      return csound->InitError(csound, Str("imageload: out of memory.\n"));
     }
 
     info_ptr = png_create_info_struct(png_ptr);
-    if (!info_ptr) {
+    if (UNLIKELY(!info_ptr)) {
       png_destroy_write_struct(&png_ptr, (png_infopp)NULL);
-      csound->InitError(csound, Str("imageload: out of memory.\n"));
       csound->FileClose(csound, fd);
-      return 0;
+      return csound->InitError(csound, Str("imageload: out of memory.\n"));
     }
 
     png_init_io(png_ptr, fp);
@@ -305,11 +313,10 @@ static int __doSaveImage(Image *image, char *filename, CSOUND *csound)
 
     png_write_info(png_ptr, info_ptr);
 
-    row_pointers = (png_bytepp)malloc(image->h*sizeof(png_bytep));
-    if (row_pointers == NULL) {
+    row_pointers = (png_bytepp)csound->Malloc(csound, image->h*sizeof(png_bytep));
+    if (UNLIKELY(row_pointers == NULL)) {
       png_destroy_write_struct(&png_ptr, &info_ptr);
-      csound->InitError(csound, Str("imageload: out of memory.\n"));
-      return 0;
+      return csound->InitError(csound, Str("imageload: out of memory.\n"));
     }
 
     rowbytes = png_get_rowbytes(png_ptr, info_ptr);
@@ -320,11 +327,11 @@ static int __doSaveImage(Image *image, char *filename, CSOUND *csound)
     png_write_image(png_ptr, row_pointers);
     png_write_end(png_ptr, info_ptr);
 
-    free(row_pointers);
+    csound->Free(csound,row_pointers);
     png_destroy_write_struct(&png_ptr, &info_ptr);
     csound->FileClose(csound, fd);
 
-    return 0;
+    return OK;
 #else
     Display *disp;
     ImlibData *id;
@@ -338,22 +345,22 @@ static int __doSaveImage(Image *image, char *filename, CSOUND *csound)
     Imlib_save_image(id, im, filename, NULL);
     Imlib_kill_image(id, im);
 
-    return 0;
+    return OK;
 #endif
 }
 
 
-static Image * createImage(int w, int h)
+static Image * createImage(CSOUND *csound, int w, int h)
 {
     Image *img;
     size_t datasize;
 
-    img = malloc(sizeof(Image));
+    img = csound->Malloc(csound, sizeof(Image));
     img->w = w;
     img->h = h;
 
     datasize = img->w*img->h*3 * sizeof(unsigned char);
-    img->imageData = malloc(datasize);
+    img->imageData = csound->Malloc(csound, datasize);
 
     return img;
 }
@@ -377,7 +384,6 @@ static Images * getImages(CSOUND *csound)
 
 static int imagecreate (CSOUND *csound, IMGCREATE * p)
 {
-
     Images *pimages;
     Image *img;
 
@@ -388,11 +394,10 @@ static int imagecreate (CSOUND *csound, IMGCREATE * p)
       (Image **) csound->ReAlloc(csound, pimages->images,
                                  sizeof(Image *) * pimages->cnt);
 
-    img = createImage(*p->kw, *p->kh);
+    img = createImage(csound, *p->kw, *p->kh);
 
-    if (img==NULL) {
-      csound->InitError(csound, Str("Cannot allocate memory.\n"));
-      return NOTOK;
+    if (UNLIKELY(img==NULL)) {
+      return csound->InitError(csound, Str("Cannot allocate memory.\n"));
     }
     else {
       pimages->images[pimages->cnt-1] = img;
@@ -403,8 +408,7 @@ static int imagecreate (CSOUND *csound, IMGCREATE * p)
 
 static int imageload (CSOUND *csound, IMGLOAD * p)
 {
-    char filename[255];
-
+    char filename[256];
     Images *pimages;
     Image *img;
 
@@ -415,19 +419,19 @@ static int imageload (CSOUND *csound, IMGLOAD * p)
       (Image **) csound->ReAlloc(csound, pimages->images,
                                  sizeof(Image *) * pimages->cnt);
 
-    strcpy(filename, (char*) p->ifilnam);
+    strncpy(filename, (char*) (p->ifilnam->data), 255);filename[255]='\0';
 
     img = __doOpenImage(filename, csound);
 
-    if (img) {
+    if (LIKELY(img)) {
       pimages->images[pimages->cnt-1] = img;
       *(p->kn) = (MYFLT) pimages->cnt;
       return OK;
     }
     else {
-      /* csound->InitError(csound,
-         Str("imageload: cannot open image %s.\n"), filename); */
-      return NOTOK;
+      return csound->InitError(csound,
+                               Str("imageload: cannot open image %s.\n"),
+                               filename);
     }
 }
 
@@ -490,20 +494,35 @@ static int imagegetpixel_a (CSOUND *csound, IMGGETPIXEL * p)
     MYFLT *tx = p->kx;
     MYFLT *ty = p->ky;
 
-    int i, n=csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
     int w, h, x, y, pixel;
 
-    pimages = (Images *) csound->QueryGlobalVariable(csound,"imageOpcodes.images");
+    pimages = (Images *) csound->QueryGlobalVariable(csound,
+                                                     "imageOpcodes.images");
     img = pimages->images[(int)(*p->kn)-1];
     w = img->w;
     h = img->h;
 
-    for (i = 0; i < n; i++){
+
+    if (UNLIKELY(offset)) {
+      memset(r, '\0', offset*sizeof(MYFLT));
+      memset(g, '\0', offset*sizeof(MYFLT));
+      memset(b, '\0', offset*sizeof(MYFLT));
+    }
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&r[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&g[nsmps], '\0', early*sizeof(MYFLT));
+      memset(&b[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (i = 0; i < nsmps; i++) {
 
       x = tx[i]*w;
       y = ty[i]*h;
 
-      if (x >= 0 && x < w && y >= 0 && y < h ) {
+      if ( x >= 0 && x < w && y >= 0 && y < h ) {
         pixel = (w*y+x)*3;
         r[i] = img->imageData[pixel]/FL(255.0);
         g[i] = img->imageData[pixel+1]/FL(255.0);
@@ -531,16 +550,20 @@ static int imagesetpixel_a (CSOUND *csound, IMGSETPIXEL * p)
     MYFLT *tx = p->kx;
     MYFLT *ty = p->ky;
 
-    int i, n=csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
     int h,w,x, y, pixel;
 
-    pimages = (Images *) csound->QueryGlobalVariable(csound,"imageOpcodes.images");
+    pimages = (Images *) csound->QueryGlobalVariable(csound,
+                                                     "imageOpcodes.images");
     img = pimages->images[(int)(*p->kn)-1];
 
     w = img->w;
     h = img->h;
 
-    for (i = 0; i < n; i++) {
+    if (UNLIKELY(early)) nsmps -= early;
+    for (i = offset; i < nsmps; i++) {
 
       x = tx[i]*w;
       y = ty[i]*h;
@@ -563,7 +586,8 @@ static int imagesetpixel (CSOUND *csound, IMGSETPIXEL * p)
     Image *img;
     int w, h, x, y, pixel;
 
-    pimages = (Images *) csound->QueryGlobalVariable(csound,"imageOpcodes.images");
+    pimages = (Images *) csound->QueryGlobalVariable(csound,
+                                                     "imageOpcodes.images");
     img = pimages->images[(int)(*p->kn)-1];
 
     w = img->w;
@@ -585,15 +609,15 @@ static int imagesave (CSOUND *csound, IMGSAVE * p)
 {
     Images *pimages;
     Image *img;
-    char filename[255];
+    char filename[256];
 
-    strcpy(filename, (char*) p->ifilnam);
+    strncpy(filename, (char*) (p->ifilnam->data), 255);filename[255]='\0';
 
-    pimages = (Images *) csound->QueryGlobalVariable(csound,"imageOpcodes.images");
+    pimages = (Images *) csound->QueryGlobalVariable(csound,
+                                                     "imageOpcodes.images");
     img = pimages->images[(int)(*p->kn)-1];
 
-    __doSaveImage(img, filename, csound);
-    return OK;
+    return __doSaveImage(img, filename, csound);
 }
 
 static int imagefree (CSOUND *csound, IMGSAVE * p)
@@ -601,28 +625,28 @@ static int imagefree (CSOUND *csound, IMGSAVE * p)
     Images *pimages;
     Image *img;
 
-    pimages = (Images *) csound->QueryGlobalVariable(csound,"imageOpcodes.images");
+    pimages = (Images *) csound->QueryGlobalVariable(csound,
+                                                     "imageOpcodes.images");
     img = pimages->images[(int)(*p->kn)-1];
-    free(img->imageData);
-    free(img);
+    csound->Free(csound,img->imageData);
+    csound->Free(csound,img);
 
     return OK;
 }
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-  { "imageload",  S(IMGLOAD),  1, "i", "S",   (SUBR)imageload, NULL, NULL   },
-  { "imagecreate",S(IMGCREATE),1, "i", "ii",  (SUBR)imagecreate, NULL, NULL },
-  { "imagesize",  S(IMGSIZE),  1, "ii", "i",  (SUBR)imagesize, NULL, NULL   },
-  { "imagegetpixel",  S(IMGGETPIXEL),  7, "sss", "ixx",
+static OENTRY image_localops[] = {
+  { "imageload",  S(IMGLOAD),  0, 1, "i", "S",   (SUBR)imageload, NULL, NULL   },
+  { "imagecreate",S(IMGCREATE),0, 1, "i", "ii",  (SUBR)imagecreate, NULL, NULL },
+  { "imagesize",  S(IMGSIZE),  0, 1, "ii", "i",  (SUBR)imagesize, NULL, NULL   },
+  { "imagegetpixel",  S(IMGGETPIXEL),  0, 7, "sss", "ixx",
     (SUBR)imagegetpixel, (SUBR)imagegetpixel, (SUBR)imagegetpixel_a   },
-  { "imagesetpixel",  S(IMGSETPIXEL),  7, "", "ixxxxx",
+  { "imagesetpixel",  S(IMGSETPIXEL),  0, 7, "", "ixxxxx",
     (SUBR)imagesetpixel, (SUBR)imagesetpixel, (SUBR)imagesetpixel_a   },
-  { "imagesave",  S(IMGSAVE),  1, "", "iS",   (SUBR)imagesave, NULL, NULL   },
-  { "imagefree",  S(IMGFREE),  1, "", "i",    (SUBR)imagefree, NULL, NULL   },
-
+  { "imagesave",  S(IMGSAVE),  0, 1, "", "iS",   (SUBR)imagesave, NULL, NULL   },
+  { "imagefree",  S(IMGFREE),  0, 1, "", "i",    (SUBR)imagefree, NULL, NULL   },
 };
 
 
-LINKAGE
+LINKAGE_BUILTIN(image_localops)
