@@ -26,7 +26,7 @@
 /** midicXX   UGs by Gabriel Maldonado **/
 /****************************************/
 
-#include "csdl.h"
+#include "stdopcod.h"
 #include "midiops2.h"
 #ifndef TRUE
 #define TRUE (1)
@@ -50,16 +50,19 @@ static int imidic7(CSOUND *csound, MIDICTL2 *p)
 {
     MYFLT value;
     FUNC  *ftp;
-    long  ctlno;
+    int32  ctlno;
 
-    if ((ctlno = (long)*p->ictlno) < 0 || ctlno > 127)
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
+    if (UNLIKELY((ctlno = (int32)*p->ictlno) < 0 || ctlno > 127))
       return csound->InitError(csound, Str("illegal controller number"));
     else {
       value = (MYFLT)(csound->curip->m_chnbp->ctl_val[ctlno] * oneTOf7bit);
       if (*p->ifn > 0) {
-        if ((ftp = csound->FTFind(csound, p->ifn)) == NULL)
+        if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))
           return NOTOK; /* if valid ftable, use value as index   */
-        value = *(ftp->ftable + (long)(value*ftp->flen)); /* no interpolation */
+        value = *(ftp->ftable + (int32)(value*ftp->flen)); /* no interpolation */
       }
       *p->r = value * (*p->imax - *p->imin) + *p->imin; /* scales the output*/
     }
@@ -68,13 +71,13 @@ static int imidic7(CSOUND *csound, MIDICTL2 *p)
 
 static int midic7set(CSOUND *csound, MIDICTL2 *p)
 {
-    long  ctlno;
-    if ((ctlno = (long)*p->ictlno) < 0 || ctlno > 127) {
+    int32  ctlno;
+    if (UNLIKELY((ctlno = (int32)*p->ictlno) < 0 || ctlno > 127)) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
     else p->ctlno = ctlno;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))
         p->flag = FALSE;  /* invalid ftable */
       else p->flag= TRUE;
     }
@@ -87,10 +90,13 @@ static int midic7(CSOUND *csound, MIDICTL2 *p)
     MYFLT value;
     INSDS *lcurip = p->h.insdshead;
 
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
     value = (MYFLT) (lcurip->m_chnbp->ctl_val[p->ctlno] * oneTOf7bit);
     if (p->flag)  {             /* if valid ftable,use value as index   */
       value = *(p->ftp->ftable +
-                (long)(value*p->ftp->flen));            /* no interpolation */
+                (int32)(value*p->ftp->flen));            /* no interpolation */
     }
     *p->r = value * (*p->imax - *p->imin) + *p->imin;   /* scales the output */
     return OK;
@@ -103,11 +109,14 @@ static int imidic14(CSOUND *csound, MIDICTL3 *p)
 {
     MYFLT value;
     FUNC  *ftp;
-    long  ctlno1;
-    long  ctlno2;
+    int32  ctlno1;
+    int32  ctlno2;
 
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 )
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+                 (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ))
       return csound->InitError(csound, Str("illegal controller number"));
     else {
       value = (MYFLT) ((csound->curip->m_chnbp->ctl_val[ctlno1] * 128 +
@@ -120,13 +129,13 @@ static int imidic14(CSOUND *csound, MIDICTL3 *p)
         MYFLT *base;
         MYFLT *top;
         MYFLT diff;
-        long length;
+        int32 length;
 
-        if ((ftp = csound->FTFind(csound, p->ifn)) == NULL)
+        if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))
           return NOTOK; /* if valid ftable,use value as index   */
         phase = value * (length = ftp->flen);
-        diff = phase - (long) phase;
-        base = (base_address = ftp->ftable) + (long)(phase);
+        diff = phase - (int32) phase;
+        base = (base_address = ftp->ftable) + (int32)(phase);
         top  = base + 1 ;
         top = (top - base_address > length) ?  base_address : top;
         value = *base + (*top - *base) * diff;
@@ -138,16 +147,16 @@ static int imidic14(CSOUND *csound, MIDICTL3 *p)
 
 static int midic14set(CSOUND *csound, MIDICTL3 *p)
 {
-    long   ctlno1;
-    long   ctlno2;
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ) {
+    int32   ctlno1;
+    int32   ctlno2;
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+                 (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 )) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
     p->ctlno1 = ctlno1;
     p->ctlno2 = ctlno2;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = FALSE;  /* invalid ftable */
       else p->flag= TRUE;
     }
@@ -161,13 +170,16 @@ static int midic14(CSOUND *csound, MIDICTL3 *p)
     MYFLT value;
     INSDS *lcurip = p->h.insdshead;
 
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
     value =     (MYFLT) ((lcurip->m_chnbp->ctl_val[p->ctlno1] *128  +
                           lcurip->m_chnbp->ctl_val[p->ctlno2] )
                          * oneTOf14bit);
     if (p->flag)  {     /* if valid ftable,use value as index   */
       MYFLT phase = value * p->ftp->flen; /* gab-A1 */
-      MYFLT *base = p->ftp->ftable + (long)(phase);
-      value = *base + (*(base+1) - *base) * (phase - (long) phase);
+      MYFLT *base = p->ftp->ftable + (int32)(phase);
+      value = *base + (*(base+1) - *base) * (phase - (int32) phase);
 
       /* linear interpolation routine */
       /*
@@ -176,11 +188,11 @@ static int midic14(CSOUND *csound, MIDICTL3 *p)
         MYFLT *base;
         MYFLT *top;
         MYFLT diff;
-        long length;
+        int32 length;
 
         phase =  value * (length = p->ftp->flen);
-        diff = phase - (long) phase;
-        base = (base_address = p->ftp->ftable) + (long)(phase);
+        diff = phase - (int32) phase;
+        base = (base_address = p->ftp->ftable) + (int32)(phase);
         top  = base + 1 ;
         top = (top - base_address > length) ?  base_address : top;
         value = *base + (*top - *base) * diff;
@@ -196,13 +208,16 @@ static int midic14(CSOUND *csound, MIDICTL3 *p)
 static int imidic21(CSOUND *csound, MIDICTL4 *p)
 {
     MYFLT value;
-    long   ctlno1;
-    long   ctlno2;
-    long   ctlno3;
+    int32   ctlno1;
+    int32   ctlno2;
+    int32   ctlno3;
 
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ||
-        (ctlno3 = (long)*p->ictlno3) < 0 || ctlno3 > 127)
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+        (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ||
+                 (ctlno3 = (int32)*p->ictlno3) < 0 || ctlno3 > 127))
       return csound->InitError(csound, Str("illegal controller number"));
     else {
       value = (MYFLT) ((csound->curip->m_chnbp->ctl_val[ctlno1] * 16384 +
@@ -211,15 +226,15 @@ static int imidic21(CSOUND *csound, MIDICTL4 *p)
                        * oneTOf21bit);
       if (*p->ifn > 0) {
         /* linear interpolation routine */
-        FUNC *ftp = csound->FTFind(csound, p->ifn); /* gab-A1 */
+        FUNC *ftp = csound->FTnp2Find(csound, p->ifn); /* gab-A1 */
         MYFLT phase;
         MYFLT *base;
-        if (ftp == NULL)
+        if (UNLIKELY(ftp == NULL))
           return csound->InitError(csound, Str("Invalid ftable no. %f"),
                                            *p->ifn);
         phase = value * ftp->flen;
-        base = ftp->ftable + (long)(phase);
-        value = *base + (*(base+1) - *base) * (phase - (long)phase);
+        base = ftp->ftable + (int32)(phase);
+        value = *base + (*(base+1) - *base) * (phase - (int32)phase);
       }
       *p->r = value * (*p->imax - *p->imin) + *p->imin;  /* scales the output*/
     }
@@ -228,19 +243,19 @@ static int imidic21(CSOUND *csound, MIDICTL4 *p)
 
 static int midic21set(CSOUND *csound, MIDICTL4 *p)
 {
-    long   ctlno1;
-    long   ctlno2;
-    long   ctlno3;
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ||
-        (ctlno3 = (long)*p->ictlno3) < 0 || ctlno3 > 127) {
+    int32   ctlno1;
+    int32   ctlno2;
+    int32   ctlno3;
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+        (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ||
+                 (ctlno3 = (int32)*p->ictlno3) < 0 || ctlno3 > 127)) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
     p->ctlno1 = ctlno1;
     p->ctlno2 = ctlno2;
     p->ctlno3 = ctlno3;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = FALSE;  /* invalid ftable */
       else
         p->flag= TRUE;
@@ -255,14 +270,17 @@ static int midic21(CSOUND *csound, MIDICTL4 *p)
     MYFLT value;
     INSDS *lcurip = p->h.insdshead;
 
+    if (!p->h.insdshead->m_chnbp) {
+      return OK;
+    }
     value = (MYFLT)((lcurip->m_chnbp->ctl_val[p->ctlno1] * 16384 +
                      lcurip->m_chnbp->ctl_val[p->ctlno2] * 128   +
                      lcurip->m_chnbp->ctl_val[p->ctlno3] )  * oneTOf21bit);
     if (p->flag)  {     /* if valid ftable,use value as index   */
       /* linear interpolation routine */
       MYFLT phase = value * p->ftp->flen;
-      MYFLT *base = p->ftp->ftable + (long)(phase);
-      value = *base + (*(base+1) - *base) * (phase - (long) phase);
+      MYFLT *base = p->ftp->ftable + (int32)(phase);
+      value = *base + (*(base+1) - *base) * (phase - (int32) phase);
 
       /*
         MYFLT phase;
@@ -270,11 +288,11 @@ static int midic21(CSOUND *csound, MIDICTL4 *p)
         MYFLT *base;
         MYFLT *top;
         MYFLT diff;
-        long length;
+        int32 length;
 
         phase = value * (length = p->ftp->flen);
-        diff = phase - (long) phase;
-        base = (base_address = p->ftp->ftable) + (long)(phase);
+        diff = phase - (int32) phase;
+        base = (base_address = p->ftp->ftable) + (int32)(phase);
         top  = base + 1 ;
         top = (top - base_address > length) ?  base_address : top;
         value = *base + (*top - *base) * diff;
@@ -292,17 +310,17 @@ static int ictrl7(CSOUND *csound, CTRL7 *p)
 {
     MYFLT value;
     FUNC *ftp;
-    long  ctlno;
+    int32  ctlno;
 
-    if ((ctlno = (long)*p->ictlno) < 0 || ctlno > 127)
+    if (UNLIKELY((ctlno = (int32)*p->ictlno) < 0 || ctlno > 127))
       return csound->InitError(csound, Str("illegal controller number"));
     else {
       value = (MYFLT) (csound->m_chnbp[(int) *p->ichan-1]->ctl_val[ctlno]
                        * oneTOf7bit);
       if (*p->ifn > 0) {
-        if ((ftp = csound->FTFind(csound, p->ifn)) == NULL)
+        if (UNLIKELY((ftp = csound->FTnp2Find(csound, p->ifn)) == NULL))
           return NOTOK;               /* if valid ftable,use value as index   */
-        value = *(ftp->ftable + (long)(value*ftp->flen)); /* no interpolation */
+        value = *(ftp->ftable + (int32)(value*ftp->flen)); /* no interpolation */
       }
       *p->r = value * (*p->imax - *p->imin) + *p->imin;  /* scales the output*/
     }
@@ -311,19 +329,19 @@ static int ictrl7(CSOUND *csound, CTRL7 *p)
 
 static int ctrl7set(CSOUND *csound, CTRL7 *p)
 {
-    long  ctlno;
+    int32  ctlno;
     int chan;
-    if ((ctlno = (long) *p->ictlno) < 0 || ctlno > 127) {
+    if (UNLIKELY((ctlno = (int32) *p->ictlno) < 0 || ctlno > 127)) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
-    else if ((chan=(int) *p->ichan-1) < 0 || chan > 15) {
+    else if (UNLIKELY((chan=(int) *p->ichan-1) < 0 || chan > 15)) {
       return csound->InitError(csound,
                      Str("illegal midi channel")); /* gab-A2 (chan number fix)*/
     }
     /*else if (midi_in_p_num < 0) midi_in_error("ctrl7");*/
     else p->ctlno = ctlno;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = FALSE;  /* invalid ftable */
       else p->flag= TRUE;
     }
@@ -337,7 +355,7 @@ static int ctrl7(CSOUND *csound, CTRL7 *p)
                            * oneTOf7bit);
     if (p->flag)  {             /* if valid ftable,use value as index   */
       value =
-        *(p->ftp->ftable + (long)(value*p->ftp->flen)); /* no interpolation */
+        *(p->ftp->ftable + (int32)(value*p->ftp->flen)); /* no interpolation */
     }
     *p->r = value * (*p->imax - *p->imin) + *p->imin;   /* scales the output */
     return OK;
@@ -348,14 +366,14 @@ static int ctrl7(CSOUND *csound, CTRL7 *p)
 static int ictrl14(CSOUND *csound, CTRL14 *p)
 {
     MYFLT value;
-    long  ctlno1;
-    long  ctlno2;
+    int32  ctlno1;
+    int32  ctlno2;
     int chan;
 
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 )
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+                 (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ))
       return csound->InitError(csound, Str("illegal controller number"));
-    else if ((chan=(int) *p->ichan-1) < 0 || chan > 15)
+    else if (UNLIKELY((chan=(int) *p->ichan-1) < 0 || chan > 15))
       return csound->InitError(csound, Str("illegal midi channel"));
     else {
       value = (MYFLT)((csound->m_chnbp[chan]->ctl_val[ctlno1] * 128 +
@@ -363,15 +381,15 @@ static int ictrl14(CSOUND *csound, CTRL14 *p)
 
       if (*p->ifn > 0) {
         /* linear interpolation routine */
-        FUNC *ftp = csound->FTFind(csound, p->ifn);
+        FUNC *ftp = csound->FTnp2Find(csound, p->ifn);
         MYFLT phase;
         MYFLT *base;
-        if (ftp == NULL)
+        if (UNLIKELY(ftp == NULL))
           return csound->InitError(csound, Str("Invalid ftable no. %f"),
                                            *p->ifn);
         phase = value * ftp->flen;
-        base = ftp->ftable + (long)(phase);
-        value = *base + (*(base+1) - *base) * (phase - (long)phase);
+        base = ftp->ftable + (int32)(phase);
+        value = *base + (*(base+1) - *base) * (phase - (int32)phase);
       }
       *p->r = value * (*p->imax - *p->imin) + *p->imin;  /* scales the output*/
     }
@@ -380,20 +398,20 @@ static int ictrl14(CSOUND *csound, CTRL14 *p)
 
 static int ctrl14set(CSOUND *csound, CTRL14 *p)
 {
-    long   ctlno1;
-    long   ctlno2;
+    int32   ctlno1;
+    int32   ctlno2;
     int chan;
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ) {
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+                 (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 )) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
-    else if ((chan=(int) *p->ichan-1) < 0 || chan > 15) {
+    else if (UNLIKELY((chan=(int) *p->ichan-1) < 0 || chan > 15)) {
       return csound->InitError(csound, Str("illegal midi channel"));
     }
     p->ctlno1 = ctlno1;
     p->ctlno2 = ctlno2;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = FALSE;  /* invalid ftable */
       else p->flag= TRUE;
     }
@@ -413,8 +431,8 @@ static int ctrl14(CSOUND *csound, CTRL14 *p)
     if (p->flag)  {             /* if valid ftable,use value as index   */
                                 /* linear interpolation routine */
        MYFLT phase = value * p->ftp->flen;
-       MYFLT *base = p->ftp->ftable + (long)(phase);
-       value = *base + (*(base+1) - *base) * (phase - (long) phase);
+       MYFLT *base = p->ftp->ftable + (int32)(phase);
+       value = *base + (*(base+1) - *base) * (phase - (int32) phase);
 
     }
     *p->r = value * (*p->imax - *p->imin) + *p->imin;   /* scales the output */
@@ -427,16 +445,16 @@ static int ctrl14(CSOUND *csound, CTRL14 *p)
 static int ictrl21(CSOUND *csound, CTRL21 *p)
 {
     MYFLT  value;
-    long   ctlno1;
-    long   ctlno2;
-    long   ctlno3;
+    int32   ctlno1;
+    int32   ctlno2;
+    int32   ctlno3;
     int chan;
 
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ||
-        (ctlno3 = (long)*p->ictlno3) < 0 || ctlno3 > 127)
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+        (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ||
+                 (ctlno3 = (int32)*p->ictlno3) < 0 || ctlno3 > 127))
       return csound->InitError(csound, Str("illegal controller number"));
-    else if ((chan=(int) *p->ichan-1) < 0 || chan > 15)
+    else if (UNLIKELY((chan=(int) *p->ichan-1) < 0 || chan > 15))
       return csound->InitError(csound, Str("illegal midi channel"));
     else {
       value = (MYFLT)((csound->m_chnbp[chan]->ctl_val[ctlno1] * 16384 +
@@ -445,15 +463,15 @@ static int ictrl21(CSOUND *csound, CTRL21 *p)
 
       if (*p->ifn > 0) {
         /* linear interpolation routine */
-        FUNC *ftp = csound->FTFind(csound, p->ifn);
+        FUNC *ftp = csound->FTnp2Find(csound, p->ifn);
         MYFLT phase;
         MYFLT *base;
-        if (ftp == NULL)
+        if (UNLIKELY(ftp == NULL))
           return csound->InitError(csound, Str("Invalid ftable no. %f"),
                                            *p->ifn);
         phase = value * ftp->flen;
-        base = ftp->ftable + (long)(phase);
-        value = *base + (*(base+1) - *base) * (phase - (long)phase);
+        base = ftp->ftable + (int32)(phase);
+        value = *base + (*(base+1) - *base) * (phase - (int32)phase);
       }
       *p->r = value * (*p->imax - *p->imin) + *p->imin;  /* scales the output*/
     }
@@ -462,23 +480,23 @@ static int ictrl21(CSOUND *csound, CTRL21 *p)
 
 static int ctrl21set(CSOUND *csound, CTRL21 *p)
 {
-    long   ctlno1;
-    long   ctlno2;
-    long   ctlno3;
+    int32   ctlno1;
+    int32   ctlno2;
+    int32   ctlno3;
     int chan;
-    if ((ctlno1 = (long)*p->ictlno1) < 0 || ctlno1 > 127 ||
-        (ctlno2 = (long)*p->ictlno2) < 0 || ctlno2 > 127 ||
-        (ctlno3 = (long)*p->ictlno3) < 0 || ctlno3 > 127) {
+    if (UNLIKELY((ctlno1 = (int32)*p->ictlno1) < 0 || ctlno1 > 127 ||
+        (ctlno2 = (int32)*p->ictlno2) < 0 || ctlno2 > 127 ||
+                 (ctlno3 = (int32)*p->ictlno3) < 0 || ctlno3 > 127)) {
       return csound->InitError(csound, Str("illegal controller number"));
     }
-    else if ((chan=(int) *p->ichan-1) < 0 || chan > 15) {
+    else if (UNLIKELY((chan=(int) *p->ichan-1) < 0 || chan > 15)) {
       return csound->InitError(csound, Str("illegal midi channel"));
     }
     p->ctlno1 = ctlno1;
     p->ctlno2 = ctlno2;
     p->ctlno3 = ctlno3;
     if (*p->ifn > 0) {
-      if (((p->ftp = csound->FTFind(csound, p->ifn)) == NULL))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
         p->flag = FALSE;  /* invalid ftable */
       else
         p->flag= TRUE;
@@ -498,8 +516,8 @@ static int ctrl21(CSOUND *csound, CTRL21 *p)
     if (p->flag)  {     /* if valid ftable,use value as index   */
         /* linear interpolation routine */
        MYFLT phase = value * p->ftp->flen;
-       MYFLT *base = p->ftp->ftable + (long)(phase);
-       value = *base + (*(base+1) - *base) * (phase - (long) phase);
+       MYFLT *base = p->ftp->ftable + (int32)(phase);
+       value = *base + (*(base+1) - *base) * (phase - (int32) phase);
     }
     *p->r = value * (*p->imax - *p->imin) + *p->imin;   /* scales the output */
     return OK;
@@ -510,10 +528,10 @@ static int initc7(CSOUND *csound, INITC7 *p)
 {                  /* (value - min) / (max - min) */
     MYFLT fvalue;
     int chan;
-    if ((fvalue = *p->ivalue) < 0. || fvalue > 1. )
+    if (UNLIKELY((fvalue = *p->ivalue) < 0. || fvalue > 1. ))
       return csound->InitError(csound, Str("value out of range"));
-    else if ((chan = (int) *p->ichan-1) < 0 || chan > 15 ||
-             !csound->m_chnbp[chan])
+    else if (UNLIKELY((chan = (int) *p->ichan-1) < 0 || chan > 15 ||
+                      !csound->m_chnbp[chan]))
       return csound->InitError(csound, Str("illegal midi channel"));
     else
       csound->m_chnbp[chan]->ctl_val[(int) *p->ictlno] = fvalue * f7bit
@@ -525,10 +543,10 @@ static int initc14(CSOUND *csound, INITC14 *p)
 {
     MYFLT fvalue;
     int value, msb, lsb, chan;
-    if ((fvalue = *p->ivalue) < FL(0.0) || fvalue > FL(1.0) )
+    if (UNLIKELY((fvalue = *p->ivalue) < FL(0.0) || fvalue > FL(1.0) ))
       return csound->InitError(csound, Str("value out of range"));
-    else if ((chan = (int) *p->ichan - 1) < 0 || chan > 15 ||
-             !csound->m_chnbp[chan])
+    else if (UNLIKELY((chan = (int) *p->ichan - 1) < 0 || chan > 15 ||
+                      !csound->m_chnbp[chan]))
       return csound->InitError(csound, Str("illegal midi channel"));
     else {
       value = (int)MYFLT2LONG(fvalue * f14bit);
@@ -544,10 +562,10 @@ static int initc21(CSOUND *csound, INITC21 *p)
 {
     MYFLT fvalue;
     int value, msb, xsb, lsb, chan;
-    if ((fvalue = *p->ivalue) < FL(0.0) || fvalue > FL(1.0) )
+    if (UNLIKELY((fvalue = *p->ivalue) < FL(0.0) || fvalue > FL(1.0) ))
       return csound->InitError(csound, Str("value out of range"));
-    else if ((chan = (int) *p->ichan - 1) < 0 || chan > 15 ||
-             !csound->m_chnbp[chan])
+    else if (UNLIKELY((chan = (int) *p->ichan - 1) < 0 || chan > 15 ||
+                      !csound->m_chnbp[chan]))
       return csound->InitError(csound, Str("illegal midi channel"));
     else {
       value = (int)MYFLT2LONG(fvalue * f21bit);
@@ -576,7 +594,7 @@ static int midipgm_opcode(CSOUND *csound, MIDIPGM_OP *p)
     *(p->ipgm) = FL(0.0);
     channelNum = (int) MYFLT2LONG(*(p->ichn));
     if (channelNum > 0) {
-      if (channelNum > 16)
+      if (UNLIKELY(channelNum > 16))
         return csound->InitError(csound, Str("invalid channel number: %d"),
                                          channelNum);
       chnp = csound->m_chnbp[channelNum - 1];
@@ -599,22 +617,22 @@ static OENTRY localops[] = {
 { "midic14", 0xffff,                                                    },
 { "midic21", 0xffff,                                                    },
 { "midic7", 0xffff,                                                     },
-{ "midic7.i",S(MIDICTL2),1,  "i", "iiio", (SUBR)imidic7,   NULL,     NULL },
-{ "midic7.k", S(MIDICTL2),3, "k", "ikko", (SUBR)midic7set, (SUBR)midic7,  NULL },
-{ "midic14.i", S(MIDICTL3), 1,"i", "iiiio",(SUBR)imidic14,   NULL,     NULL },
-{ "midic14.k", S(MIDICTL3), 3,"k", "iikko",(SUBR)midic14set, (SUBR)midic14, NULL },
-{ "midic21.i", S(MIDICTL4),1,"i", "iiiiio",(SUBR)imidic21,   NULL,     NULL },
-{ "midic21.k", S(MIDICTL4), 3,"k", "iiikko",(SUBR)midic21set,(SUBR)midic21, NULL },
-{ "ctrl7.i", S(CTRL7), 1,    "i", "iiiio", (SUBR)ictrl7,     NULL,     NULL },
-{ "ctrl7.k", S(CTRL7),  3,   "k", "iikko", (SUBR)ctrl7set,  (SUBR)ctrl7, NULL },
-{ "ctrl14.i", S(CTRL14),1,   "i", "iiiiio",(SUBR)ictrl14,    NULL,     NULL },
-{ "ctrl14.k", S(CTRL14), 3,  "k", "iiikko",(SUBR)ctrl14set, (SUBR)ctrl14,  NULL },
-{ "ctrl21.i", S(CTRL21),1,   "i", "iiiiiio", (SUBR)ictrl21,  NULL,     NULL },
-{ "ctrl21.k", S(CTRL21), 3,  "k", "iiiikko", (SUBR)ctrl21set, (SUBR)ctrl21, NULL },
-{ "initc7", S(INITC7), 1,     "",  "iii",  (SUBR)initc7,     NULL,     NULL },
-{ "initc14", S(INITC14), 1,   "",  "iiii", (SUBR)initc14,    NULL,     NULL },
-{ "initc21", S(INITC21), 1,   "",  "iiiii",(SUBR)initc21,    NULL,     NULL },
-{ "midipgm", S(MIDIPGM_OP), 1, "i", "o",   (SUBR)midipgm_opcode, NULL, NULL }
+{ "midic7.i",S(MIDICTL2),0, 1,  "i", "iiio", (SUBR)imidic7, NULL, NULL  },
+{ "midic7.k", S(MIDICTL2),0, 3, "k", "ikko", (SUBR)midic7set, (SUBR)midic7, NULL },
+{ "midic14.i", S(MIDICTL3), 0, 1,"i", "iiiio",(SUBR)imidic14, NULL, NULL },
+{ "midic14.k", S(MIDICTL3), 0, 3,"k", "iikko",(SUBR)midic14set, (SUBR)midic14,NULL},
+{ "midic21.i", S(MIDICTL4),0, 1,"i", "iiiiio",(SUBR)imidic21, NULL, NULL },
+{ "midic21.k", S(MIDICTL4), 0, 3,"k", "iiikko",(SUBR)midic21set,(SUBR)midic21,NULL},
+{ "ctrl7.i", S(CTRL7), 0, 1,    "i", "iiiio", (SUBR)ictrl7,   NULL, NULL },
+{ "ctrl7.k", S(CTRL7),  0, 3,   "k", "iikko", (SUBR)ctrl7set, (SUBR)ctrl7, NULL },
+{ "ctrl14.i", S(CTRL14),0, 1,   "i", "iiiiio",(SUBR)ictrl14, NULL, NULL },
+{ "ctrl14.k", S(CTRL14), 0, 3,  "k", "iiikko",(SUBR)ctrl14set, (SUBR)ctrl14, NULL },
+{ "ctrl21.i", S(CTRL21),0, 1,   "i", "iiiiiio", (SUBR)ictrl21, NULL, NULL },
+{ "ctrl21.k", S(CTRL21), 0, 3,  "k", "iiiikko", (SUBR)ctrl21set,(SUBR)ctrl21,NULL},
+{ "initc7", S(INITC7), 0, 1,     "",  "iii",  (SUBR)initc7,     NULL,     NULL },
+{ "initc14", S(INITC14), 0, 1,   "",  "iiii", (SUBR)initc14,    NULL,     NULL },
+{ "initc21", S(INITC21), 0, 1,   "",  "iiiii",(SUBR)initc21,    NULL,     NULL },
+{ "midipgm", S(MIDIPGM_OP), 0, 1, "i", "o",   (SUBR)midipgm_opcode, NULL, NULL }
 };
 
 int midiops2_init_(CSOUND *csound)
