@@ -940,6 +940,7 @@ static int grain3(CSOUND *csound, GRAIN3 *p)
       f = w_frq_f / x_frq_f;
       g_frq = (f > FL(0.99999) ? OSCBNK_PHSMAX : OSCBNK_PHS2INT(f));
       /* initial window phase */
+      // COVERITY: g_frq is not zero, as it is derived from 1/sr
       g_ph = OSCBNK_PHSMAX % g_frq;
       if (g_ph < (OSCBNK_PHSMAX >> 16)) g_ph += g_frq;
       g_ph = OSCBNK_PHSMAX - g_ph;
@@ -1555,6 +1556,11 @@ static void vco2_calculate_table(CSOUND *csound,
     MYFLT   *fftbuf;
     int     i, minh;
 
+    if(table->ftable == NULL) {
+      csound->InitError(csound, "function table is NULL, check that ibasfn is available\n");
+      return;
+    }
+
     /* allocate memory for FFT */
     fftbuf = (MYFLT*) csound->Malloc(csound, sizeof(MYFLT) * (table->size + 2));
     if (tp->waveform >= 0) {                        /* no DC offset for   */
