@@ -70,12 +70,14 @@ struct TVConv : csnd::Plugin<1, 6> {
   csnd::AuxMem<MYFLT> irsp;
   csnd::AuxMem<MYFLT> out;
   csnd::AuxMem<MYFLT> saved;
+  csnd::AuxMem<MYFLT>::iterator itn;
+  csnd::AuxMem<MYFLT>::iterator itr;
+  csnd::AuxMem<MYFLT>::iterator itnsp;
+  csnd::AuxMem<MYFLT>::iterator itrsp;
   uint32_t n;
   uint32_t fils;
   uint32_t pars;
   uint32_t ffts;
-  uint32_t nparts;
-  uint32_t pp;
   csnd::fftp fwd, inv;
   typedef std::complex<MYFLT> cmplx;
 
@@ -102,24 +104,25 @@ struct TVConv : csnd::Plugin<1, 6> {
       std::swap(pars, fils);
     if (pars > 1) {
       pars = rpow2(pars);
-      fils = rpow2(fils);
+      fils = rpow2(fils) * 2;
       ffts = pars * 2;
       fwd = csound->fft_setup(ffts, FFT_FWD);
       inv = csound->fft_setup(ffts, FFT_INV);
-      out.allocate(csound, 2 * pars);
-      insp.allocate(csound, 2 * fils);
-      irsp.allocate(csound, 2 * fils);
+      out.allocate(csound, ffts);
+      insp.allocate(csound, fils);
+      irsp.allocate(csound, fils);
       saved.allocate(csound, pars);
-      ir.allocate(csound, 2 * fils);
-      in.allocate(csound, 2 * fils);
-      nparts = fils / pars;
-      fils *= 2;
+      ir.allocate(csound, fils);
+      in.allocate(csound, fils);
+      itnsp = insp.begin();
+      itrsp = insp.begin();
+      n = 0;
     } else {
       ir.allocate(csound, fils);
       in.allocate(csound, fils);
     }
-    n = 0;
-    pp = 0;
+    itn = in.begin();
+    itr = ir.begin();
     return OK;
   }
 
@@ -129,34 +132,41 @@ struct TVConv : csnd::Plugin<1, 6> {
     csnd::AudioSig outsig(this, outargs(0));
     auto irp = irsig.begin();
     auto inp = insig.begin();
-    MYFLT *frz1 = inargs(2);
-    MYFLT *frz2 = inargs(3);
-    bool inc1 = csound->is_asig(frz1);
-    bool inc2 = csound->is_asig(frz2);
+    auto *frz1 = inargs(2);
+    auto *frz2 = inargs(3);
+    auto inc1 = csound->is_asig(frz1);
+    auto inc2 = csound->is_asig(frz2);
 
     for (auto &s : outsig) {
-      if(*frz1 > 0) in[pp + n] = *inp;
-      if(*frz2 > 0) ir[pp + n] = *irp;
+      if(*frz1 > 0) itn[n] = *inp;
+      if(*frz2 > 0) itr[n] = *irp;
 
       s = out[n] + saved[n];
       saved[n] = out[n + pars];
       if (++n == pars) {
         cmplx *ins, *irs, *ous = to_cmplx(out.data());
-        std::copy(in.begin() + pp, in.begin() + pp + ffts, insp.begin() + pp);
-        std::copy(ir.begin() + pp, ir.begin() + pp + ffts, irsp.begin() + pp);
+        std::copy(itn, itn + ffts, itnsp);
+        std::copy(itr, itr + ffts, itrsp);
         std::fill(out.begin(), out.end(), 0.);
         // FFT
-        csound->rfft(fwd, insp.data() + pp);
-        csound->rfft(fwd, irsp.data() + pp);
-        pp += ffts;
-        if (pp == fils)
-          pp = 0;
+        csound->rfft(fwd, itnsp);
+        csound->rfft(fwd, itrsp);
+        // increment iterators
+        itnsp += ffts, itrsp += ffts;
+        itn += ffts, itr += ffts;
+        if (itnsp == insp.end()) {
+          itnsp = insp.begin();
+          itrsp = irsp.begin();
+          itn = in.begin();
+          itr = ir.begin();
+        }
         // spectral delay line
-        for (uint32_t k = 0, kp = pp; k < nparts; k++, kp += ffts) {
-          if (kp == fils)
-            kp = 0;
-          ins = to_cmplx(insp.data() + kp);
-          irs = to_cmplx(irsp.data() + (nparts - k - 1) * ffts);
+        for (csnd::AuxMem<MYFLT>::iterator it1 = itnsp,
+             it2 = irsp.end() - ffts; it2 >= irsp.begin();
+             it1 += ffts, it2 -= ffts) {
+          if (it1 == insp.end()) it1 = insp.begin();
+          ins =  to_cmplx(it1);
+          irs =  to_cmplx(it2);
           // spectral product
           for (uint32_t i = 1; i < pars; i++)
             ous[i] += ins[i] * irs[i];
@@ -166,38 +176,40 @@ struct TVConv : csnd::Plugin<1, 6> {
         csound->rfft(inv, out.data());
         n = 0;
       }
-      frz1 += inc1;
-      frz2 += inc2;
-      irp++;
-      inp++;
+      frz1 += inc1, frz2 += inc2;
+      irp++, inp++;
     }
     return OK;
   }
 
-  int dconv() {
+ int dconv() {
     csnd::AudioSig insig(this, inargs(0));
     csnd::AudioSig irsig(this, inargs(1));
     csnd::AudioSig outsig(this, outargs(0));
     auto irp = irsig.begin();
     auto inp = insig.begin();
-    MYFLT *frz1 = inargs(2);
-    MYFLT *frz2 = inargs(3);
-    bool inc1 = csound->is_asig(frz1);
-    bool inc2 = csound->is_asig(frz2);
+    auto frz1 = inargs(2);
+    auto frz2 = inargs(3);
+    auto inc1 = csound->is_asig(frz1);
+    auto inc2 = csound->is_asig(frz2);
+
     for (auto &s : outsig) {
-      if(*frz1 > 0) in[pp] = *inp;
-      if(*frz2 > 0) ir[pp] = *irp;
-      pp = pp != fils - 1 ? pp + 1 : 0;
-      s = 0.;
-      for (uint32_t k = 0, kp = pp; k < fils; k++, kp++) {
-        if (kp == fils)
-          kp = 0;
-        s += in[kp] * ir[fils - k - 1];
+      if(*frz1 > 0) *itn = *inp;
+      if(*frz2 > 0) *itr = *irp;
+      itn++, itr++;
+      if(itn == in.end()) {
+         itn = in.begin();
+         itr = ir.begin();
       }
-      frz1 += inc1;
-      frz2 += inc2;
-      inp++;
-      irp++;
+      s = 0.;
+      for (csnd::AuxMem<MYFLT>::iterator it1 = itn,
+           it2 = ir.end() - 1; it2 >= ir.begin();
+           it1++, it2--) {
+        if(it1 == in.end()) it1  = in.begin();
+        s += *it1 * *it2;
+      }
+      frz1 += inc1, frz2 += inc2;
+      inp++, irp++;
     }
     return OK;
   }
@@ -210,11 +222,80 @@ struct TVConv : csnd::Plugin<1, 6> {
   }
 };
 
+/*
+class PrintThread : public csnd::Thread {
+  std::atomic_bool splock;
+  std::atomic_bool on;
+  std::string message;
+
+  void lock() {
+    bool tmp = false;
+    while(!splock.compare_exchange_weak(tmp,true))
+      tmp = false;
+  }
+
+  void unlock() {
+    splock = false;
+  }
+
+  uintptr_t run() {
+    std::string old;
+    while(on) {
+      lock();
+      if(old.compare(message)) {
+       csound->message(message.c_str());
+       old = message;
+      }
+      unlock();
+    }
+    return 0;
+  }
+
+public:
+  PrintThread(csnd::Csound *csound)
+    : Thread(csound), splock(false), on(true), message("") {};
+
+  ~PrintThread(){
+    on = false;
+    join();
+  }
+
+  void set_message(const char *m) {
+    lock();
+    message = m;
+    unlock();
+  }
+
+};
+
+
+struct TPrint : csnd::Plugin<0, 1> {
+  static constexpr char const *otypes = "";
+  static constexpr char const *itypes = "S";
+  PrintThread t;
+
+  int init() {
+    csound->plugin_deinit(this);
+    csnd::constr(&t, csound);
+    return OK;
+  }
+
+  int deinit() {
+    csnd::destr(&t);
+    return OK;
+  }
+
+  int kperf() {
+    t.set_message(inargs.str_data(0).data);
+    return OK;
+  }
+};
+*/
+
+
+
 #include <modload.h>
 void csnd::on_load(Csound *csound) {
   csnd::plugin<PVTrace>(csound, "pvstrace", csnd::thread::ik);
-  csnd::plugin<TVConv>(csound, "tvconv", "a", "aakkii", csnd::thread::ia);
-  csnd::plugin<TVConv>(csound, "tvconv", "a", "aaakii", csnd::thread::ia);
-  csnd::plugin<TVConv>(csound, "tvconv", "a", "aakaii", csnd::thread::ia);
-  csnd::plugin<TVConv>(csound, "tvconv", "a", "aaaaii", csnd::thread::ia);
+  csnd::plugin<TVConv>(csound, "tvconv", "a", "aaxxii", csnd::thread::ia);
 }
