@@ -2006,12 +2006,12 @@ static int chunk_read(CSOUND *csound, FILE *fil, CHUNK *chunk)
       chunk->ckSize = 0;
       return 0;
     }
-    if (UNLIKELY(chunk->ckSize>0x40000000)) return 0;
+    //if (UNLIKELY(chunk->ckSize>0x8fffff00)) return 0;
     ChangeByteOrder("d", (char *)&chunk->ckSize, 4);
     chunk->ckDATA = (BYTE *) csound->Malloc(csound, chunk->ckSize);
     if (chunk->ckDATA==NULL)
       return 0;
-    if (chunk->ckSize>0x04000000) return 0;
+    if (chunk->ckSize>0x8fffff00) return 0;
     return fread(chunk->ckDATA,1,chunk->ckSize,fil);
 }
 
