@@ -134,6 +134,14 @@ static int deinit_udpRecv_S(CSOUND *csound, void *pdata)
 
     p->threadon = 0;
     csound->JoinThread(p->thrid);
+
+#ifndef WIN32
+    close(p->sock);
+    csound->Message(csound, Str("OSCraw: Closing socket\n"));
+#else
+    closesocket(p->sock);
+    csound->Message(csound, Str("OSCraw: Closing socket\n"));
+#endif
     return OK;
 }
 
@@ -164,19 +172,24 @@ static int init_recv(CSOUND *csound, SOCKRECV *p)
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
-
     p->cs = csound;
     p->sock = socket(AF_INET, SOCK_DGRAM, 0);
 #ifndef WIN32
     if (UNLIKELY(fcntl(p->sock, F_SETFL, O_NONBLOCK)<0))
       return csound->InitError(csound, Str("Cannot set nonblock"));
+#else
+    {
+      u_long argp = 1;
+      err = ioctlsocket(p->sock, FIONBIO, &argp);
+      if (UNLIKELY(err != NO_ERROR))
+        return csound->InitError(csound, Str("Cannot set nonblock"));
+    }
 #endif
     if (UNLIKELY(p->sock < 0)) {
-      return csound->InitError
-        (csound, Str("creating socket"));
+      return csound->InitError(csound, Str("creating socket"));
     }
     /* create server address: where we want to send to and clear it out */
     memset(&p->server_addr, 0, sizeof(p->server_addr));
@@ -221,8 +234,8 @@ static int init_recv_S(CSOUND *csound, SOCKRECVSTR *p)
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
 
     p->cs = csound;
@@ -232,8 +245,7 @@ static int init_recv_S(CSOUND *csound, SOCKRECVSTR *p)
       return csound->InitError(csound, Str("Cannot set nonblock"));
 #endif
     if (UNLIKELY(p->sock < 0)) {
-      return csound->InitError
-        (csound, Str("creating socket"));
+      return csound->InitError(csound, Str("creating socket"));
     }
     /* create server address: where we want to send to and clear it out */
     memset(&p->server_addr, 0, sizeof(p->server_addr));
@@ -275,7 +287,7 @@ static int send_recv_k(CSOUND *csound, SOCKRECV *p)
 {
     MYFLT   *ksig = p->ptr1;
     *ksig = FL(0.0);
-    if(p->outsamps >= p->rcvsamps){
+    if (p->outsamps >= p->rcvsamps){
       p->outsamps =  0;
       p->rcvsamps =
         csound->ReadCircularBuffer(csound, p->cb, p->buf, p->buffsize);
@@ -317,7 +329,7 @@ static int send_recv(CSOUND *csound, SOCKRECV *p)
     if (UNLIKELY(early)) nsmps -= early;
 
     for(i=offset; i < nsmps ; i++){
-      if(outsamps >= rcvsamps){
+      if (outsamps >= rcvsamps){
         outsamps =  0;
         rcvsamps = csound->ReadCircularBuffer(csound, p->cb, buf, p->buffsize);
       }
@@ -338,7 +350,7 @@ static int init_recvS(CSOUND *csound, SOCKRECV *p)
     WSADATA wsaData = {0};
     int err;
     if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
 
     p->cs = csound;
@@ -401,7 +413,7 @@ static int send_recvS(CSOUND *csound, SOCKRECV *p)
 
     if (UNLIKELY(early)) nsmps -= early;
     for(i=offset; i < nsmps ; i++){
-      if(outsamps >= rcvsamps){
+      if (outsamps >= rcvsamps){
         outsamps =  0;
         rcvsamps = csound->ReadCircularBuffer(csound, p->cb, buf, p->buffsize);
       }
@@ -422,7 +434,7 @@ static int init_srecv(CSOUND *csound, SOCKRECVT *p)
     WSADATA wsaData = {0};
     int err;
     if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
     /* create a STREAM (TCP) socket in the INET (IP) protocol */
     p->sock = socket(PF_INET, SOCK_STREAM, 0);
@@ -518,6 +530,19 @@ static inline void tabensure(CSOUND *csound, ARRAYDAT *p, int size)
     }
 }
 
+static int destroy_raw_osc(CSOUND *csound, void *pp) {
+    RAWOSC *p = (RAWOSC *) pp;
+#ifndef WIN32
+    close(p->sock);
+    csound->Message(csound, Str("OSCraw: Closing socket\n"));
+#else
+    closesocket(p->sock);
+    csound->Message(csound, Str("OSCraw: Closing socket\n"));
+#endif
+    return OK;
+}
+
+
 
 static int init_raw_osc(CSOUND *csound, RAWOSC *p)
 {
@@ -526,7 +551,7 @@ static int init_raw_osc(CSOUND *csound, RAWOSC *p)
     WSADATA wsaData = {0};
     int err;
     if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
     p->sock = socket(AF_INET, SOCK_DGRAM, 0);
 #ifndef WIN32
@@ -538,8 +563,7 @@ static int init_raw_osc(CSOUND *csound, RAWOSC *p)
        return csound->InitError(csound, Str("Cannot set nonblock"));
 #endif
     if (UNLIKELY(p->sock < 0)) {
-      return csound->InitError
-        (csound, Str("creating socket"));
+      return csound->InitError(csound, Str("creating socket"));
     }
     /* create server address: where we want to send to and clear it out */
     memset(&p->server_addr, 0, sizeof(p->server_addr));
@@ -559,7 +583,9 @@ static int init_raw_osc(CSOUND *csound, RAWOSC *p)
       memset(buf, 0, MTU);
     }
 
-  tabensure(csound, p->sout,2);
+    csound->RegisterDeinitCallback(csound, (void *) p, destroy_raw_osc);
+    tabensure(csound, p->sout,2);
+
   return OK;
 }
 
@@ -572,7 +598,7 @@ static inline char le_test(){
 }
 
 static inline char *byteswap(char *p, int N){
-    if(le_test()) {
+    if (le_test()) {
       char tmp;
       int j ;
       for(j = 0; j < N/2; j++) {
@@ -587,7 +613,7 @@ static inline char *byteswap(char *p, int N){
 static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
 
     ARRAYDAT *sout = p->sout;
-    if(sout->sizes[0] < 2 ||
+    if (sout->sizes[0] < 2 ||
        sout->dimensions > 1)
       return
         csound->PerfError(csound, p->h.insdshead, Str("output array too small\n"));
@@ -598,18 +624,18 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
     char c;
     memset(buf, 0, p->buffer.size);
     uint32_t size = 0;
-    char *types;
+    char *types  = NULL;
     struct sockaddr from;
     socklen_t clilen = sizeof(from);
     int bytes =
       recvfrom(p->sock, (void *)buf, MTU-1, 0, &from, &clilen);
-    if(bytes < 0) bytes = 0;
+    if (bytes < 0) bytes = 0;
 
     // terminating string to satisfy coverity
     buf[p->buffer.size-1] = '\0';
 
-    if(bytes) {
-      if(strncmp(buf,"#bundle",7) == 0) { // bundle
+    if (bytes) {
+      if (strncmp(buf,"#bundle",7) == 0) { // bundle
         buf += 8;
         buf += 8;
         size = *((uint32_t *) buf);
@@ -618,11 +644,11 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
       } else size = bytes;
       while(size > 0 && size < MTU)  {
         /* get address & types */
-        if(n < sout->sizes[0]) {
+        if (n < sout->sizes[0]) {
           len = strlen(buf);
           // printf("len %d size %d incr %d\n",
           //        len, str[n].size, ((size_t) ceil((len+1)/4.)*4));
-          if(len >= str[n].size) {
+          if (len >= str[n].size) {
             str[n].data = csound->ReAlloc(csound, str[n].data, len+1);
             memset(str[n].data,0,len+1);
             str[n].size  = len+1;
@@ -634,7 +660,7 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
         }
         if (n < sout->sizes[0]) {
           len = strlen(buf);
-          if(len >= str[n].size) {
+          if (len >= str[n].size) {
             str[n].data = csound->ReAlloc(csound, str[n].data, len+1);
             str[n].size  = len+1;
           }
@@ -647,10 +673,10 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
         j = 1;
         // parse data
         while((c = types[j++]) != '\0' && n < sout->sizes[0]){
-          if(c == 'f') {
+          if (c == 'f') {
             float f = *((float *) buf);
             byteswap((char*)&f,4);
-            if(str[n].size < 32) {
+            if (str[n].size < 32) {
               str[n].data = csound->ReAlloc(csound, str[n].data, 32);
               str[n].size  = 32;
             }
@@ -659,7 +685,7 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
           } else if (c == 'i') {
             int d = *((int32_t *) buf);
             byteswap((char*) &d,4);
-            if(str[n].size < 32) {
+            if (str[n].size < 32) {
               str[n].data = csound->ReAlloc(csound, str[n].data, 32);
               str[n].size  = 32;
             }
@@ -667,7 +693,7 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
             buf += 4;
           } else if (c == 's') {
             len = strlen(buf);
-            if(len > str[n].size) {
+            if (len > str[n].size) {
               str[n].data = csound->ReAlloc(csound, str[n].data, len+1);
               str[n].size  = len+1;
             }
@@ -679,7 +705,7 @@ static int perf_raw_osc(CSOUND *csound, RAWOSC *p) {
             len = *((uint32_t *) buf);
             byteswap((char*)&len,4);
             len = ceil((len)/4.)*4;
-            if(len > str[n].size) {
+            if (len > str[n].size) {
               str[n].data = csound->ReAlloc(csound, str[n].data, len+1);
               str[n].size  = len+1;
             }
