@@ -86,8 +86,8 @@ static int init_send(CSOUND *csound, SOCKSEND *p)
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
     p->ff = (int)(*p->format);
     p->bsize = bsize = (int) *p->buffersize;
@@ -211,7 +211,7 @@ static int send_send_Str(CSOUND *csound, SOCKSENDT *p)
     char    *q = p->str->data;
     int     len = p->str->size;
 
-    if (len>=buffersize) {
+    if (UNLIKELY(len>=buffersize)) {
       csound->Warning(csound, Str("string truncated in socksend"));
       len = buffersize-1;
     }
@@ -235,8 +235,8 @@ static int init_sendS(CSOUND *csound, SOCKSENDS *p)
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
 
     p->ff = (int)(*p->format);
@@ -334,8 +334,8 @@ static int init_ssend(CSOUND *csound, SOCKSEND *p)
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
 
     /* create a STREAM (TCP) socket in the INET (IP) protocol */
@@ -365,8 +365,8 @@ static int init_ssend(CSOUND *csound, SOCKSEND *p)
     p->server_addr.sin_port = htons((int) *p->port);
 
  again:
-    if (connect(p->sock, (struct sockaddr *) &p->server_addr,
-                sizeof(p->server_addr)) < 0) {
+    if (UNLIKELY(connect(p->sock, (struct sockaddr *) &p->server_addr,
+                         sizeof(p->server_addr)) < 0)) {
 #ifdef ECONNREFUSED
       if (errno == ECONNREFUSED)
         goto again;
@@ -383,7 +383,7 @@ static int send_ssend(CSOUND *csound, SOCKSEND *p)
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     int32_t n = sizeof(MYFLT) * (CS_KSMPS-offset-early);
 
-    if (n != write(p->sock, &p->asig[offset], n)) {
+    if (UNLIKELY(n != write(p->sock, &p->asig[offset], n))) {
       csound->Message(csound, Str("Expected %d got %d\n"),
                       (int) (sizeof(MYFLT) * CS_KSMPS), n);
       return csound->PerfError(csound, p->h.insdshead,
@@ -413,16 +413,17 @@ typedef struct {
 static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
 {
     unsigned int     bsize;
-    if(p->INOCOUNT < (unsigned int) p->type->size + 4)
-      return csound->InitError(csound,
-                               Str("insufficient number of arguments for "
-                                   "OSC message types\n"));
+
+    if (UNLIKELY(p->INOCOUNT > 4 && p->INOCOUNT < (unsigned int) p->type->size + 4))
+       return csound->InitError(csound,
+                             Str("insufficient number of arguments for "
+                                 "OSC message types\n"));
 
 #if defined(WIN32) && !defined(__CYGWIN__)
     WSADATA wsaData = {0};
     int err;
-    if ((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0)
-      csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
+    if (UNLIKELY((err=WSAStartup(MAKEWORD(2,2), &wsaData))!= 0))
+      return csound->InitError(csound, Str("Winsock2 failed to start: %d"), err);
 #endif
     p->sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (UNLIKELY(p->sock < 0)) {
@@ -440,7 +441,8 @@ static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
 #endif
     p->server_addr.sin_port = htons((int) *p->port);    /* the port */
 
-    if (p->types.auxp == NULL || strlen(p->type->data) > p->types.size)
+    if(p->INCOUNT > 4) {
+              if (p->types.auxp == NULL || strlen(p->type->data) > p->types.size)
       /* allocate space for the types buffer */
       csound->AuxAlloc(csound, strlen(p->type->data), &p->types);
     memcpy(p->types.auxp, p->type->data, strlen(p->type->data));
@@ -455,7 +457,7 @@ static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
     for(i=0; i < p->type->size-1; i++) {
       switch(p->type->data[i]){
       case 't':
-        if(p->INOCOUNT < (unsigned int) p->type->size + 5)
+        if (UNLIKELY(p->INOCOUNT < (unsigned int) p->type->size + 5))
           return csound->InitError(csound, "extra argument needed for type t\n");
         bsize += 8;
         iarg+=2;
@@ -468,7 +470,7 @@ static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
         iarg++;
         break;
       case 's':
-        if(!IS_STR_ARG(p->arg[i]))
+        if (UNLIKELY(!IS_STR_ARG(p->arg[i])))
           return csound->InitError(csound, Str("expecting a string argument\n"));
         s = (STRINGDAT *)p->arg[i];
         bsize += strlen(s->data) + 64;
@@ -477,6 +479,7 @@ static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
       case 'l':
       case 'h': /* OSC-accepted type name for 64bit int */
         p->type->data[i] = 'h';
+        /* fall through */
       case 'd':
         bsize += 8;
         iarg++;
@@ -516,6 +519,18 @@ static int osc_send2_init(CSOUND *csound, OSCSEND2 *p)
       memset(p->aux.auxp, 0, bsize);
     }
     p->iargs = iarg;
+    } else {
+      bsize = strlen(p->dest->data)+1;
+      bsize = ceil(bsize/4.)*4;;
+    if (p->aux.auxp == NULL || bsize > p->aux.size)
+      /* allocate space for the buffer */
+      csound->AuxAlloc(csound, bsize, &p->aux);
+    else {
+      memset(p->aux.auxp, 0, bsize);
+    }
+
+    }
+
     p->last = FL(0.0);
     return OK;
 }
@@ -563,6 +578,7 @@ static int osc_send2(CSOUND *csound, OSCSEND2 *p)
       memcpy(out,p->dest->data,size);
       size = ceil(size/4.)*4;
       buffersize += size;
+      if(p->INCOUNT > 4) {
       /* package type in a 4-byte zero-padded block;
          add a comma to the beginning of the type string.
       */
@@ -752,6 +768,7 @@ static int osc_send2(CSOUND *csound, OSCSEND2 *p)
           break;
         }
       }
+      }
       if (UNLIKELY(sendto(p->sock, (void*)out, buffersize, 0, to,
                           sizeof(p->server_addr)) < 0)) {
         return csound->PerfError(csound, p->h.insdshead, Str("OSCsend2 failed"));
@@ -778,7 +795,7 @@ static OENTRY socksend_localops[] = {
     (SUBR) send_sendS },
   { "stsend", S(SOCKSEND), 0, 5, "", "aSi", (SUBR) init_ssend, NULL,
     (SUBR) send_ssend },
-  { "OSCsend", S(OSCSEND2), 0, 3, "", "kSkSS*", (SUBR)osc_send2_init,
+  { "OSCsend", S(OSCSEND2), 0, 3, "", "kSk*", (SUBR)osc_send2_init,
     (SUBR)osc_send2 }
 };
 
