@@ -23,7 +23,7 @@
 
 /* ----- spat3d, spat3di, and spat3dt -- written by Istvan Varga, 2001 ----- */
 
-#include "csdl.h"
+#include "stdopcod.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
@@ -45,7 +45,7 @@ static int    spat3d_init_window(CSOUND *csound, SPAT3D *p)
     o = p->oversamp << 5;           /* window size = 32 * oversample */
 
     i = ((o + 1) * (sizeof(int) + sizeof(MYFLT)));      /* allocate */
-    if ((p->fltr.auxp == NULL) || (p->fltr.size < i))   /* space    */
+    if ((p->fltr.auxp == NULL) || (p->fltr.size < (unsigned int)i)) /* space */
       csound->AuxAlloc(csound, i, &(p->fltr));
     p->sample = (int *) p->fltr.auxp;                 /* sample number */
     p->window = (MYFLT *) (p->sample + o + 1);        /* window value  */
@@ -115,7 +115,7 @@ static SPAT3D_WALL*
 spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
                  int    wallno,         /* wall number                      */
                  int    dep,            /* recursion depth                  */
-                 long   *wmax,          /* wall structure number            */
+                 int32   *wmax,          /* wall structure number            */
                  MYFLT  X, MYFLT Y, MYFLT Z) /* coordinates (spat3di/spat3dt) */
 {
     int             i;
@@ -207,8 +207,8 @@ spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
       /* extend delay buffer */
       if ((MYFLT) d0 > p->mdel) p->mdel = (MYFLT) d0;
       if ((MYFLT) d1 > p->mdel) p->mdel = (MYFLT) d1;
-      ws->D0 = d0 * (double) csound->esr + 0.5;
-      ws->D1 = d1 * (double) csound->esr + 0.5;
+      ws->D0 = d0 * (double) CS_ESR + 0.5;
+      ws->D1 = d1 * (double) CS_ESR + 0.5;
       ws->W0 = w; ws->X0 = x; ws->Y0 = y; ws->Z0 = z;
     }
 
@@ -230,14 +230,14 @@ spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
 
 static int spat3d_init_delay(CSOUND *csound, SPAT3D *p)
 {
-    long    i, j;
+    int32    i, j;
 
-    i = ((long) (p->mdel * csound->esr) + (long) csound->ksmps + 34L)
-        * (long) p->oversamp;
+    i = ((int32) (p->mdel * CS_ESR) + (int32) CS_KSMPS + 34L)
+        * (int32) p->oversamp;
     p->mdel_s = i;
     if (p->o_num == 1) i += 4;      /* extra samples for spat3d */
-    j = i * (long) sizeof(MYFLT) * (long) (p->zout > 3 ? 4 : p->zout + 1);
-    if ((p->del.auxp == NULL) || (p->del.size < j))         /* allocate */
+    j = i * (int32) sizeof(MYFLT) * (int32) (p->zout > 3 ? 4 : p->zout + 1);
+    if ((p->del.auxp == NULL) || (p->del.size < (unsigned int)j)) /* allocate */
       csound->AuxAlloc(csound, j, &(p->del));               /* space    */
     p->Wb = (MYFLT *) p->del.auxp;                  /* W */
     if (p->zout > 0) p->Yb = p->Wb + i;             /* Y */
@@ -266,7 +266,7 @@ static int spat3d_init_delay(CSOUND *csound, SPAT3D *p)
 
 /* count reflections */
 
-static void spat3d_count_refl(long *cnt, int *md,
+static void spat3d_count_refl(int32 *cnt, int *md,
                               int d, int mdep, int w, int wm)
 {
     int     j;
@@ -285,14 +285,14 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 {
     int     xidist, xift, ximode, ximdel, xiovr, xirlen, xioutft;
     int     d, wmask;
-    long    i;
+    int32    i;
 
     /* default settings */
 
     p->ftable = p->outft = NULL;    /* no ftables */
     p->zout = p->rseed = p->mindep = p->maxdep = p->outftlnth = wmask = 0;
     p->oversamp = 1;                /* oversample */
-    p->bs = (int) csound->ksmps;    /* block size */
+    p->bs = (int) CS_KSMPS;    /* block size */
     p->irlen = 2;                   /* IR length  */
     p->mdist = p->mdel = FL(0.001); /* unit circle dist., max. delay */
     p->mdel_s = p->del_p = 0L;
@@ -318,7 +318,7 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
       p->mdist = *(p->args[xidist]);
     if (xift >= 0) {                                /* ftable */
       int fLen;
-      fLen = csound->GetTable(csound, &(p->ftable), (int) *(p->args[xift]));
+      fLen = csoundGetTable(csound, &(p->ftable), (int) *(p->args[xift]));
       if (fLen < 53)
         p->ftable = NULL;
     }
@@ -327,10 +327,10 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
     if (xiovr >= 0)                                 /* oversample */
       p->oversamp = (int) MYFLT2LRND(*(p->args[xiovr]));
     if (xirlen >= 0)                                /* IR length */
-      p->irlen = (int) MYFLT2LRND(*(p->args[xirlen]) * csound->esr);
+      p->irlen = (int) MYFLT2LRND(*(p->args[xirlen]) * CS_ESR);
     if (xioutft >= 0) {                             /* output table */
       int fLen;
-      fLen = csound->GetTable(csound, &(p->outft), (int) *(p->args[xioutft]));
+      fLen = csoundGetTable(csound, &(p->outft), (int) *(p->args[xioutft]));
       if (fLen < 1) {
         p->outft = NULL; p->outftlnth = 0;
       }
@@ -352,12 +352,12 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
       if (p->ftable[2] >= FL(0.0))            /* max. delay        */
         p->mdel = p->ftable[2];
       if (p->ftable[3] >= FL(0.0))            /* IR length         */
-        p->irlen = (int) MYFLT2LRND(p->ftable[3] * csound->esr);
+        p->irlen = (int) MYFLT2LRND(p->ftable[3] * CS_ESR);
       if (p->ftable[4] >= FL(0.0))            /* unit circle dist. */
         p->mdist = p->ftable[4];
-      p->rseed = (long) MYFLT2LRND(p->ftable[5]);     /* seed      */
+      p->rseed = (int32) MYFLT2LRND(p->ftable[5]);     /* seed      */
       if (p->rseed < 0L)
-        p->rseed = (long) csound->GetRandomSeedFromTime() & 0xFFFFL;
+        p->rseed = (int32) csound->GetRandomSeedFromTime() & 0xFFFFL;
       for (i = 6; i; i--) {                   /* wall mask         */
         wmask <<= 1; if (p->ftable[i*8 - 2] > FL(0.5)) wmask++;
       }
@@ -380,12 +380,12 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
     if (p->maxdep >= 0) {
       i = d = 0; spat3d_count_refl(&i, &d, 0, p->maxdep, 0, wmask);
-      i *= (long) sizeof(SPAT3D_WALL);
-      if ((p->ws.auxp == NULL) || (p->ws.size < i))
+      i *= (int32) sizeof(SPAT3D_WALL);
+      if ((p->ws.auxp == NULL) || (p->ws.size < (unsigned int)i))
         csound->AuxAlloc(csound, i, &(p->ws));
-      i = (long) p->bs * (long) d;
-      i *= (long) sizeof(MYFLT);
-      if ((p->y.auxp == NULL) || (p->y.size < i))
+      i = (int32) p->bs * (int32) d;
+      i *= (int32) sizeof(MYFLT);
+      if ((p->y.auxp == NULL) || (p->y.size < (unsigned int)i))
         csound->AuxAlloc(csound, i, &(p->y));
     }
     return OK;
@@ -397,7 +397,7 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
 static int    spat3dset(CSOUND *csound, SPAT3D *p)
 {
-    long    wmax;
+    int32    wmax;
 
     if (*(p->args[13]) != FL(0.0)) return OK; /* skip init    */
     p->o_num = 1;                             /* opcode number         */
@@ -416,7 +416,7 @@ static int    spat3dset(CSOUND *csound, SPAT3D *p)
 
 static int    spat3diset(CSOUND *csound, SPAT3D *p)
 {
-    long    wmax;
+    int32    wmax;
 
     if (*(p->args[11]) != FL(0.0)) return OK; /* skip init             */
     p->o_num = 0;                             /* opcode number         */
@@ -444,7 +444,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
     MYFLT       *yn, W0, X0, Y0, Z0, *Wb, *Xb, *Yb, *Zb;
     MYFLT       a, d, w, x, y, z, wd, xd, yd, zd, x1;
     double      d0, d1, d0d, d1d, D0, D1;
-    long        xpos, nn, pos;
+    int32        xpos, nn, pos;
 
     yn = ws->yn; D0 = ws->D0; D1 = ws->D1; pos = p->del_p;
     W0 = ws->W0; X0 = ws->X0; Y0 = ws->Y0; Z0 = ws->Z0;
@@ -478,17 +478,17 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
       d = SPAT3D_XYZ2DIST(x, Y, Z);             /* distance  */
       d1 = (double) SPAT3D_DIST2DEL(d);         /* delay     */
       a = SPAT3D_DIST2AMP(d);                   /* amp.      */
-      z = (MYFLT) sqrt(1.0 + (double) (x / (d + FL(0.0001))));
+      z = SQRT(FL(1.0) + (x / (d + FL(0.0001))));
       z *= a; y = a - z;                        /* Rh, Rl    */
       x += p->mdist;                            /* left channel */
       d = SPAT3D_XYZ2DIST(x, Y, Z);             /* distance  */
       d0 = (double) SPAT3D_DIST2DEL(d);         /* delay     */
       a = SPAT3D_DIST2AMP(d);                   /* amp.      */
-      x = (MYFLT) sqrt(1.0 - (double) (x / (d + FL(0.0001))));
+      x = SQRT(FL(1.0) - (x / (d + FL(0.0001))));
       x *= a; w = a - x;                                /* Lh, Ll   */
-      d1 *= (double) p->oversamp * (double) csound->esr;/* convert  */
+      d1 *= (double) p->oversamp * (double) CS_ESR;/* convert  */
     }                                                   /* delay to */
-    d0 *= (double) p->oversamp * (double) csound->esr;  /* samples  */
+    d0 *= (double) p->oversamp * (double) CS_ESR;  /* samples  */
 
     /* interpolate W, X, Y, Z, and delay */
 
@@ -518,7 +518,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
 
       /* write to delay buffer with cubic interpolation */
 
-      xpos = (long) (D0 += d0d);
+      xpos = (int32) (D0 += d0d);
       x1 = (MYFLT) (D0 - (double) (xpos--));
       z = x1 * x1; z--; z *= FL(0.1666666667);
       y = x1; y++; w = (y *= FL(0.5)); w--;
@@ -546,7 +546,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
       case 4:   Xb = p->Xb + xpos; X0 += xd;    /* Lh */
         *(Xb++) += w * X0; *(Xb++) += x * X0;
         *(Xb++) += y * X0; *Xb += z * X0;
-        xpos = (long) (D1 += d1d);
+        xpos = (int32) (D1 += d1d);
         x1 = (MYFLT) (D1 - (double) (xpos--));
         z = x1 * x1; z--; z *= FL(0.1666666667);
         y = x1; y++; w = (y *= FL(0.5)); w--;
@@ -584,7 +584,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
 
 static int    spat3d(CSOUND *csound, SPAT3D *p)
 {
-    long        nn, i, j;
+    int32        nn, i, j;
     MYFLT       *aoutW, *aoutX, *aoutY, *aoutZ, w;
 
     /* assign object data to local variables */
@@ -599,9 +599,7 @@ static int    spat3d(CSOUND *csound, SPAT3D *p)
 
     if (p->maxdep < 0) return OK;  /* depth < 0 : nothing to render */
 
-    if ((p->ws.auxp == NULL) || (p->y.auxp == NULL)) {
-      return csound->PerfError(csound, Str("spat3d: not initialised"));
-    }
+    if (UNLIKELY((p->ws.auxp == NULL) || (p->y.auxp == NULL))) goto err1;
 
     /* spatialize and send to delay line */
 
@@ -662,6 +660,9 @@ static int    spat3d(CSOUND *csound, SPAT3D *p)
         p->del_p -= p->mdel_s;
     }
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("spat3d: not initialised"));
 }
 
 /* -------------------------- spat3di performance -------------------------- */
@@ -673,15 +674,15 @@ static void spat3di_wall_perf(SPAT3D        *p,     /* opcode struct    */
                               SPAT3D_WALL   *ws)    /* wall params      */
 {
     MYFLT       *yn, *Wb, *Xb, *Yb, *Zb, w, x, y, z;
-    long        xpos0, xpos1, nn, bs;
+    int32        xpos0, xpos1, nn, bs;
 
     yn = ws->yn;
     bs = p->mdel_s;
-    xpos0 = (long) ws->D0 + p->del_p; while (xpos0 >= bs) xpos0 -= bs;
+    xpos0 = (int32) ws->D0 + p->del_p; while (xpos0 >= bs) xpos0 -= bs;
     xpos1 = xpos0; Wb = Xb = Yb = Zb = NULL;
     w = ws->W0; x = ws->X0; y = ws->Y0; z = ws->Z0;
     switch (p->zout) {
-    case 4:     xpos1 = (long) ws->D1 + p->del_p;
+    case 4:     xpos1 = (int32) ws->D1 + p->del_p;
       while (xpos1 >= bs) xpos1 -= bs;
     case 3:     Zb = p->Zb + xpos1;             /* Z / Rh */
     case 2:     Xb = p->Xb + xpos0;             /* X / Lh */
@@ -738,7 +739,7 @@ static void spat3di_wall_perf(SPAT3D        *p,     /* opcode struct    */
 
 static int    spat3di(CSOUND *csound, SPAT3D *p)
 {
-    long        nn;
+    int32        nn;
     MYFLT       *a_outW, *a_outX, *a_outY, *a_outZ;
 
     /* assign object data to local variables */
@@ -754,9 +755,7 @@ static int    spat3di(CSOUND *csound, SPAT3D *p)
 
     if (p->maxdep < 0) return OK;  /* depth < 0 : nothing to render */
 
-    if ((p->ws.auxp == NULL) || (p->y.auxp == NULL)) {
-      return csound->PerfError(csound, Str("spat3di: not initialised"));
-    }
+    if (UNLIKELY((p->ws.auxp == NULL) || (p->y.auxp == NULL))) goto err1;
 
     /* spatialize and send to delay line */
 
@@ -779,6 +778,9 @@ static int    spat3di(CSOUND *csound, SPAT3D *p)
       if (++(p->del_p) >= p->mdel_s) p->del_p -= p->mdel_s;
     } while (--nn);
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("spat3di: not initialised"));
 }
 
 /* ---------------------------- spat3dt opcode ----------------------------- */
@@ -790,12 +792,12 @@ static void spat3dt_wall_perf(SPAT3D        *p,     /* opcode struct    */
                               SPAT3D_WALL   *ws)    /* wall params      */
 {
     MYFLT       *yn, *Wb, *Yb, *endp, w, x, y, z, a, d, ad, yw;
-    long        nn;
+    int32        nn;
 
     yn = ws->yn;
     endp = p->outft;            /* write to ftable      */
-    Wb = endp + ((long) ws->D0 << 2);
-    Yb = (p->zout < 4 ? Wb : endp + ((long) ws->D1 << 2)) + 2;
+    Wb = endp + ((int32) ws->D0 << 2);
+    Yb = (p->zout < 4 ? Wb : endp + ((int32) ws->D1 << 2)) + 2;
     endp += p->outftlnth;       /* end of table         */
 
     w = ws->W0; x = ws->X0; y = ws->Y0; z = ws->Z0;
@@ -838,7 +840,7 @@ static void spat3dt_wall_perf(SPAT3D        *p,     /* opcode struct    */
 
 static int    spat3dt(CSOUND *csound, SPAT3D *p)
 {
-    long    wmax;
+    int32    wmax;
     MYFLT   *ir;
 
     p->o_num = 2;                           /* opcode number         */
@@ -848,19 +850,20 @@ static int    spat3dt(CSOUND *csound, SPAT3D *p)
     spat3d_init_wall(p, 0, 0, &wmax,
                      *(p->args[1]), *(p->args[2]), *(p->args[3]));
     p->outftlnth = ((p->outftlnth) >> 2) << 2;      /* table length  */
-    if ((p->outft == NULL) || (p->outftlnth < 4)) return NOTOK; /* no table */
+    if (UNLIKELY((p->outft == NULL) || (p->outftlnth < 4)))
+      return NOTOK;                         /* no table */
 
     /* initialise IR */
 
-    ir = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT) * (long) p->bs);
+    ir = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT) * (int32) p->bs);
     ir[0] = FL(1.0);
-    wmax = 0; while (++wmax < (long) p->bs)
+    wmax = 0; while (++wmax < (int32) p->bs)
       ir[wmax] = (sizeof(MYFLT) < 8 ? FL(1.0e-24) : FL(1.0e-48));
 
-    if (*(p->args[8]) == FL(0.0))           /* clear ftable (if enabled) */
+    if (*(p->args[8]) == FL(0.0)) {          /* clear ftable (if enabled) */
       wmax = -1; while (++wmax < p->outftlnth)
         p->outft[wmax] = FL(0.0);
-
+    } /* braces added by JPff -- REVIEW */
     /* render IR */
 
     spat3dt_wall_perf(p, ir, (SPAT3D_WALL *) p->ws.auxp);
@@ -872,11 +875,11 @@ static int    spat3dt(CSOUND *csound, SPAT3D *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-    { "spat3d", S(SPAT3D), 5, "aaaa", "akkkiiiiio",
+    { "spat3d", S(SPAT3D), 0, 5, "aaaa", "akkkiiiiio",
                     (SUBR) spat3dset,   NULL,   (SUBR) spat3d   },
-    { "spat3di",S(SPAT3D), 5, "aaaa", "aiiiiiio",
+    { "spat3di",S(SPAT3D), 0, 5, "aaaa", "aiiiiiio",
                     (SUBR) spat3diset,  NULL,   (SUBR) spat3di  },
-    { "spat3dt",S(SPAT3D), 1, "", "iiiiiiiio",
+    { "spat3dt",S(SPAT3D), 0, 1, "", "iiiiiiiio",
                     (SUBR) spat3dt,     NULL,   NULL            }
 };
 
