@@ -22,7 +22,7 @@
     02111-1307 USA
 */
 
-#include "csdl.h"               /*                      UGENS7.C        */
+#include "stdopcod.h"               /*                      UGENS7.C        */
 #include "ugens7.h"
 #include <math.h>
 
@@ -33,20 +33,20 @@ static   int    newpulse(CSOUND *, FOFS *, OVRLAP *, MYFLT *, MYFLT *, MYFLT *);
 static int fofset0(CSOUND *csound, FOFS *p, int flag)
 {
     int skip = (*p->iskip != FL(0.0) && p->auxch.auxp != 0);
-    if ((p->ftp1 = csound->FTFind(csound, p->ifna)) != NULL &&
-        (p->ftp2 = csound->FTFind(csound, p->ifnb)) != NULL) {
+    if (LIKELY((p->ftp1 = csound->FTFind(csound, p->ifna)) != NULL &&
+               (p->ftp2 = csound->FTFind(csound, p->ifnb)) != NULL)) {
       OVRLAP *ovp, *nxtovp;
-      long   olaps;
-      p->durtogo = (long)(*p->itotdur * csound->esr);
+      int32  olaps;
+      p->durtogo = (int32)(*p->itotdur * CS_ESR);
       if (!skip) { /* legato: skip all memory management */
         if (*p->iphs == FL(0.0))                /* if fundphs zero,  */
           p->fundphs = MAXLEN;                  /*   trigger new FOF */
-        else p->fundphs = (long)(*p->iphs * FMAXLEN) & PHMASK;
-        if ((olaps = (long)*p->iolaps) <= 0) {
+        else p->fundphs = (int32)(*p->iphs * FMAXLEN) & PHMASK;
+        if (UNLIKELY((olaps = (int32)*p->iolaps) <= 0)) {
           return csound->InitError(csound, Str("illegal value for iolaps"));
         }
         if (*p->iphs >= FL(0.0))
-          csound->AuxAlloc(csound, (long)olaps * sizeof(OVRLAP), &p->auxch);
+          csound->AuxAlloc(csound, (size_t)olaps * sizeof(OVRLAP), &p->auxch);
         ovp = &p->basovrlap;
         nxtovp = (OVRLAP *) p->auxch.auxp;
         do {
@@ -59,13 +59,13 @@ static int fofset0(CSOUND *csound, FOFS *p, int flag)
         p->fofcount = -1;
         p->prvband = FL(0.0);
         p->expamp = FL(1.0);
-        p->prvsmps = 0L;
+        p->prvsmps = (int32)0;
         p->preamp = FL(1.0);
       } /* end of legato code */
-      p->xincod   = (p->XINCODE & 0x7) ? 1 : 0;
-      p->ampcod   = (XINARG1) ? 1 : 0;
-      p->fundcod  = (XINARG2) ? 1 : 0;
-      p->formcod  = (XINARG3) ? 1 : 0;
+      p->ampcod   = IS_ASIG_ARG(p->xamp) ? 1 : 0;
+      p->fundcod  = IS_ASIG_ARG(p->xfund) ? 1 : 0;
+      p->formcod  = IS_ASIG_ARG(p->xform) ? 1 : 0;
+      p->xincod   = p->ampcod || p->fundcod || p->formcod;
       if (flag)
         p->fmtmod = (*p->ifmode == FL(0.0)) ? 0 : 1;
     }
@@ -86,39 +86,43 @@ static int fofset2(CSOUND *csound, FOFS *p)
 
 static int fof(CSOUND *csound, FOFS *p)
 {
-    OVRLAP *ovp;
+    OVRLAP  *ovp;
     FUNC    *ftp1,  *ftp2;
     MYFLT   *ar, *amp, *fund, *form;
-    long   nsmps = csound->ksmps, fund_inc, form_inc;
-    MYFLT  v1, fract ,*ftab;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
+    int32   fund_inc, form_inc;
+    MYFLT   v1, fract ,*ftab;
 
-    if (p->auxch.auxp==NULL) { /* RWD fix */
-      return csound->PerfError(csound, Str("fof: not initialised"));
-    }
+    if (UNLIKELY(p->auxch.auxp==NULL)) goto err1; /* RWD fix */
     ar = p->ar;
     amp = p->xamp;
     fund = p->xfund;
     form = p->xform;
     ftp1 = p->ftp1;
     ftp2 = p->ftp2;
-    fund_inc = (long)(*fund * csound->sicvt);
-    form_inc = (long)(*form * csound->sicvt);
-    do {
+    fund_inc = (int32)(*fund * csound->sicvt);
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    form_inc = (int32)(*form * csound->sicvt);
+    for (n=offset; n<nsmps; n++) {
       if (p->fundphs & MAXLEN) {               /* if phs has wrapped */
         p->fundphs &= PHMASK;
-        if ((ovp = p->basovrlap.nxtfree) == NULL) {
-          return csound->PerfError(csound, Str("FOF needs more overlaps"));
-        }
+        if ((ovp = p->basovrlap.nxtfree) == NULL) goto err2;
         if (newpulse(csound, p, ovp, amp, fund, form)) {   /* init new fof */
           ovp->nxtact = p->basovrlap.nxtact;     /* & link into  */
           p->basovrlap.nxtact = ovp;             /*   actlist    */
           p->basovrlap.nxtfree = ovp->nxtfree;
         }
       }
-      *ar = FL(0.0);
+      ar[n] = FL(0.0);
       ovp = &p->basovrlap;
       while (ovp->nxtact != NULL) {         /* perform cur actlist:  */
-        MYFLT result;
+        MYFLT  result;
         OVRLAP *prvact = ovp;
         ovp = ovp->nxtact;                   /*  formant waveform  */
         fract = PFRAC1(ovp->formphs);        /* from JMC Fog*/
@@ -138,7 +142,7 @@ static int fof(CSOUND *csound, FOFS *p)
              pitch of grain at each a-rate pass (ovp->formphs is the
              index into ifna; ovp->forminc is the stepping factor that
              decides pitch) */
-          ovp->formphs += (long)(ovp->forminc + ovp->glissbas * ovp->sampct++);
+          ovp->formphs += (int32)(ovp->forminc + ovp->glissbas * ovp->sampct++);
         }
         ovp->formphs &= PHMASK;
         if (ovp->risphs < MAXLEN) {             /*  formant ris envlp */
@@ -150,12 +154,12 @@ static int fof(CSOUND *csound, FOFS *p)
           if ((ovp->decphs -= ovp->decinc) < 0)
             ovp->decphs = 0;
         }
-        *ar += (result * ovp->curamp);          /*  add wavfrm to out */
+        ar[n] += (result * ovp->curamp);        /*  add wavfrm to out */
         if (--ovp->timrem)                      /*  if fof not expird */
-          ovp->curamp *= ovp->expamp;         /*   apply bw exp dec */
+          ovp->curamp *= ovp->expamp;           /*   apply bw exp dec */
         else {
-          prvact->nxtact = ovp->nxtact;       /*  else rm frm activ */
-          ovp->nxtfree = p->basovrlap.nxtfree;/*  & ret spc to free */
+          prvact->nxtact = ovp->nxtact;         /*  else rm frm activ */
+          ovp->nxtfree = p->basovrlap.nxtfree;  /*  & ret spc to free */
           p->basovrlap.nxtfree = ovp;
           ovp = prvact;
         }
@@ -163,26 +167,31 @@ static int fof(CSOUND *csound, FOFS *p)
       p->fundphs += fund_inc;
       if (p->xincod) {
         if (p->ampcod)    amp++;
-        if (p->fundcod)   fund_inc = (long)(*++fund * csound->sicvt);
-        if (p->formcod)   form_inc = (long)(*++form * csound->sicvt);
+        if (p->fundcod)   fund_inc = (int32)(*++fund * csound->sicvt);
+        if (p->formcod)   form_inc = (int32)(*++form * csound->sicvt);
       }
       p->durtogo--;
-      ar++;
-    } while (--nsmps);
+    }
     return OK;
+ err1:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("fof: not initialised"));
+ err2:
+    return csound->PerfError(csound, p->h.insdshead,
+                             Str("FOF needs more overlaps"));
 }
 
 static int newpulse(CSOUND *csound,
                     FOFS *p, OVRLAP *ovp, MYFLT *amp, MYFLT *fund, MYFLT *form)
 {
     MYFLT   octamp = *amp, oct;
-    long   rismps, newexp = 0;
+    int32   rismps, newexp = 0;
 
-    if ((ovp->timrem = (long)(*p->kdur * csound->esr)) > p->durtogo &&
+    if ((ovp->timrem = (int32)(*p->kdur * CS_ESR)) > p->durtogo &&
         (*p->iskip==FL(0.0))) /* ringtime */
       return(0);
     if ((oct = *p->koct) > FL(0.0)) {                   /* octaviation */
-      long ioct = (long)oct, bitpat = ~(-1L << ioct);
+      int32 ioct = (int32)oct, bitpat = ~(-1L << ioct);
       if (bitpat & ++p->fofcount)
         return(0);
       if ((bitpat += 1) & p->fofcount)
@@ -190,11 +199,11 @@ static int newpulse(CSOUND *csound,
     }
     if (*fund == FL(0.0))                               /* formant phs */
       ovp->formphs = 0;
-    else ovp->formphs = (long)(p->fundphs * *form / *fund) & PHMASK;
-    ovp->forminc = (long)(*form * csound->sicvt);
+    else ovp->formphs = (int32)(p->fundphs * *form / *fund) & PHMASK;
+    ovp->forminc = (int32)(*form * csound->sicvt);
     if (*p->kband != p->prvband) {                    /* bw: exp dec */
       p->prvband = *p->kband;
-      p->expamp = (MYFLT)exp((double)(*p->kband * csound->mpidsr));
+      p->expamp =  EXP(*p->kband * csound->mpidsr);
       newexp = 1;
     }
     /* Init grain rise ftable phase. Negative kform values make
@@ -202,10 +211,10 @@ static int newpulse(CSOUND *csound,
        So insert another if-test with compensating code. */
     if (*p->kris >= csound->onedsr && *form != FL(0.0)) {   /* init fnb ris */
       if (*form < FL(0.0) && ovp->formphs != 0)
-        ovp->risphs = (long)((MAXLEN - ovp->formphs) / -*form / *p->kris);
+        ovp->risphs = (int32)((MAXLEN - ovp->formphs) / -*form / *p->kris);
       else
-        ovp->risphs = (long)(ovp->formphs / *form / *p->kris);
-      ovp->risinc = (long)(csound->sicvt / *p->kris);
+        ovp->risphs = (int32)(ovp->formphs / *form / *p->kris);
+      ovp->risinc = (int32)(csound->sicvt / *p->kris);
       rismps = MAXLEN / ovp->risinc;
     }
     else {
@@ -219,13 +228,13 @@ static int newpulse(CSOUND *csound,
     }
     ovp->curamp = octamp * p->preamp;                /* set startamp  */
     ovp->expamp = p->expamp;
-    if ((ovp->dectim = (long)(*p->kdec * csound->esr)) > 0) /*  fnb dec  */
-      ovp->decinc = (long)(csound->sicvt / *p->kdec);
+    if ((ovp->dectim = (int32)(*p->kdec * CS_ESR)) > 0) /*  fnb dec  */
+      ovp->decinc = (int32)(csound->sicvt / *p->kdec);
     ovp->decphs = PHMASK;
     if (!p->foftype) {
       /* Make fof take k-rate phase increment:
          Add current iphs to initial form phase */
-      ovp->formphs += (long)(*p->iphs * FMAXLEN);           /*  krate phs */
+      ovp->formphs += (int32)(*p->iphs * FMAXLEN);           /*  krate phs */
       ovp->formphs &= PHMASK;
       /* Set up grain gliss increment: ovp->glissbas will be added to
          ovp->forminc at each pass in fof2. Thus glissbas must be
@@ -247,15 +256,17 @@ static int hrngflg=0;
 static int harmset(CSOUND *csound, HARMON *p)
 {
     MYFLT minfrq = *p->ilowest;
-    if (minfrq < FL(64.0)) {
+    if (UNLIKELY(minfrq < FL(64.0))) {
       return csound->InitError(csound, Str("Minimum frequency too low"));
     }
     if (p->auxch.auxp == NULL || minfrq < p->minfrq) {
-      long nbufs = (long)(csound->ekr * FL(3.0) / minfrq) + 1;
-      long nbufsmps = nbufs * csound->ksmps;
-      long maxprd = (long)(csound->esr / minfrq);
-      long totalsiz = nbufsmps * 5 + maxprd; /* Surely 5! not 4 */
-      csound->AuxAlloc(csound, (long)totalsiz * sizeof(MYFLT), &p->auxch);
+      int32 nbufs = (int32)(CS_EKR * FL(3.0) / minfrq) + 1;
+      int32 nbufsmps = nbufs * CS_KSMPS;
+      int32 maxprd = (int32)(CS_ESR / minfrq);
+      int32 totalsiz = nbufsmps * 5 + maxprd; /* Surely 5! not 4 */
+      /* printf("init: nbufs = %d; nbufsmps = %d; maxprd = %d; totalsiz = %d\n", */
+      /*        nbufs, nbufsmps, maxprd, totalsiz);       */
+      csound->AuxAlloc(csound, (size_t)totalsiz * sizeof(MYFLT), &p->auxch);
       p->bufp = (MYFLT *) p->auxch.auxp;
       p->midp = p->bufp + nbufsmps;        /* each >= maxprd * 3 */
       p->bufq = p->midp + nbufsmps;
@@ -266,9 +277,11 @@ static int harmset(CSOUND *csound, HARMON *p)
       p->lomaxdist = maxprd;
       p->minfrq = minfrq;
     }
-    if ((p->autoktim = MYFLT2LONG(*p->iptrkprd * csound->ekr)) < 1)
+    if ((p->autoktim = (int)/*MYFLT2LONG*/(*p->iptrkprd * CS_EKR)) < 1)
       p->autoktim = 1;
     p->autokcnt = 1;              /* init for immediate autocorr attempt */
+    printf("ekr = %f iptrk = %f, autocnt = %d; autotim = %d\n",
+           CS_EKR, *p->iptrkprd, p->autokcnt, p->autoktim);
     p->lsicvt = FL(65536.0) * csound->onedsr;
     p->cpsmode = ((*p->icpsmode != FL(0.0)));
     p->inp1 = p->bufp;
@@ -289,15 +302,30 @@ static int harmset(CSOUND *csound, HARMON *p)
     return OK;
 }
 
+#if 0
+static int cycle = 0;
+#endif
 static int harmon(CSOUND *csound, HARMON *p)
 {
     MYFLT *src1, *src2, *src3, *inp1, *inp2, *outp;
     MYFLT c1, c2, qval, *inq1, *inq2;
     MYFLT sum, minval, *minqp = NULL, *minq1, *minq2, *endp;
     MYFLT *pulstrt, lin1, lin2, lin3;
-    long  cnt1, cnt2, cnt3;
-    long  nn, nsmps, phase1, phase2, phsinc1, phsinc2, period;
+    int32  cnt1, cnt2, cnt3;
+    int32  nn, phase1, phase2, phsinc1, phsinc2, period;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
 
+    outp = p->ar;
+#if 0
+    if (early || offset) printf("early=%d, offet=%d\n", early, offset);
+#endif
+    if (UNLIKELY(offset)) memset(outp, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&outp[nsmps], '\0', early*sizeof(MYFLT));
+    }
     inp1 = p->inp1;
     inp2 = p->inp2;
     inq1 = p->inq1;
@@ -305,7 +333,7 @@ static int harmon(CSOUND *csound, HARMON *p)
     qval = p->prvq;
     if (*p->kest != p->prvest &&
         *p->kest != FL(0.0)) {    /* if new pitch estimate */
-      MYFLT estperiod = csound->esr / *p->kest;
+      MYFLT estperiod = CS_ESR / *p->kest;
       double b = 2.0 - cos((double)(*p->kest * csound->tpidsr));
       p->c2 = (MYFLT)(b - sqrt(b*b - 1.0)); /*   recalc lopass coefs */
       p->c1 = FL(1.0) - p->c2;
@@ -316,9 +344,9 @@ static int harmon(CSOUND *csound, HARMON *p)
     if (*p->kvar != p->prvar) {
       MYFLT oneplusvar = FL(1.0) + *p->kvar;
       /* prd window is prd +/- var int */
-      p->mindist = (long)(p->estprd/oneplusvar);
+      p->mindist = (int32)(p->estprd/oneplusvar);
 /*       if (p->mindist==0) p->mindist=1; */
-      p->maxdist = (long)(p->estprd*oneplusvar);
+      p->maxdist = (int32)(p->estprd*oneplusvar);
       if (p->maxdist > p->lomaxdist)
         p->maxdist = p->lomaxdist;
       p->max2dist = p->maxdist * 2;
@@ -326,10 +354,12 @@ static int harmon(CSOUND *csound, HARMON *p)
     }
     c1 = p->c1;
     c2 = p->c2;
-    for (src1 = p->asig, nsmps = csound->ksmps; nsmps--; src1++) {
-      *inp1++ = *inp2++ = *src1;              /* dbl store the wavform */
-      if (*src1 > FL(0.0))
-        qval = c1 * *src1 + c2 * qval;        /*  & its half-wave rect */
+    //printf("cycle %d\n", ++cycle);
+    for (src1 = p->asig, n = offset; n<nsmps; n++) {
+      *inp1++ = *inp2++ = src1[n];            /* dbl store the wavform */
+      //printf("src[%d] = %f\n", n, src1[n]);
+      if (src1[n] > FL(0.0))
+        qval = c1 * src1[n] + c2 * qval;      /*  & its half-wave rect */
       else qval = c2 * qval;
       *inq1++ = *inq2++ = qval;
     }
@@ -337,7 +367,8 @@ static int harmon(CSOUND *csound, HARMON *p)
       MYFLT *mid1, *mid2, *src4;
       MYFLT *autop, *maxp;
       MYFLT dsum, dinv, win, windec, maxval;
-      long  dist;
+      int32  dist;
+      //printf("AUTOCORRELATE min/max = %d,%d\n",p->mindist, p->maxdist);
       p->autokcnt = p->autoktim;
       mid2 = inp2 - p->max2dist;
       mid1 = mid2 - 1;
@@ -349,6 +380,7 @@ static int harmon(CSOUND *csound, HARMON *p)
         src2 = mid2;  src4 = mid2 + dist;
         for (win = FL(1.0), windec = dinv, nn = dist; nn--; ) {
           dsum += win * (*src1 * *src3 + *src2 * *src4);
+          //printf("dsum = %f from %f %f %f %f\n", dsum, *src1, *src2, *src3, *src4);
           src1--; src2++; src3--; src4++;
           win -= windec;
         }
@@ -358,25 +390,27 @@ static int harmon(CSOUND *csound, HARMON *p)
       maxp = autop = p->autobuf;
       endp = autop + p->maxdist - p->mindist;
       while (autop < endp) {
+        //printf("newval, maxval = %f, %f\n", *autop, maxval);
         if (*autop > maxval) {          /* max autocorr gives new period */
           maxval = *autop;
           maxp = autop;
 #if 0
-          csound->Message(csound, "new maxval %f at %ld\n", maxval, (long)maxp);
+          csound->Message(csound, "new maxval %f at %p\n", maxval, (long)maxp);
 #endif
         }
         autop++;
       }
+      //printf("**** maxval = %f ****\n", maxval);
       period = p->mindist + maxp - p->autobuf;
       if (period != p->period) {
 #if 0
-        csound->Message(csound, "New period\n");
+        csound->Message(csound, "New period %d %d\n", period, p->period);
 #endif
         p->period = period;
         if (!p->cpsmode)
           p->lsicvt = FL(65536.0) / period;
-        p->pnt1 = (long)((MYFLT)period * FL(0.2));
-        p->pnt2 = (long)((MYFLT)period * FL(0.8));
+        p->pnt1 = (int32)((MYFLT)period * FL(0.2));
+        p->pnt2 = (int32)((MYFLT)period * FL(0.8));
         p->pnt3 = period;
         p->inc1 = FL(1.0) / p->pnt1;
         p->inc2 = FL(1.0) / (period - p->pnt2);
@@ -397,15 +431,12 @@ static int harmon(CSOUND *csound, HARMON *p)
     }
     src1 = minqp - p->n2bufsmps;            /* get src equiv of 1st min  */
     if (period==0) {
-      csound->Message(csound, "Period zero\n");
+      csound->Warning(csound, Str("Period zero\n"));
       outp = p->ar;
-      nsmps = csound->ksmps;
-      do {
-        *outp++ = FL(0.0);
-      } while (nsmps--);
+      memset(outp, 0, sizeof(MYFLT)*CS_KSMPS);
       return OK;
     }
-    while (src1 + csound->ksmps > inp2)     /* if not enough smps presnt */
+    while (src1 + CS_KSMPS > inp2)     /* if not enough smps presnt */
       src1 -= period;                       /*      back up 1 prd        */
     pulstrt = src1;                         /* curr available pulse beg  */
 
@@ -420,11 +451,9 @@ static int harmon(CSOUND *csound, HARMON *p)
     cnt3 = p->cnt3;
     phase1 = p->phase1;
     phase2 = p->phase2;
-    phsinc1 = (long)(*p->kfrq1 * p->lsicvt);
-    phsinc2 = (long)(*p->kfrq2 * p->lsicvt);
-    outp = p->ar;
-    nsmps = csound->ksmps;
-    do {
+    phsinc1 = (int32)(*p->kfrq1 * p->lsicvt);
+    phsinc2 = (int32)(*p->kfrq2 * p->lsicvt);
+    for (n=offset; n<nsmps; n++) {
       MYFLT sum;
       if (src1 != NULL) {
         if (++cnt1 < p->pnt11) {
@@ -469,7 +498,7 @@ static int harmon(CSOUND *csound, HARMON *p)
         }
         else src3 = NULL;
       }
-      if ((phase1 += phsinc1) & 0xFFFF0000L) {
+      if ((phase1 += phsinc1) & (~0xFFFFL)) { /* 64bit safe! */
         phase1 &= 0x0000FFFFL;
         if (src1 == NULL) {
           src1 = pulstrt;
@@ -502,13 +531,13 @@ static int harmon(CSOUND *csound, HARMON *p)
           p->pnt33 = p->pnt3;
         }
 #if 0
-        else if (++hrngflg > 200) {
+        else if (UNLIKELY(++hrngflg > 200)) {
           csound->Message(csound, Str("harmon out of range...\n"));
           hrngflg = 0;
         }
 #endif
       }
-      if ((phase2 += phsinc2) & 0xFFFF0000L) {
+      if ((phase2 += phsinc2) & (~0xFFFFL)) {
         phase2 &= 0x0000FFFFL;
         if (src1 == NULL) {
           src1 = pulstrt;
@@ -541,14 +570,14 @@ static int harmon(CSOUND *csound, HARMON *p)
           p->pnt33 = p->pnt3;
         }
 #if 0
-        else if (++hrngflg > 200) {
+        else if (UNLIKELY(++hrngflg > 200)) {
           csound->Message(csound, Str("harmon out of range\n"));
           hrngflg = 0;
         }
 #endif
       }
-      *outp++ = sum;
-    } while (--nsmps);
+      outp[n] = sum;
+    }
     if (inp1 >= p->midp) {
       p->inp1 = p->bufp;
       p->inp2 = p->midp;
@@ -585,9 +614,9 @@ static int harmon(CSOUND *csound, HARMON *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-{ "fof",    S(FOFS),   5, "a","xxxkkkkkiiiiooo",(SUBR)fofset,NULL,(SUBR)fof   },
-{ "fof2",   S(FOFS),   5, "a","xxxkkkkkiiiikko",(SUBR)fofset2,NULL,(SUBR)fof  },
-{ "harmon", S(HARMON), 5, "a",  "akkkkiii",(SUBR)harmset,NULL,  (SUBR)harmon  }
+{ "fof",    S(FOFS),   TR, 5, "a","xxxkkkkkiiiiooo",(SUBR)fofset,NULL,(SUBR)fof   },
+{ "fof2",   S(FOFS),   TR, 5, "a","xxxkkkkkiiiikko",(SUBR)fofset2,NULL,(SUBR)fof  },
+{ "harmon", S(HARMON), 0,5, "a",  "akkkkiii",(SUBR)harmset,NULL,  (SUBR)harmon  }
 };
 
 int ugens7_init_(CSOUND *csound)
