@@ -28,7 +28,8 @@
    Ville Pulkki & John ffitch
 */
 
-#include "csdl.h"
+
+#include "csoundCore.h"
 #include "vbap.h"
 #include <math.h>
 #include <stdio.h>
@@ -42,39 +43,46 @@ int vbap_zak(CSOUND *csound, VBAP_ZAK *p)   /* during note performance: */
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int i,j;
+    int j;
     int n = p->n;
-    int nsmps = csound->ksmps;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
 
     vbap_zak_control(csound,p);
-    for (i=0; i<n; i++) {
-      p->beg_gains[i]=p->end_gains[i];
-      p->end_gains[i]=p->updated_gains[i];
+    for (j=0; j<n; j++) {
+      p->beg_gains[j] = p->end_gains[j];
+      p->end_gains[j] = p->updated_gains[j];
     }
 
     /* write audio to result audio streams weighted
        with gain factors */
-    invfloatn =  csound->onedksmps;
     outptr = p->out_array;
+    if (UNLIKELY(early)) nsmps -= early;
+    invfloatn =  FL(1.0)/(nsmps-offset);
     for (j=0; j<n; j++) {
       inptr = p->audio;
       ogain = p->beg_gains[j];
       ngain = p->end_gains[j];
       gainsubstr = ngain - ogain;
+      if (UNLIKELY(offset)) memset(outptr, '\0', offset*sizeof(MYFLT));
+      if (UNLIKELY(early)) memset(&outptr[nsmps], '\0', early*sizeof(MYFLT));
       if (ngain != FL(0.0) || ogain != FL(0.0))
         if (ngain != ogain) {
-          for (i = 0; i < nsmps; i++) {
+          for (i = offset; i < nsmps; i++) {
             outptr[i] = inptr[i] *
               (ogain + (MYFLT) (i+1) * invfloatn * gainsubstr);
           }
           p->curr_gains[j]= ogain +
             (MYFLT) (i) * invfloatn * gainsubstr;
         }
-        else
-          for (i=0; i<nsmps; ++i)
-            outptr[n] = inptr[n] * ogain;
+        else {
+          for (i=offset; i<nsmps; ++i)
+            outptr[i] = inptr[i] * ogain;
+        }
       else
         memset(outptr, 0, nsmps*sizeof(MYFLT));
+      outptr += nsmps;
     }
     return OK;
 }
@@ -84,18 +92,17 @@ int vbap_zak_control(CSOUND *csound, VBAP_ZAK *p)
     CART_VEC spreaddir[16];
     CART_VEC spreadbase[16];
     ANG_VEC atmp;
-    long i,j, spreaddirnum;
+    int32 i,j, spreaddirnum;
     int n = p->n;
     MYFLT tmp_gains[MAXCHNLS],sum = FL(0.0);
-    if (p->dim == 2 && fabs(*p->ele) > 0.0) {
-      csound->Message(csound,
+    if (UNLIKELY(p->dim == 2 && fabs(*p->ele) > 0.0)) {
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       *p->ele = FL(0.0);
     }
-
     if (*p->spread <FL(0.0))
       *p->spread=FL(0.0);
-    if (*p->spread >FL(100.0))
+    else if (*p->spread >FL(100.0))
       *p->spread=FL(100.0);
     /* Current panning angles */
     p->ang_dir.azi = (MYFLT) *p->azi;
@@ -180,7 +187,7 @@ int vbap_zak_control(CSOUND *csound, VBAP_ZAK *p)
       sum = sum+(p->updated_gains[i]*p->updated_gains[i]);
     }
 
-    sum = (MYFLT)sqrt((double)sum);
+    sum = SQRT(sum);
     for (i=0;i<n;i++) {
       p->updated_gains[i] /= sum;
     }
@@ -193,28 +200,33 @@ int vbap_zak_init(CSOUND *csound, VBAP_ZAK *p)
     MYFLT   *ls_table, *ptr; /* , *gains; */
     LS_SET  *ls_set_ptr;
     int n = p->n = (int)MYFLT2LONG(*p->numb); /* Set size */
+    char name[24];
     /* Check to see this index is within the limits of za space.    */
-    indx = (long) *p->ndx;
-    if (indx > csound->zalast) {
-      return csound->PerfError(csound, Str("outz index > isizea. No output"));
+    indx = (int32) *p->ndx;
+    if (UNLIKELY(indx > csound->zalast)) {
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("outz index > isizea. No output"));
     }
-    else if (indx < 0) {
-      return csound->PerfError(csound, Str("outz index < 0. No output."));
+    else if (UNLIKELY(indx < 0)) {
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("outz index < 0. No output."));
     }
+    if ((int)*p->layout==0) strcpy(name, "vbap_ls_table");
+    else snprintf(name, 24, "vbap_ls_table_%d", (int)*p->layout==0);
     /* Now read from the array in za space and write to the output. */
-    p->out_array     = csound->zastart + (indx * csound->ksmps);/* outputs */
+    p->out_array     = csound->zastart + (indx * CS_KSMPS);/* outputs */
     csound->AuxAlloc(csound, p->n*sizeof(MYFLT)*4, &p->auxch);
     p->curr_gains    = (MYFLT*)p->auxch.auxp;
     p->beg_gains     = p->curr_gains + p->n;
     p->end_gains     = p->beg_gains + p->n;
     p->updated_gains = p->end_gains + p->n;
-    ls_table = get_ls_table(csound);
+    ls_table = (MYFLT*) (csound->QueryGlobalVariableNoCheck(csound, name));
     p->dim           = (int) ls_table[0];   /* reading in loudspeaker info */
     p->ls_am         = (int) ls_table[1];
     p->ls_set_am     = (int) ls_table[2];
     ptr              = &(ls_table[3]);
     csound->AuxAlloc(csound, p->ls_set_am * sizeof (LS_SET), &p->aux);
-    if (p->aux.auxp == NULL) {
+    if (UNLIKELY(p->aux.auxp == NULL)) {
       return csound->InitError(csound, Str("could not allocate memory"));
     }
     p->ls_sets = (LS_SET*) p->aux.auxp;
@@ -232,8 +244,8 @@ int vbap_zak_init(CSOUND *csound, VBAP_ZAK *p)
     }
 
     /* other initialization */
-    if (p->dim == 2 && fabs(*p->ele) > 0.0) {
-      csound->Message(csound,
+    if (UNLIKELY(p->dim == 2 && fabs(*p->ele) > 0.0)) {
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       *p->ele = FL(0.0);
     }
@@ -257,19 +269,26 @@ int vbap_zak_moving(CSOUND *csound, VBAP_ZAK_MOVING *p)
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int i,j;
-    int nsmps = csound->ksmps;
+    int j;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t i, nsmps = CS_KSMPS;
 
     vbap_zak_moving_control(csound,p);
-    for (i=0;i< p->n; i++) {
-      p->beg_gains[i] = p->end_gains[i];
-      p->end_gains[i] = p->updated_gains[i];
+    for (j=0;j< p->n; j++) {
+      p->beg_gains[j] = p->end_gains[j];
+      p->end_gains[j] = p->updated_gains[j];
     }
 
-    /* write audio to resulting audio streams wEIGHTed
+    /* write audio to resulting audio streams weighted
        with gain factors */
-    invfloatn =  csound->onedksmps;
+    invfloatn =  FL(1.0)/(nsmps-offset);
     outptr = p->out_array;
+    if (UNLIKELY(offset)) memset(outptr, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&outptr[nsmps], '\0', early*sizeof(MYFLT));
+    }
     for (j=0; j<p->n ;j++) {
       inptr = p->audio;
       ogain = p->beg_gains[j];
@@ -277,7 +296,7 @@ int vbap_zak_moving(CSOUND *csound, VBAP_ZAK_MOVING *p)
       gainsubstr = ngain - ogain;
       if (ngain != FL(0.0) || ogain != FL(0.0))
         if (ngain != ogain) {
-          for (i = 0; i < nsmps; i++) {
+          for (i = offset; i < nsmps; i++) {
             outptr[i] = inptr[i] *
               (ogain + (MYFLT) (i+1) * invfloatn * gainsubstr);
           }
@@ -285,7 +304,7 @@ int vbap_zak_moving(CSOUND *csound, VBAP_ZAK_MOVING *p)
             (MYFLT) (i) * invfloatn * gainsubstr;
         }
         else
-          for (i=0; i<nsmps; ++i)
+          for (i=offset; i<nsmps; ++i)
             outptr[i] = inptr[i] * ogain;
       else
         memset(outptr, 0, nsmps*sizeof(MYFLT));
@@ -298,20 +317,20 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
     CART_VEC spreaddir[16];
     CART_VEC spreadbase[16];
     ANG_VEC atmp;
-    long i,j, spreaddirnum;
+    int32 i,j, spreaddirnum;
     int n = p->n;
     CART_VEC tmp1, tmp2, tmp3;
     MYFLT coeff, angle;
     MYFLT tmp_gains[MAXCHNLS],sum = FL(0.0); /* Array long enough */
-    if (p->dim == 2 && fabs(p->ang_dir.ele) > 0.0) {
-      csound->Message(csound,
+    if (UNLIKELY(p->dim == 2 && fabs(p->ang_dir.ele) > 0.0)) {
+      csound->Warning(csound,
                       Str("Warning: truncating elevation to 2-D plane\n"));
       p->ang_dir.ele = FL(0.0);
     }
 
     if (*p->spread <FL(0.0))
       *p->spread = FL(0.0);
-    if (*p->spread >FL(100.0))
+    else if (*p->spread >FL(100.0))
       *p->spread = FL(100.0);
     if (p->point_change_counter++ >= p->point_change_interval) {
       p->point_change_counter = 0;
@@ -331,12 +350,13 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
             p->next_fld = 1;
         }
       }
-      if ((p->fld[abs(p->next_fld)]==NULL))
-        csound->Die(csound, Str("Missing fields in vbapzmove\n"));
+      if (UNLIKELY((p->fld[abs(p->next_fld)]==NULL)))
+        return csound->PerfError(csound, p->h.insdshead,
+                                 Str("Missing fields in vbapzmove\n"));
       if (*p->field_am >= FL(0.0) && p->dim == 2) /* point-to-point */
-        if (fabs(fabs(*p->fld[p->next_fld] - *p->fld[p->curr_fld])
-                 - 180.0) < 1.0)
-          csound->Message(csound,
+        if (UNLIKELY(fabs(fabs(*p->fld[p->next_fld] - *p->fld[p->curr_fld])
+                          - 180.0) < 1.0))
+          csound->Warning(csound,
                           Str("Warning: Ambiguous transition 180 degrees.\n"));
     }
     if (*p->field_am >= FL(0.0)) { /* point-to-point */
@@ -376,20 +396,21 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
         p->ang_dir.ele = FL(0.0);
       }
       else {
-        csound->Die(csound, Str("Wrong dimension\n"));
+        return csound->PerfError(csound, p->h.insdshead,
+                                 Str("Missing fields in vbapzmove\n"));
       }
     }
     else { /* angular velocities */
       if (p->dim == 2) {
         p->ang_dir.azi = p->ang_dir.azi +
-          (*p->fld[p->next_fld] * csound->onedkr);
+          (*p->fld[p->next_fld] * CS_ONEDKR);
         scale_angles(&(p->ang_dir));
       }
       else { /* 3D angular */
         p->ang_dir.azi = p->ang_dir.azi +
-          (*p->fld[p->next_fld] * csound->onedkr);
+          (*p->fld[p->next_fld] * CS_ONEDKR);
         p->ang_dir.ele = p->ang_dir.ele +
-          p->ele_vel * (*p->fld[p->next_fld+1] * csound->onedkr);
+          p->ele_vel * (*p->fld[p->next_fld+1] * CS_ONEDKR);
         if (p->ang_dir.ele > FL(90.0)) {
           p->ang_dir.ele = FL(90.0);
           p->ele_vel = -p->ele_vel;
@@ -478,7 +499,7 @@ int vbap_zak_moving_control(CSOUND *csound, VBAP_ZAK_MOVING *p)
       sum += (p->updated_gains[i]*p->updated_gains[i]);
   }
 
-  sum = (MYFLT)sqrt((double)sum);
+  sum = SQRT(sum);
   for (i=0;i<n;i++) {
     p->updated_gains[i] /= sum;
   }
@@ -493,28 +514,31 @@ int vbap_zak_moving_init(CSOUND *csound, VBAP_ZAK_MOVING *p)
     int n = p->n;
     p->n = (int)MYFLT2LONG(*p->numb); /* Set size */
     /* Check to see this index is within the limits of za space.    */
-    indx = (long) *p->ndx;
-    if (indx > csound->zalast) {
-      return csound->PerfError(csound, Str("outz index > isizea. No output"));
+    indx = (int32) *p->ndx;
+    if (UNLIKELY(indx > csound->zalast)) {
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("outz index > isizea. No output"));
     }
-    else if (indx < 0) {
-      return csound->PerfError(csound, Str("outz index < 0. No output."));
+    else if (UNLIKELY(indx < 0)) {
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("outz index < 0. No output."));
     }
     /* Now read from the array in za space and write to the output. */
-    p->out_array     = csound->zastart + (indx * csound->ksmps);/* outputs */
+    p->out_array     = csound->zastart + (indx * CS_KSMPS);/* outputs */
     csound->AuxAlloc(csound, p->n*sizeof(MYFLT)*4, &p->auxch);
     p->curr_gains    = (MYFLT*)p->auxch.auxp;
     p->beg_gains     = p->curr_gains + p->n;
     p->end_gains     = p->beg_gains + p->n;
     p->updated_gains = p->end_gains + p->n;
     /* reading in loudspeaker info */
-    ls_table = get_ls_table(csound);
+    ls_table = (MYFLT*) (csound->QueryGlobalVariableNoCheck(csound,
+                                                        "vbap_ls_table_0"));
     p->dim           = (int) ls_table[0];
     p->ls_am         = (int) ls_table[1];
     p->ls_set_am     = (int) ls_table[2];
     ptr              = &(ls_table[3]);
     csound->AuxAlloc(csound, p->ls_set_am * sizeof (LS_SET), &p->aux);
-    if (p->aux.auxp == NULL) {
+    if (UNLIKELY(p->aux.auxp == NULL)) {
       return csound->InitError(csound, Str("could not allocate memory"));
     }
     p->ls_sets = (LS_SET*) p->aux.auxp;
@@ -524,8 +548,9 @@ int vbap_zak_moving_init(CSOUND *csound, VBAP_ZAK_MOVING *p)
       for (j=0 ; j < p->dim ; j++) {
         ls_set_ptr[i].ls_nos[j] = (int) *(ptr++);
       }
-      for (j=0 ; j < 9; j++)
-        ls_set_ptr[i].ls_mx[j] = FL(0.0);  /* initial setting */
+      memset(ls_set_ptr[i].ls_mx, '\0', 9*sizeof(MYFLT));
+      /* for (j=0 ; j < 9; j++) */
+      /*   ls_set_ptr[i].ls_mx[j] = FL(0.0);  /\* initial setting *\/ */
       for (j=0 ; j < (p->dim) * (p->dim); j++) {
         ls_set_ptr[i].ls_mx[j] = (MYFLT) *(ptr++);
       }
@@ -533,19 +558,19 @@ int vbap_zak_moving_init(CSOUND *csound, VBAP_ZAK_MOVING *p)
 
     /* other initialization */
     p->ele_vel = FL(1.0);    /* functions specific to movement */
-    if (fabs(*p->field_am) < (2+ (p->dim - 2)*2)) {
-      csound->Die(csound,
+    if (UNLIKELY(fabs(*p->field_am) < (2+ (p->dim - 2)*2))) {
+      return csound->InitError(csound,
                   Str("Have to have at least %d directions in vbapzmove"),
                   2 + (p->dim - 2) * 2);
     }
     if (p->dim == 2)
-      p->point_change_interval = (int) (csound->ekr * *p->dur
+      p->point_change_interval = (int) (CS_EKR * *p->dur
                                         / (fabs(*p->field_am) - 1.0));
-    else if (p->dim == 3)
-      p->point_change_interval = (int) (csound->ekr * *p->dur
+    else if (LIKELY(p->dim == 3))
+      p->point_change_interval = (int) (CS_EKR * *p->dur
                                         / (fabs(*p->field_am) * 0.5 - 1.0));
     else
-      csound->Die(csound, Str("Wrong dimension"));
+      return csound->InitError(csound, Str("Wrong dimension"));
     p->point_change_counter = 0;
     p->curr_fld = 0;
     p->next_fld = 1;
@@ -570,4 +595,3 @@ int vbap_zak_moving_init(CSOUND *csound, VBAP_ZAK_MOVING *p)
     }
     return OK;
 }
-
