@@ -1,8 +1,9 @@
 //  vst4cs: VST HOST OPCODES FOR CSOUND
 //
-//  Uses code by Hermann Seib from his Vst Host program
-//  and from the vst~ object by Thomas Grill,
-//  which in turn borrows from the Psycle tracker.
+//  Uses code by Hermann Seib from his VSTHost program and from the vst~
+//  object by Thomas Grill (no license), which in turn borrows from the Psycle
+//  tracker (also based on VSTHost).
+//
 //  VST is a trademark of Steinberg Media Technologies GmbH.
 //  VST Plug-In Technology by Steinberg.
 //
@@ -22,6 +23,30 @@
 //  License along with The vst4cs library; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 //  02111-1307 USA
+//
+//  Linking vst4cs statically or dynamically with other modules is making a
+//  combined work based on vst4cs. Thus, the terms and conditions of the GNU
+//  Lesser General Public License cover the whole combination.
+//
+//  In addition, as a special exception, the copyright holders of vst4cs,
+//  including the Csound developers and Hermann Seib, the original author of
+//  VSTHost, give you permission to combine vst4cs with free software programs
+//  or libraries that are released under the GNU LGPL and with code included
+//  in the standard release of the VST SDK version 2 under the terms of the
+//  license stated in the VST SDK version 2 files. You may copy and distribute
+//  such a system following the terms of the GNU LGPL for vst4cs and the
+//  licenses of the other code concerned. The source code for the VST SDK
+//  version 2 is available in the VST SDK hosted at
+//  https://github.com/steinbergmedia/vst3sdk.
+//
+//  Note that people who make modified versions of vst4cs are not obligated to
+//  grant this special exception for their modified versions; it is their
+//  choice whether to do so. The GNU Lesser General Public License gives
+//  permission to release a modified version without this exception; this
+//  exception also makes it possible to release a modified version which
+//  carries forward this exception.
+
+// Linux only: #define CSOUND_LIFECYCLE_DEBUG
 
 #ifdef _WIN32
 #pragma warning(disable:4786) //gab
@@ -32,13 +57,20 @@
 #include <vector>
 #include <string>
 #include "vst4cs.h"
+#include <OpcodeBase.hpp>
 #include "vsthost.h"
 #include "fxbank.h"
 
+#if defined(CSOUND_LIFECYCLE_DEBUG)
+#include <unistd.h>
+#include <sys/syscall.h>
+#include <sys/types.h>
+#endif
+
 // These two collections replace similar ones that used to be in widglobals.h.
 
-static std::vector<VSTPlugin*> *vstPlugEditors = 0;
-static std::vector<VSTPlugin*> *vstPlugins = 0;
+//typedef std::vector<VSTEDIT*> vstPlugEditors_t;
+typedef std::vector<VSTPlugin*> vstPlugins_t;
 
 extern "C" {
     std::string version = "0.2";
@@ -55,16 +87,18 @@ extern "C" {
     {
         VSTINIT *p = (VSTINIT *) data;
         VSTPlugin *plugin = new VSTPlugin(csound);
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         *p->iVSThandle = (MYFLT) vstPlugins->size();
         vstPlugins->push_back(plugin);
         if ((int) vstPlugins->size() == 1) {
-            plugin->Log("============================================================\n");
-            plugin->Log("vst4cs version %s by Andres Cabrera and Michael Gogins\n",
+          plugin->Log("============================================================\n");
+          plugin->Log("vst4cs version %s by Andres Cabrera and Michael Gogins\n",
                         version.c_str());
-            plugin->Log("Using code from H. Seib's VstHost and T. Grill's vst~ object\n");
-            plugin->Log("VST is a trademark of Steinberg Media Technologies GmbH\n");
-            plugin->Log("VST Plug-In Technology by Steinberg\n");
-            plugin->Log("============================================================\n");
+          plugin->Log("Using code from H. Seib's VstHost and T. Grill's vst~ object\n");
+          plugin->Log("VST is a trademark of Steinberg Media Technologies GmbH\n");
+          plugin->Log("VST Plug-In Technology by Steinberg\n");
+          plugin->Log("============================================================\n");
         }
         char vstplugname[0x100];
         strncpy(vstplugname,((STRINGDAT *)p->iplugin)->data, MAXNAME-1);
@@ -72,12 +106,12 @@ extern "C" {
         path_convert(vstplugname);
 #endif
         if (plugin->Instantiate(vstplugname)) {
-            csound->InitError(csound, "vstinit: Error loading effect.");
-            csound->LongJmp(csound, 1);
+          return csound->InitError(csound, Str("vstinit: Error loading effect."));
+          csound->LongJmp(csound, 1);
         }
         plugin->Init();
         if (*p->iverbose) {
-            plugin->Info();
+          plugin->Info();
         }
         return OK;
     }
@@ -85,6 +119,8 @@ extern "C" {
     static int vstinfo(CSOUND *csound, void *data)
     {
         VSTINFO *p = (VSTINFO *) data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
         plugin->Info();
         return OK;
@@ -93,12 +129,14 @@ extern "C" {
     static int vstaudio_init(CSOUND *csound, void *data)
     {
         VSTAUDIO *p = (VSTAUDIO *) data;
-
         p->opcodeInChannels = (size_t) (csound->GetInputArgCnt(data) - 1);
         if (p->opcodeInChannels > 32) {
-            csound->InitError(csound, "vstaudio: too many input args");
+          return csound->InitError(csound, Str("vstaudio: too many input args"));
         }
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         plugin->Debug("vstaudio_init.\n");
         p->framesPerBlock = csound->GetKsmps(csound);
         p->pluginInChannels  = (size_t) plugin->getNumInputs();
@@ -111,7 +149,7 @@ extern "C" {
     {
         VSTAUDIO *p = (VSTAUDIO *) data;
         size_t  i, j;
-        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        VSTPlugin *plugin = p->vstplugin;
         uint32_t offset = p->h.insdshead->ksmps_offset;
         for(j=0; j < p->pluginOutChannels; j++) {
             memset(p->aouts[j], '\0', offset*sizeof(MYFLT));
@@ -134,7 +172,8 @@ extern "C" {
                             p->framesPerBlock);
             for (j = 0; j < p->pluginOutChannels && j < p->opcodeOutChannels; j++)
                 for (i = offset; i < p->framesPerBlock; i++) {
-                    p->aouts[j][i] = (MYFLT) plugin->outputs_[j][i] * csound->Get0dBFS(csound);
+                    p->aouts[j][i] =
+                      (MYFLT) plugin->outputs_[j][i] * csound->Get0dBFS(csound);
                 }
             for ( ; j < p->opcodeOutChannels; j++)
                 for (i = 0; i < p->framesPerBlock; i++) {
@@ -156,8 +195,8 @@ extern "C" {
     static int vstaudiog(CSOUND *csound, void *data)
     {
         VSTAUDIO *p = (VSTAUDIO *) data;
+        VSTPlugin *plugin = p->vstplugin;
         size_t  i, j;
-        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
         uint32_t offset = p->h.insdshead->ksmps_offset;
         for(j=0; j < p->pluginOutChannels; j++) {
             memset(p->aouts[j], '\0', offset*sizeof(MYFLT));
@@ -178,7 +217,8 @@ extern "C" {
                         p->framesPerBlock);
         for (j = 0; j < p->pluginOutChannels && j < p->opcodeOutChannels; j++)
             for (i = offset; i < p->framesPerBlock; i++) {
-                p->aouts[j][i] = (MYFLT) plugin->outputs_[j][i] * csound->Get0dBFS(csound);
+                p->aouts[j][i] =
+                  (MYFLT) plugin->outputs_[j][i] * csound->Get0dBFS(csound);
             }
         for ( ; j < p->opcodeOutChannels; j++)
             for (i = 0; i < p->framesPerBlock; i++) {
@@ -191,9 +231,10 @@ extern "C" {
     static int vstmidiout_init(CSOUND *csound, void *data)
     {
         VSTMIDIOUT *p = (VSTMIDIOUT *) data;
-        VSTPlugin *plugin;
-        p->vstHandle = (size_t) *p->iVSThandle;
-        plugin = (*vstPlugins)[p->vstHandle];
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
+        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         plugin->Debug("vstmidiout_init.\n");
         p->prvMidiData = 0;
         return OK;
@@ -202,7 +243,7 @@ extern "C" {
     static int vstmidiout(CSOUND *csound, void *data)
     {
         VSTMIDIOUT *p = (VSTMIDIOUT *) data;
-        VSTPlugin *plugin;
+        VSTPlugin *plugin = p->vstplugin;
         int     st, ch, d1, d2, midiData;
         st = (int) *(p->kstatus);
         if (st < 128 || st >= 240) {
@@ -231,7 +272,6 @@ extern "C" {
             return OK;
         }
         p->prvMidiData = midiData;
-        plugin = (*vstPlugins)[p->vstHandle];
         plugin->Debug("vstmidiout. kstatus = %i kdata1 = %i kdata2 = %i"
                       "--- mididata = %i\n",
                       (int) *(p->kstatus),
@@ -244,13 +284,18 @@ extern "C" {
 
     static int vstparamget_init(CSOUND *csound, void *data)
     {
+        VSTPARAMGET *p = (VSTPARAMGET *) data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
+        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         return OK;
     }
 
     static int vstparamget(CSOUND *csound, void *data)
     {
         VSTPARAMGET *p = (VSTPARAMGET *) data;
-        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        VSTPlugin *plugin = p->vstplugin;
         plugin->Debug("vstparamset(%d).\n", int(*p->kparam));
         *p->kvalue = plugin->GetParamValue(int(*p->kparam));
         if (*(p->kvalue) == FL(-1.0)) {
@@ -262,7 +307,10 @@ extern "C" {
     static int vstparamset_init(CSOUND *csound, void *data)
     {
         VSTPARAMSET *p = (VSTPARAMSET *) data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         plugin->Debug("vstparamset_init.\n");
         p->oldkparam = 0;
         p->oldkvalue = 0;
@@ -272,7 +320,7 @@ extern "C" {
     static int vstparamset(CSOUND *csound, void *data)
     {
         VSTPARAMSET *p = (VSTPARAMSET *) data;
-        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        VSTPlugin *plugin = p->vstplugin;
         if (*p->kparam == p->oldkparam && *p->kvalue == p->oldkvalue) {
             return OK;
         }
@@ -286,26 +334,29 @@ extern "C" {
     static int vstbankload(CSOUND *csound, void *data)
     {
         VSTBANKLOAD *p = (VSTBANKLOAD *) data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         void    *dummyPointer = 0;
         CFxBank fxBank((char *) p->ibank);          /* load the bank    */
         plugin->Dispatch(effBeginLoadBank,
                          0, 0, (VstPatchChunkInfo *) fxBank.GetChunk(), 0);
         if (plugin->Dispatch(effBeginLoadBank,
                              0, 0, (VstPatchChunkInfo *) fxBank.GetChunk(), 0)) {
-            csound->InitError(csound, "Error: BeginLoadBank.");
-            return NOTOK;
+          return csound->InitError(csound, Str("Error: BeginLoadBank."));
         }
         if (fxBank.IsLoaded()) {
-            if (plugin->aeffect->uniqueID != fxBank.GetFxID()) {
-                csound->InitError(csound, "Loaded bank ID doesn't match plug-in ID.");
-                return NOTOK;
+          if (plugin->aeffect->uniqueID != fxBank.GetFxID()) {
+            return
+              csound->InitError(csound,
+                                Str("Loaded bank ID doesn't match plug-in ID."));
             }
             if (fxBank.IsChunk()) {
-                if (!(plugin->aeffect->flags & effFlagsProgramChunks)) {
-                    csound->InitError(csound, "Loaded bank contains a chunk format "
-                                      "that the effect cannot handle.");
-                    return NOTOK;
+              if (!(plugin->aeffect->flags & effFlagsProgramChunks)) {
+                return csound->InitError(csound,
+                                         Str("Loaded bank contains a chunk format "
+                                             "that the effect cannot handle."));
                 }
                 plugin->Dispatch(effSetChunk, 0, fxBank.GetChunkSize(),
                                  fxBank.GetChunk(), 0); // isPreset = 0
@@ -325,8 +376,9 @@ extern "C" {
                 plugin->Dispatch(effSetProgram, 0, cProg, dummyPointer, 0);
             }
         } else {
-            csound->InitError(csound, "Problem loading bank.");
-            return NOTOK;           /* check if error loading */
+          return
+            csound->InitError(csound,
+                              Str("Problem loading bank.")); /* check if error loading */
         }
         plugin->Log("Bank loaded OK.\n");
         return OK;
@@ -336,10 +388,14 @@ extern "C" {
     {
         // The changes here are part of an attempt to map 0 to 1 and others
         VSTPROGSET *p = (VSTPROGSET *) data;
-        int program = (int)*p->iprogram;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
+        int program = (int)*p->iprogram;
         if (program<=0) {
-            csound->Message(csound, "VSTprogset: Program %d treated as 1\n", program);
+          csound->Message(csound,
+                          Str("VSTprogset: Program %d treated as 1\n"), program);
             program = 1;
         }
         plugin->SetCurrentProgram(program);
@@ -349,16 +405,22 @@ extern "C" {
     static int vstedit_init(CSOUND *csound, void *data)
     {
         VSTEDIT *p = (VSTEDIT *) data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         plugin->OpenEditor();
-        vstPlugEditors->push_back(plugin); //gab
+        //~ vstPlugEditors->push_back(plugin); //gab
         return OK;
     }
 
     static int vstSetTempo(CSOUND *csound, void *data)
     {
         VSTTEMPO *p = (VSTTEMPO *)data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         plugin->vstTimeInfo.tempo = *p->tempo;
         return OK;
     }
@@ -366,7 +428,10 @@ extern "C" {
     int vstbanksave(CSOUND *csound, void *data)
     {
         VSTBANKLOAD *p = (VSTBANKLOAD *)data;
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         char bankname[512]; //gab
         strcpy(bankname, (char *) p->ibank);          /*   use that         */
         if (!plugin) {
@@ -396,8 +461,8 @@ extern "C" {
                     plugin->EffGetProgramName(szName);
                     b.SetProgramName(i, szName);
                     for (j = 0; j < nParms; j++)
-                        b.SetProgParm(i, j,
-                                      plugin->aeffect->getParameter(plugin->aeffect,j));
+                      b.SetProgParm(i, j,
+                                    plugin->aeffect->getParameter(plugin->aeffect,j));
                 }
                 plugin->EffSetProgram(cProg);
             }
@@ -436,20 +501,22 @@ extern "C" {
         MYFLT *iKey;
         MYFLT *iVelocity;
         MYFLT *iDuration;
-        VSTPlugin *vstPlugin;
         MYFLT startTime;
         MYFLT offTime;
         int channel;
         int key;
         int velocity;
         int on;
+        VSTPlugin *vstplugin;
     } VSTNOTEOUT;
 
     static int vstnote_init(CSOUND *csound, void *data)
     {
         VSTNOTEOUT *p = (VSTNOTEOUT *)data;
-        size_t vstHandle = (size_t) *p->iVSThandle;
-        p->vstPlugin = (*vstPlugins)[vstHandle];
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
+        VSTPlugin *plugin = (*vstPlugins)[(size_t) *p->iVSThandle];
+        p->vstplugin = plugin;
         p->startTime = getCurrentTime(csound);
         double onTime = double(p->h.insdshead->p2.value);
         double deltaTime = onTime - getCurrentTime(csound);
@@ -463,7 +530,8 @@ extern "C" {
             // In case of real-time performance with indefinite p3...
         } else if (*p->iDuration == FL(0.0)) {
             if (csound->GetDebug(csound)) {
-                csound->Message(csound, "vstnote_init: not scheduling 0 duration note.\n");
+              csound->Message(csound,
+                              Str("vstnote_init: not scheduling 0 duration note.\n"));
             }
             return OK;
         } else {
@@ -477,7 +545,7 @@ extern "C" {
         int cents = int( ( ( double(*p->iKey) - double(p->key) ) * double(100.0) ) +
                          double(0.5) );
         p->velocity = int(*p->iVelocity) & 0x7f;
-        p->vstPlugin->AddMIDI(144 | p->channel | (p->key << 8) | (p->velocity << 16),
+        p->vstplugin->AddMIDI(144 | p->channel | (p->key << 8) | (p->velocity << 16),
                               deltaFrames, cents);
         // Ensure that the opcode instance is still active when we are scheduled
         // to turn the note off!
@@ -509,7 +577,7 @@ extern "C" {
                 if (deltaTime > 0) {
                     deltaFrames = int(deltaTime / csound->GetSr(csound));
                 }
-                p->vstPlugin->AddMIDI(128 | p->channel | (p->key << 8) | (0 << 16),
+                p->vstplugin->AddMIDI(128 | p->channel | (p->key << 8) | (0 << 16),
                                       deltaFrames, 0);
                 p->on = false;
                 if (csound->GetDebug(csound)) {
@@ -568,13 +636,24 @@ extern "C" {
 
     PUBLIC int csoundModuleCreate(CSOUND *csound)
     {
-        vstPlugEditors = new std::vector<VSTPlugin*>;
-        vstPlugins = new std::vector<VSTPlugin*>;
+        // It is necessary to store global references to plugins and editors from Seib's code
+        // so that their memory can be freed when the opcode module is destroyed.
+
+        #if defined(CSOUND_LIFECYCLE_DEBUG)
+        csound->Message(csound, "csoundModuleCreate: csound: %p thread: %d\n", csound, syscall(SYS_gettid));
+        #endif
+
+        int result = 0;
+        vstPlugins_t *vstPlugins = new vstPlugins_t;
+        result = csound::CreateGlobalPointer (csound, "vstPlugins", vstPlugins);
         return 0;
     }
 
     PUBLIC int csoundModuleInit(CSOUND *csound)
     {
+        #if defined(CSOUND_LIFECYCLE_DEBUG)
+        csound->Message(csound, "csoundModuleInit: csound: %p thread: %d\n", csound, syscall(SYS_gettid));
+        #endif
         OENTRY  *ep = (OENTRY *) &(localops[0]);
         int     err = 0;
         while (ep->opname != NULL) {
@@ -595,6 +674,11 @@ extern "C" {
 
     PUBLIC int csoundModuleDestroy(CSOUND *csound)
     {
+        #if defined(CSOUND_LIFECYCLE_DEBUG)
+        csound->Message(csound, "csoundModuleDestroy: csound: %p thread: %d\n", csound, syscall(SYS_gettid));
+        #endif
+        vstPlugins_t *vstPlugins = 0;
+        csound::QueryGlobalPointer(csound, "vstPlugins", vstPlugins);
         for (size_t i = 0, n = vstPlugins->size(); i < n; ++i) {
             if ((*vstPlugins)[i]) {
                 delete (*vstPlugins)[i];
@@ -603,14 +687,16 @@ extern "C" {
         }
         delete vstPlugins;
         vstPlugins = 0;
-        for (size_t i = 0, n = vstPlugEditors->size(); i < n; ++i) {
-            if ((*vstPlugEditors)[i]) {
-                delete (*vstPlugEditors)[i];
-            }
-            vstPlugEditors->clear();
-        }
-        delete vstPlugEditors;
-        vstPlugEditors = 0;
+        //~ vstPlugins_t *vstPlugEditors = 0;
+        //~ csound::QueryGlobalPointer(csound, "vstPlugEditors", vstPlugEditors);
+        //~ for (size_t i = 0, n = vstPlugEditors->size(); i < n; ++i) {
+            //~ if ((*vstPlugEditors)[i]) {
+                //~ delete (*vstPlugEditors)[i];
+            //~ }
+            //~ vstPlugEditors->clear();
+        //~ }
+        //~ delete vstPlugEditors;
+        //~ vstPlugEditors = 0;
         return 0;
     }
 }  // extern "C"
