@@ -1,8 +1,9 @@
 //  vst4cs: VST HOST OPCODES FOR CSOUND
 //
-//  Uses code by Hermann Seib from his Vst Host program
-//  and from the vst~ object by Thomas Grill,
-//  which in turn borrows from the Psycle tracker.
+//  Uses code by Hermann Seib from his VSTHost program and from the vst~
+//  object by Thomas Grill (no license), which in turn borrows from the Psycle
+//  tracker (also based on VSTHost).
+//
 //  VST is a trademark of Steinberg Media Technologies GmbH.
 //  VST Plug-In Technology by Steinberg.
 //
@@ -22,6 +23,28 @@
 //  License along with The vst4cs library; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 //  02111-1307 USA
+//
+//  Linking vst4cs statically or dynamically with other modules is making a
+//  combined work based on vst4cs. Thus, the terms and conditions of the GNU
+//  Lesser General Public License cover the whole combination.
+//
+//  In addition, as a special exception, the copyright holders of vst4cs,
+//  including the Csound developers and Hermann Seib, the original author of
+//  VSTHost, give you permission to combine vst4cs with free software programs
+//  or libraries that are released under the GNU LGPL and with code included
+//  in the standard release of the VST SDK version 2 under the terms of the
+//  license stated in the VST SDK version 2 files. You may copy and distribute
+//  such a system following the terms of the GNU LGPL for vst4cs and the
+//  licenses of the other code concerned. The source code for the VST SDK
+//  version 2 is available in the VST SDK hosted at
+//  https://github.com/steinbergmedia/vst3sdk.
+//
+//  Note that people who make modified versions of vst4cs are not obligated to
+//  grant this special exception for their modified versions; it is their
+//  choice whether to do so. The GNU Lesser General Public License gives
+//  permission to release a modified version without this exception; this
+//  exception also makes it possible to release a modified version which
+//  carries forward this exception.
 
 #include "vsthost.h"
 #include <cmath>
@@ -48,10 +71,11 @@
 
 void VSTPlugin::initializeOpcodes()
 {
-    if (opcodeRefCount()) {
-      opcodeRefCount()++;
-      return;
+    static bool opcodes_initialized = false;
+    if (opcodes_initialized) {
+        return;
     }
+    opcodes_initialized = true;
     dispatchOpcodes().insert(std::pair<long,
                              std::string>((long) effOpen, "effOpen"));
     dispatchOpcodes().insert(std::pair<long,
@@ -423,7 +447,6 @@ void VSTPlugin::initializeOpcodes()
                            std::string>((long)audioMasterGetInputSpeakerArrangement,
                                         "audioMasterGetInputSpeakerArrangement"));
 
-    opcodeRefCount()++;
 }
 
 VSTPlugin::VSTPlugin(CSOUND *csound_)
@@ -449,7 +472,6 @@ VSTPlugin::VSTPlugin(CSOUND *csound_)
 VSTPlugin::~VSTPlugin()
 {
     Free();
-    opcodeRefCount()--;
 }
 
 bool VSTPlugin::AddMIDI(int data, int deltaFrames, int detune)
