@@ -121,62 +121,65 @@ static inline void set_stdout_assign(CSOUND *csound, int type, int state)
 
 /* IV - Feb 19 2005 */
 static const char *shortUsageList[] = {
-  Str_noop("--help\tprint long usage options"),
-  Str_noop("--version\tprint version details"),
-  Str_noop("-U unam\trun utility program unam"),
-  Str_noop("-C\tuse Cscore processing of scorefile"),
-  Str_noop("-j N\tuse N threads in performance"),
-  Str_noop("-I\tI-time only orch run"),
-  Str_noop("-n\tno sound onto disk"),
-  Str_noop("-i fnam\tsound input filename"),
-  Str_noop("-o fnam\tsound output filename"),
-  Str_noop("-b N\tsample frames (or -kprds) per software sound I/O buffer"),
-  Str_noop("-B N\tsamples per hardware sound I/O buffer"),
-  Str_noop("-A\tcreate an AIFF format output soundfile"),
-  Str_noop("-W\tcreate a WAV format output soundfile"),
-  Str_noop("-J\tcreate an IRCAM format output soundfile"),
-  Str_noop("-h\tno header on output soundfile"),
-  Str_noop("-c\t8-bit signed_char sound samples"),
+  Str_noop("--help      print long usage options"),
+  Str_noop("--version   print version details"),
+  Str_noop("-U unam     run utility program unam"),
+  Str_noop("-C          use Cscore processing of scorefile"),
+  Str_noop("-j N        use N threads in performance"),
+  Str_noop("-I          I-time only orch run"),
+  Str_noop("-n          no sound onto disk"),
+  Str_noop("-i fnam     sound input filename"),
+  Str_noop("-o fnam     sound output filename"),
+  Str_noop("-b N        sample frames (or -kprds) per software sound I/O buffer"),
+  Str_noop("-B N        samples per hardware sound I/O buffer"),
+  Str_noop("-A          create an AIFF format output soundfile"),
+  Str_noop("-W          create a WAV format output soundfile"),
+  Str_noop("-J          create an IRCAM format output soundfile"),
+  Str_noop("-h          no header on output soundfile"),
+  Str_noop("-c          8-bit signed_char sound samples"),
 #ifdef never
-  Str_noop("-a\talaw sound samples"),
+  Str_noop("-a          alaw sound samples"),
 #endif
-  Str_noop("-8\t8-bit unsigned_char sound samples"),
-  Str_noop("-u\tulaw sound samples"),
-  Str_noop("-s\tshort_int sound samples"),
-  Str_noop("-l\tlong_int sound samples"),
-  Str_noop("-f\tfloat sound samples"),
-  Str_noop("-3\t24bit sound samples"),
-  Str_noop("-r N\torchestra srate override"),
-  Str_noop("-k N\torchestra krate override"),
-  Str_noop("-K\tDo not generate PEAK chunks"),
-  Str_noop("-v\tverbose orch translation"),
-  Str_noop("-m N\ttty message level. Sum of:"),
-  Str_noop("\t\t1=note amps, 2=out-of-range msg, 4=warnings"),
-  Str_noop("\t\t0/32/64/96=note amp format (raw,dB,colors)"),
-  Str_noop("\t\t128=print benchmark information"),
-  Str_noop("-d\tsuppress all displays"),
-  Str_noop("-g\tsuppress graphics, use ascii displays"),
-  Str_noop("-G\tsuppress graphics, use Postscript displays"),
-  Str_noop("-x fnam\textract from score.srt using extract file 'fnam'"),
-  Str_noop("-t N\tuse uninterpreted beats of the score, initially at tempo N"),
-  Str_noop("-t 0\tuse score.srt for sorted score rather than a temporary"),
-  Str_noop("-L dnam\tread Line-oriented realtime score events from device 'dnam'"),
-  Str_noop("-M dnam\tread MIDI realtime events from device 'dnam'"),
-  Str_noop("-F fnam\tread MIDIfile event stream from file 'fnam'"),
-  /*  Str_noop("-P N\tMIDI sustain pedal threshold (0 - 128)"), */
-  Str_noop("-R\tcontinually rewrite header while writing soundfile (WAV/AIFF)"),
-  Str_noop("-H#\tprint heartbeat style 1, 2 or 3 at each soundfile write"),
-  Str_noop("-N\tnotify (ring the bell) when score or miditrack is done"),
-  Str_noop("-T\tterminate the performance when miditrack is done"),
-  Str_noop("-D\tdefer GEN01 soundfile loads until performance time"),
-  Str_noop("-Q dnam\tselect MIDI output device"),
-  Str_noop("-z\tList opcodes in this version"),
-  Str_noop("-Z\tDither output"),
+  Str_noop("-8          8-bit unsigned_char sound samples"),
+  Str_noop("-u          ulaw sound samples"),
+  Str_noop("-s          short_int sound samples"),
+  Str_noop("-l          long_int sound samples"),
+  Str_noop("-f          float sound samples"),
+  Str_noop("-3          24bit sound samples"),
+  Str_noop("-r N        orchestra srate override"),
+  Str_noop("-k N        orchestra krate override"),
+  Str_noop("-K          do not generate PEAK chunks"),
+  Str_noop("-v          verbose orch translation"),
+  Str_noop("-m N        tty message level. Sum of:"),
+  Str_noop("              1=note amps, 2=out-of-range msg, 4=warnings"),
+  Str_noop("              0/32/64/96=note amp format (raw,dB,colors)"),
+  Str_noop("              128=print benchmark information"),
+  Str_noop("-d          suppress all displays"),
+  Str_noop("-g          suppress graphics, use ascii displays"),
+  Str_noop("-G          suppress graphics, use Postscript displays"),
+  Str_noop("-x fnam     extract from score.srt using extract file 'fnam'"),
+  Str_noop("-t N        use uninterpreted beats of the score, "
+                       "initially at tempo N"),
+  Str_noop("-t 0        use score.srt for sorted score rather than a temporary"),
+  Str_noop("-L dnam     read Line-oriented realtime score events from "
+                       "device 'dnam'"),
+  Str_noop("-M dnam     read MIDI realtime events from device 'dnam'"),
+  Str_noop("-F fnam     read MIDIfile event stream from file 'fnam'"),
+  /* Str_noop("-P N        MIDI sustain pedal threshold (0 - 128)"), */
+  Str_noop("-R          continually rewrite header while writing soundfile "
+                       "(WAV/AIFF)"),
+  Str_noop("-H#         print heartbeat style 1, 2 or 3 at each soundfile write"),
+  Str_noop("-N          notify (ring the bell) when score or miditrack is done"),
+  Str_noop("-T          terminate the performance when miditrack is done"),
+  Str_noop("-D          defer GEN01 soundfile loads until performance time"),
+  Str_noop("-Q dnam     select MIDI output device"),
+  Str_noop("-z          list opcodes in this version"),
+  Str_noop("-Z          dither output"),
 #if defined(LINUX)
   Str_noop("--sched     set real-time priority and lock memory"),
-  Str_noop("            (requires -d and real time audio (-iadc/-odac))"),
+  Str_noop("              (requires -d and real time audio (-iadc/-odac))"),
   Str_noop("--sched=N   set specified scheduling priority, and lock memory"),
-  Str_noop("            (requires -d and real time audio (-iadc/-odac))"),
+  Str_noop("              (requires -d and real time audio (-iadc/-odac))"),
 #endif
   NULL
 };
@@ -185,116 +188,126 @@ static const char *longUsageList[] = {
   "--format={wav,aiff,au,raw,paf,svx,nist,voc,ircam,w64,mat4,mat5",
   "          pvf,xi,htk,sds,avr,wavex,sd2,flac,caf,wve,ogg,mpc2k,rf64}",
   "--format={alaw,ulaw,schar,uchar,float,double,short,long,24bit,vorbis}",
-  Str_noop("\t\t\tSet output file format"),
-  Str_noop("--aiff\t\t\tSet AIFF format"),
-  Str_noop("--au\t\t\tSet AU format"),
-  Str_noop("--wave\t\t\tSet WAV format"),
-  Str_noop("--ircam\t\t\tSet IRCAM format"),
-  Str_noop("--ogg\t\t\tSet OGG/VORBIS format"),
-  Str_noop("--noheader\t\tRaw format"),
-  Str_noop("--nopeaks\t\tDo not write peak information"),
+  Str_noop("  Set output file format"),
+  Str_noop("--aiff                  set AIFF format"),
+  Str_noop("--au                    set AU format"),
+  Str_noop("--wave                  set WAV format"),
+  Str_noop("--ircam                 set IRCAM format"),
+  Str_noop("--ogg                   set OGG/VORBIS format"),
+  Str_noop("--noheader              raw format"),
+  Str_noop("--nopeaks               do not write peak information"),
   " ",
-   Str_noop("--displays\t\tUse graphic displays"),
-  Str_noop("--nodisplays\t\tSuppress all displays"),
-  Str_noop("--asciidisplay\t\tSuppress graphics, use ascii displays"),
-  Str_noop("--postscriptdisplay\tSuppress graphics, use Postscript displays"),
+  Str_noop("--displays              use graphic displays"),
+  Str_noop("--nodisplays            suppress all displays"),
+  Str_noop("--asciidisplay          suppress graphics, use ascii displays"),
+  Str_noop("--postscriptdisplay     suppress graphics, use Postscript displays"),
   " ",
-  Str_noop("--defer-gen1\t\tDefer GEN01 soundfile loads until performance time"),
-  Str_noop("--iobufsamps=N\t\tSample frames (or -kprds) per software "
-           "sound I/O buffer"),
-  Str_noop("--hardwarebufsamps=N\tSamples per hardware sound I/O buffer"),
-  Str_noop("--cscore\t\tUse Cscore processing of scorefile"),
-  Str_noop("--orc\t\t\tUse orchfile without scorefile"),
+  Str_noop("--defer-gen1            defer GEN01 soundfile loads until "
+                                   "performance time"),
+  Str_noop("--iobufsamps=N          sample frames (or -kprds) per software "
+                                    "sound I/O buffer"),
+  Str_noop("--hardwarebufsamps=N    samples per hardware sound I/O buffer"),
+  Str_noop("--cscore                use Cscore processing of scorefile"),
+  Str_noop("--orc                   use orchfile without scorefile"),
   " ",
-  Str_noop("--midifile=FNAME\tRead MIDIfile event stream from file"),
-  Str_noop("--midioutfile=FNAME\tWrite MIDI output to file FNAME"),
-  Str_noop("--midi-device=FNAME\tRead MIDI realtime events from device"),
-  Str_noop("--terminate-on-midi\tTerminate the performance when miditrack is done"),
+  Str_noop("--midifile=FNAME        read MIDIfile event stream from file"),
+  Str_noop("--midioutfile=FNAME     write MIDI output to file FNAME"),
+  Str_noop("--midi-device=FNAME     read MIDI realtime events from device"),
+  Str_noop("--terminate-on-midi     terminate the performance when miditrack "
+           "is done"),
   " ",
-  Str_noop("--heartbeat=N\t\tPrint a heartbeat style 1, 2 or 3 at "
-           "each soundfile write"),
-  Str_noop("--notify\t\tNotify (ring the bell) when score or miditrack is done"),
-  Str_noop("--rewrite\t\tContinually rewrite header while writing "
-           "soundfile (WAV/AIFF)"),
+  Str_noop("--heartbeat=N           print a heartbeat style 1, 2 or 3 at "
+                                    "each soundfile write"),
+  Str_noop("--notify                notify (ring the bell) when score or "
+           "miditrack is done"),
+  Str_noop("--rewrite               continually rewrite header while writing "
+                                    "soundfile (WAV/AIFF)"),
   " ",
-  Str_noop("--input=FNAME\t\tSound input filename"),
-  Str_noop("--output=FNAME\t\tSound output filename"),
-  Str_noop("--logfile=FNAME\t\tLog output to file"),
+  Str_noop("--input=FNAME           sound input filename"),
+  Str_noop("--output=FNAME          sound output filename"),
+  Str_noop("--logfile=FNAME         log output to file"),
   " ",
-  Str_noop("--nosound\t\tNo sound onto disk or device"),
-  Str_noop("--tempo=N\t\tUse uninterpreted beats of the score, initially"
-           " at tempo N"),
-  Str_noop("--i-only\t\tI-time only orch run"),
-  Str_noop("--syntax-check-only\tStop after checking orchestra and score syntax"),
-  Str_noop("--control-rate=N\tOrchestra krate override"),
-  Str_noop("--sample-rate=N\t\tOrchestra srate override"),
-  Str_noop("--score-in=FNAME\tRead Line-oriented realtime score events"
-           " from device"),
-  Str_noop("--messagelevel=N\ttty message level, sum of:"),
-  Str_noop("--messageolevel=O\ttty message level in octal, of:"),
-  Str_noop("\t\t\t\t1=note amps, 2=out-of-range msg, 4=warnings,"),
-  Str_noop("\t\t\t\t0/32/64/96=note amp format (raw,dB,colors),"),
-  Str_noop("\t\t\t\t128=print benchmark information"),
+  Str_noop("--nosound               no sound onto disk or device"),
+  Str_noop("--tempo=N               use uninterpreted beats of the score, "
+                                   "initially at tempo N"),
+  Str_noop("--i-only                I-time only orch run"),
+  Str_noop("--syntax-check-only     stop after checking orchestra and "
+                                    "score syntax"),
+  Str_noop("--control-rate=N        orchestra krate override"),
+  Str_noop("--sample-rate=N         orchestra srate override"),
+  Str_noop("--score-in=FNAME        read line-oriented realtime score events "
+                                    "from device"),
+  Str_noop("--messagelevel=N        tty message level, sum of:"),
+  Str_noop("--messageolevel=O       tty message level in octal, of:"),
+  Str_noop("                          1=note amps, 2=out-of-range msg, 4=warnings,"),
+  Str_noop("                          0/32/64/96=note amp format (raw,dB,colors),"),
+  Str_noop("                          128=print benchmark information"),
   " ",
-  Str_noop("--m-amps=[01]\tmessages on note amps"),
-  Str_noop("--m-range=[01]\tMessages on range errors"),
-  Str_noop("--m-warnings=[01]\tMesage on warnings"),
-  Str_noop("--m-raw=[01]\tRaw amp messages"),
-  Str_noop("--m-dB=[01]\tAmp messages in dB"),
-  Str_noop("--m-colours=[01]\tColour amp messages"),
-  Str_noop("--m-benchmarks=[01]\tPrint benchmark information"),
-  Str_noop("--csd-line-nums=[01]\tControls how error line numbers are printed:"),
-  Str_noop("\t\t\t1=use CSD line #s (default), 0=use ORC/SCO-relative line #s"),
-  Str_noop("--extract-score=FNAME\tExtract from score.srt using extract file"),
+  Str_noop("--m-amps=[01]           messages on note amps"),
+  Str_noop("--m-range=[01]          messages on range errors"),
+  Str_noop("--m-warnings=[01]       mesage on warnings"),
+  Str_noop("--m-raw=[01]            raw amp messages"),
+  Str_noop("--m-dB=[01]             amp messages in dB"),
+  Str_noop("--m-colours=[01]        colour amp messages"),
+  Str_noop("--m-benchmarks=[01]     print benchmark information"),
+  Str_noop("--csd-line-nums=[01]    controls how error line numbers are printed:"),
+  Str_noop("                          1=use CSD line #s (default), 0=use "
+                                   "ORC/SCO-relative line #s"),
+  Str_noop("--extract-score=FNAME   extract from score.srt using extract file"),
   Str_noop("--keep-sorted-score"),
-  Str_noop("--env:NAME=VALUE\tSet environment variable NAME to VALUE"),
-  Str_noop("--env:NAME+=VALUE\tAppend VALUE to environment variable NAME"),
-  Str_noop("--strsetN=VALUE\t\tSet strset table at index N to VALUE"),
-  Str_noop("--utility=NAME\t\tRun utility program"),
-  Str_noop("--verbose\t\tVerbose orch translation"),
-  Str_noop("--list-opcodes\t\tList opcodes in this version"),
-  Str_noop("--list-opcodesN\t\tList opcodes in style N in this version"),
-  Str_noop("--dither\t\tDither output"),
-  Str_noop("--dither-triangular\t\tDither output with triangular distribution"),
-  Str_noop("--dither-uniform\t\tDither output with rectanular distribution"),
-  Str_noop("--sched\t\t\tSet real-time scheduling priority and lock memory"),
-  Str_noop("--sched=N\t\tSet priority to N and lock memory"),
-  Str_noop("--opcode-lib=NAMES\tDynamic libraries to load"),
-  Str_noop("--opcode-omit=NAMES\tDynamic libraries not to load"),
-  Str_noop("--omacro:XXX=YYY\tSet orchestra macro XXX to value YYY"),
-  Str_noop("--smacro:XXX=YYY\tSet score macro XXX to value YYY"),
-  Str_noop("--midi-key=N\t\tRoute MIDI note on message"),
-  Str_noop("\t\t\tkey number to pfield N as MIDI value [0-127]"),
-  Str_noop("--midi-key-cps=N\tRoute MIDI note on message"),
-  Str_noop("\t\t\tkey number to pfield N as cycles per second"),
-  Str_noop("--midi-key-oct=N\tRoute MIDI note on message"),
-  Str_noop("\t\t\tkey number to pfield N as linear octave"),
-  Str_noop("--midi-key-pch=N\tRoute MIDI note on message"),
-  Str_noop("\t\t\tkey number to pfield N as oct.pch"),
-  Str_noop("--midi-velocity=N\tRoute MIDI note on message"),
-  Str_noop("\t\t\tvelocity number to pfield N as MIDI value [0-127]"),
-  Str_noop("--midi-velocity-amp=N\tRoute MIDI note on message"),
-  Str_noop("\t\t\tvelocity number to pfield N as amplitude"),
-  Str_noop("--no-default-paths\tTurn off relative paths from CSD/ORC/SCO"),
-  Str_noop("--sample-accurate\t\tUse sample-accurate timing of score events"),
-  Str_noop("--realtime\t\trealtime priority mode"),
-  Str_noop("--nchnls=N\t\t override number of audio channels"),
-  Str_noop("--nchnls_i=N\t\t override number of input audio channels"),
-  Str_noop("--0dbfs=N\t\t override 0dbfs (max positive signal amplitude)"),
-  Str_noop("--sinesize\t\tlength of internal sine table"),
-  Str_noop("--daemon\t\t daemon mode: do not exit if CSD/orchestra is "
-           "not given, is empty or does not compile"),
-  Str_noop("--port=N\t\t listen to UDP port N for instruments/orchestra "
-           "code (implies --daemon)"),
-  Str_noop("--vbr-quality=Ft\t set quality of variable bit0rate compression"),
-    Str_noop("--devices[=in|out] \t\t list available MIDI devices and exit"),
-  Str_noop("--midi-devices[=in|out] \t\t list available audio devices and exit"),
-  Str_noop("--get-system-sr \t\t print system sr and exit"),
-  Str_noop("--ksmps=N \t\t override ksmps"),
-  Str_noop("--fftlib=N \t\t real fft lib to use (FFTLIB=0, PFFFT = 1, vDSP =2)"),
+  Str_noop("--env:NAME=VALUE        set environment variable NAME to VALUE"),
+  Str_noop("--env:NAME+=VALUE       append VALUE to environment variable NAME"),
+  Str_noop("--strsetN=VALUE         set strset table at index N to VALUE"),
+  Str_noop("--utility=NAME          run utility program"),
+  Str_noop("--verbose               verbose orch translation"),
+  Str_noop("--list-opcodes          list opcodes in this version"),
+   Str_noop("--list-opcodesN         list opcodes in style N in this version"),
+  Str_noop("--dither                dither output"),
+  Str_noop("--dither-triangular     dither output with triangular distribution"),
+  Str_noop("--dither-uniform        dither output with rectanular distribution"),
+  Str_noop("--sched                 set real-time scheduling priority and "
+                                   "lock memory"),
+  Str_noop("--sched=N               set priority to N and lock memory"),
+  Str_noop("--opcode-lib=NAMES      dynamic libraries to load"),
+  Str_noop("--opcode-omit=NAMES     dynamic libraries not to load"),
+  Str_noop("--omacro:XXX=YYY        set orchestra macro XXX to value YYY"),
+  Str_noop("--smacro:XXX=YYY        set score macro XXX to value YYY"),
+  Str_noop("--midi-key=N            route MIDI note on message"),
+  Str_noop("                          key number to pfield N as "
+                                   "MIDI value [0-127]"),
+  Str_noop("--midi-key-cps=N        route MIDI note on message"),
+  Str_noop("                          key number to pfield N as cycles per second"),
+  Str_noop("--midi-key-oct=N        route MIDI note on message"),
+  Str_noop("                          key number to pfield N as linear octave"),
+  Str_noop("--midi-key-pch=N        route MIDI note on message"),
+  Str_noop("                          key number to pfield N as oct.pch"),
+  Str_noop("--midi-velocity=N       route MIDI note on message"),
+  Str_noop("                          velocity number to pfield N as MIDI "
+                                   "value [0-127]"),
+  Str_noop("--midi-velocity-amp=N   route MIDI note on message"),
+  Str_noop("                          velocity number to pfield N as amplitude"),
+  Str_noop("--no-default-paths      turn off relative paths from CSD/ORC/SCO"),
+  Str_noop("--sample-accurate       use sample-accurate timing of score events"),
+  Str_noop("--realtime              realtime priority mode"),
+  Str_noop("--nchnls=N              override number of audio channels"),
+  Str_noop("--nchnls_i=N            override number of input audio channels"),
+  Str_noop("--0dbfs=N               override 0dbfs (max positive signal amplitude)"),
+  Str_noop("--sinesize              length of internal sine table"),
+  Str_noop("--daemon                daemon mode: do not exit if CSD/orchestra is "
+                                    "not given, is empty or does not compile"),
+  Str_noop("--port=N                listen to UDP port N for instruments/orchestra "
+                                    "code (implies --daemon)"),
+  Str_noop("--vbr-quality=Ft        set quality of variable bit-rate compression"),
+  Str_noop("--devices[=in|out]      list available MIDI devices and exit"),
+  Str_noop("--midi-devices[=in|out] list available audio devices and exit"),
+  Str_noop("--get-system-sr         print system sr and exit"),
+  Str_noop("--ksmps=N               override ksmps"),
+  Str_noop("--fftlib=N              actual FFT lib to use (FFTLIB=0, "
+                                   "PFFFT = 1, vDSP =2)"),
+  Str_noop("--udp-echo              echo UDP commands on terminal"),
+  Str_noop("--aft-zero              set aftertouch to zero, not 127 (default)"),
   " ",
-  Str_noop("--help\t\t\tLong help"),
-
+  Str_noop("--help                  long help"),
   NULL
 };
 
@@ -309,39 +322,40 @@ void print_short_usage(CSOUND *csound)
       csound->Message(csound, "%s", Str(buf));
     }
     csound->Message(csound,
-                    Str("flag defaults: csound -s -otest -b%d -B%d -m%d\n"),
+                    Str("flag defaults: csound -s -otest -b%d -B%d -m%d\n\n"),
                     IOBUFSAMPS, IODACSAMPS, csound->oparms->msglevel);
 }
 
 static void longusage(CSOUND *p)
 {
     const char **sp;
-    p->Message(p, Str("Usage:\tcsound [-flags] orchfile scorefile\n"));
+    p->Message(p, Str("Usage:     csound [-flags] orchfile scorefile\n"));
     p->Message(p, Str("Legal flags are:\n"));
     p->Message(p, Str("Long format:\n\n"));
     for (sp = &(longUsageList[0]); *sp != NULL; sp++)
       p->Message(p, "%s\n", Str(*sp));
-    /* IV - Feb 19 2005 */
     dump_cfg_variables(p);
-    p->Message(p, Str("\nShort form:\n"));
+    p->Message(p, Str("\nShort format:\n\n"));
     print_short_usage(p);
-    // p->LongJmp(p, 0);
 }
 
-void dieu(CSOUND *csound, char *s, ...)
+CS_NORETURN void dieu(CSOUND *csound, char *s, ...)
 {
     va_list args;
 
-    csound->Message(csound,Str("Usage:\tcsound [-flags] orchfile scorefile\n"));
+    csound->Message(csound,Str("Usage:      csound [-flags] orchfile scorefile\n"));
     csound->Message(csound,Str("Legal flags are:\n"));
     print_short_usage(csound);
     va_start(args, s);
-    csound->ErrMsgV(csound, Str("Csound Command ERROR:\t"), s, args);
+    csound->ErrMsgV(csound, Str("Csound Command ERROR:    "), s, args);
     va_end(args);
-    if (csound->info_message_request == 0){
+    //***FIXME This code makes no sense
+    if (csound->info_message_request == 0) {
       csound->info_message_request = 0;
-    csound->LongJmp(csound, 1);
+      csound->LongJmp(csound, 1);
     }
+    //Added longjump -- JPff
+    csound->LongJmp(csound, 1);
 }
 
 void set_output_format(OPARMS *O, char c)
@@ -854,7 +868,7 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
      */
     else if (UNLIKELY(!(strncmp (s, "tempo=", 6)))) {
       s += 6;
-      O->cmdTempo = atoi(s);
+      O->cmdTempo = atof(s);
       O->Beatmode = 1;                  /* on uninterpreted Beats */
       return 1;
     }
@@ -1074,6 +1088,33 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       O->daemon = atoi(s);
       return 1;
     }
+    else if (!(strncmp(s, "udp-echo",8))) {
+      s += 8;
+      O->echo = 1;
+      return 1;
+    }
+    else if (!(strncmp(s, "udp-console=",12))) {
+      char *ports;
+      s += 12;
+      ports = strchr(s, ':');
+      if(*s != '\0' && ports != NULL) {
+        *ports = '\0';
+        csoundUDPConsole(csound, s, atoi(ports+1),0);
+      } else
+        csound->Warning(csound, "UDP console: needs address and port\n");
+      return 1;
+    }
+    else if (!(strncmp(s, "udp-mirror-console=",19))) {
+      char *ports;
+      s += 19;
+      ports = strchr(s, ':');
+      if(*s != '\0' && ports != NULL) {
+        *ports = '\0';
+        csoundUDPConsole(csound, s, atoi(ports+1),1);
+      } else
+        csound->Warning(csound, "UDP console: needs address and port\n");
+      return 1;
+    }
     else if (!(strncmp(s, "fftlib=",7))) {
       s += 7;
       O->fft_lib = atoi(s);
@@ -1139,6 +1180,10 @@ static int decode_long(CSOUND *csound, char *s, int argc, char **argv)
       csound->info_message_request = 1;
       return 1;
     }
+    else if (!(strcmp(s, "aft-zero"))){
+      csound->aftouch = 0;
+      return 1;
+    }
 
     csoundErrorMsg(csound, Str("unknown long option: '--%s'"), s);
     return 0;
@@ -1298,7 +1343,7 @@ PUBLIC int argdecode(CSOUND *csound, int argc, const char **argv_)
             FIND(Str("no tempo value"));
             {
               double val;
-              sscanf(s, "%g%n", &val, &n); /* use this tempo .. */
+              sscanf(s, "%lg%n", &val, &n); /* use this tempo .. */
               s += n;
               if (UNLIKELY(val < 0.0)) dieu(csound, Str("illegal tempo"));
               else if (val == 0.0) {
@@ -1411,7 +1456,7 @@ PUBLIC int argdecode(CSOUND *csound, int argc, const char **argv_)
               else {
                 CORFIL *cf = copy_to_corefile(csound, s, NULL, 0);
                 readOptions(csound, cf, 0);
-                corfile_rm(&cf);
+                corfile_rm(csound, &cf);
                 csound->FileClose(csound, fd);
               }
               while (*s++) {};
