@@ -172,7 +172,7 @@ PUBLIC EVLIST * cscoreListCreate(CSOUND *csound, int nslots)
     int   needsiz = sizeof(EVLIST) + nslots * sizeof(EVENT *);
     int   minfreesiz = needsiz + sizeof(CSHDR);
 
-    if (minfreesiz > MAXALLOC) {
+    if (UNLIKELY(minfreesiz > MAXALLOC)) {
       csound->Message(csound, Str("Not enough memory\n"));
       exit(1);
     }
@@ -203,7 +203,7 @@ PUBLIC EVENT * cscoreCreateEvent(CSOUND *csound, int pcnt)
     int   needsiz = sizeof(EVENT) + pcnt * sizeof(MYFLT);
     int   minfreesiz = needsiz + sizeof(CSHDR);
 
-    if (minfreesiz > MAXALLOC) {
+    if (UNLIKELY(minfreesiz > MAXALLOC)) {
       csound->Message(csound, Str("Not enough memory\n"));
       exit(1);
     }
@@ -279,7 +279,7 @@ PUBLIC EVENT * cscoreDefineEvent(CSOUND *csound, char *s)
         s++;
       while (*s == ' ')
         s++;
-      if (p > q && *s != '\0')  {           /* too many ? */
+      if (UNLIKELY(p > q && *s != '\0'))  {           /* too many ? */
         p++;
         csound->Message(csound,
                         Str("PMAX exceeded, string event truncated.\n"));
@@ -398,7 +398,7 @@ PUBLIC EVLIST * cscoreListGetSection(CSOUND *csound)
 
     a = cscoreListCreate(csound, NSLOTS);
     p = &a->e[1];
-    if (csound->scstr == NULL || csound->scstr->body[0] == '\0')
+    if (UNLIKELY(csound->scstr == NULL || csound->scstr->body[0] == '\0'))
       return a;
     while ((e = cscoreGetEvent(csound)) != NULL) {
       if (e->op == 's' || e->op == 'e')
@@ -827,9 +827,9 @@ PUBLIC int csoundInitializeCscore(CSOUND *csound, FILE* insco, FILE* outsco)
     EVENT  *next;
 
     if (insco != NULL) {
-      CORFIL *inf = corfile_create_w();
+      CORFIL *inf = corfile_create_w(csound);
       int c;
-      while ((c=getc(insco))!=EOF) corfile_putc(c, inf);
+      while ((c=getc(insco))!=EOF) corfile_putc(csound, c, inf);
       corfile_rewind(inf);
       csound->scstr = inf;
     }
@@ -914,12 +914,12 @@ PUBLIC FILE *cscoreFileGetCurrent(CSOUND *csound)
 PUBLIC void cscoreFileSetCurrent(CSOUND *csound, FILE *fp)
 {
     if (fp != NULL) {
-      CORFIL *inf = corfile_create_w();
+      CORFIL *inf = corfile_create_w(csound);
       int c;
       fseek(fp, 0, SEEK_SET);
-      while ((c=getc(fp))!=EOF) corfile_putc(c, inf);
+      while ((c=getc(fp))!=EOF) corfile_putc(csound, c, inf);
       corfile_rewind(inf);
-      corfile_rm(&csound->scstr);
+      corfile_rm(csound, &csound->scstr);
       csound->scstr = inf;
       nxtevt->op = '\0';
       atEOF = 0;
