@@ -1,7 +1,5 @@
 /*
- * C S O U N D   V S T
- *
- * A VST plugin version of Csound, with Python scripting.
+ * C S O U N D
  *
  * L I C E N S E
  *
@@ -26,7 +24,7 @@
 %module CsoundAC
 %{
 #include <string>
-  %}
+%}
 #else
 #include <string>
 #endif
@@ -36,11 +34,11 @@ namespace csound
   /**
    * Base class for C++ exceptions in the Silence system.
    */
-  class Exception
+  class SILENCE_PUBLIC Exception
   {
     std::string message;
   public:
-    Exception(std::string message_) : 
+    Exception(std::string message_) :
       message(message_)
       {
       }
