@@ -1,7 +1,5 @@
-/**
- * C S O U N D   V S T
- *
- * A VST plugin version of Csound, with Python scripting.
+/*
+ * C S O U N D
  *
  * L I C E N S E
  *
@@ -27,7 +25,11 @@
 #include <fstream>
 #include <iostream>
 #include <map>
+#include <sstream>
 #include <vector>
+#include <cstring>
+
+using namespace std;
 
 namespace csound
 {
@@ -123,15 +125,41 @@ namespace csound
     return (a << 24) + (b << 16) + (c << 8) + d;
   }
 
-  Chunk::Chunk(const char *_id)
+  Chunk::Chunk() :
+    id(0),
+    chunkSize(0),
+    chunkSizePosition(0),
+    chunkStart(0),
+    chunkEnd(0)
+  {
+  }
+
+  Chunk::Chunk(const char *_id) : chunkSize(0), chunkSizePosition(0), chunkStart(0), chunkEnd(0)
   {
     id = MidiFile::chunkName(_id[0], _id[1], _id[2], _id[3]);
   }
 
+  Chunk::Chunk(const Chunk &a)
+  {
+    *this = a;
+  }
+
   Chunk::~Chunk()
   {
   }
 
+  Chunk &Chunk::operator = (const Chunk &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+    }
+    return *this;
+  }
+
   void Chunk::read(std::istream &stream)
   {
     int _id = MidiFile::readInt(stream);
@@ -184,11 +212,31 @@ namespace csound
     clear();
   }
 
+  MidiHeader::MidiHeader(const MidiHeader &a)
+  {
+    *this = a;
+  }
+
   MidiHeader::~MidiHeader()
   {
     clear();
   }
 
+  MidiHeader &MidiHeader::operator = (const MidiHeader &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+      type = a.type;
+      trackCount = a.trackCount;
+      timeFormat = a.timeFormat;
+    }
+    return *this;
+  }
+
   void MidiHeader::clear()
   {
     type = 0;
@@ -217,63 +265,74 @@ namespace csound
   {
   }
 
+  MidiEvent::MidiEvent(const MidiEvent &a)
+  {
+    *this = a;
+  }
+
   MidiEvent::~MidiEvent()
   {
   }
 
-  void MidiEvent::write(std::ostream &stream, MidiFile &midiFile, int lastTick)
+  MidiEvent &MidiEvent::operator = (const MidiEvent &a)
+  {
+    if (this != &a) {
+      this->ticks = a.ticks;
+      this->time = a.time;
+      resize(a.size());
+      for (size_t i = 0; i < a.size(); i++) {
+        (*this)[i] = a[i];
+      }
+    }
+    return *this;
+  }
+
+  void MidiEvent::write(std::ostream &stream, const MidiFile &midiFile, int lastTick) const
   {
     int deltaTicks = ticks - lastTick;
     MidiFile::writeVariableLength(stream, deltaTicks);
     //  Channel event.
-    if(getMetaType() < 0)
-      {
-        for(size_t i = 0, n = size(); i < n; i++)
-          {
-            stream.put((*this)[i]);
-          }
+    if(getStatusNybble() != 0xf) {
+      for(size_t i = 0, n = size(); i < n; i++) {
+        stream.put((*this)[i]);
       }
-    //  Meta event.
-    else
-      {
-        stream.put((*this)[0]);
-        stream.put((*this)[1]);
-        size_t n = getMetaSize();
-        MidiFile::writeVariableLength(stream, (int) n);
-        size_t i;
-        for(i = 3, n = size(); i < n; i++)
-          {
-            stream.put((*this)[i]);
-          }
+      // Meta event.
+    } else {
+      stream.put(getStatus());
+      stream.put(getMetaType());
+      MidiFile::writeVariableLength(stream, getMetaSize());
+      for(size_t i = 0, n = getMetaSize(); i < n; i++) {
+        stream.put((*this)[2 + i]);
       }
+    }
   }
 
-  int MidiEvent::getStatus()
+  int MidiEvent::getStatus() const
   {
     return (*this)[0];
   }
 
-  int MidiEvent::getStatusNybble()
+  int MidiEvent::getStatusNybble() const
   {
     return (*this)[0] & 0xf0;
   }
 
-  int MidiEvent::getChannelNybble()
+  int MidiEvent::getChannelNybble() const
   {
     return (*this)[0] & 0x0f;
   }
 
-  int MidiEvent::getKey()
+  int MidiEvent::getKey() const
   {
     return (*this)[1];
   }
 
-  int MidiEvent::getVelocity()
+  int MidiEvent::getVelocity() const
   {
     return (*this)[2];
   }
 
-  int MidiEvent::getMetaType()
+  int MidiEvent::getMetaType() const
   {
     if(getStatus() == MidiFile::META_EVENT)
       {
@@ -282,12 +341,12 @@ namespace csound
     return -1;
   }
 
-  unsigned char MidiEvent::getMetaData(int i)
+  unsigned char MidiEvent::getMetaData(int i) const
   {
     return (*this)[i + 2];
   }
 
-  size_t MidiEvent::getMetaSize()
+  size_t MidiEvent::getMetaSize() const
   {
     return (size() - 2);
   }
@@ -297,72 +356,81 @@ namespace csound
     char c;
     stream.get(c);
     push_back((unsigned char) c);
-#ifdef _DEBUG
-    //          fprintf(stderr, " pos %x val %x\n", (int) stream.tellg(), (unsigned char) c);
-#endif
     return (unsigned char) c;
   }
 
-  bool MidiEvent::isChannelVoiceMessage()
+  bool MidiEvent::isChannelVoiceMessage() const
   {
-    if(getStatusNybble() < MidiFile::CHANNEL_NOTE_OFF)
-      {
-        return false;
-      }
-    if(getStatusNybble() > MidiFile::CHANNEL_PITCH_BEND)
-      {
-        return false;
-      }
+    if(getStatusNybble() < MidiFile::CHANNEL_NOTE_OFF) {
+      return false;
+    }
+    if(getStatusNybble() > MidiFile::CHANNEL_PITCH_BEND) {
+      return false;
+    }
     return true;
   }
 
-  bool MidiEvent::isNoteOn()
+  bool MidiEvent::isNoteOn() const
   {
-    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_ON && (*this)[2] > 0)
-      {
+    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_ON) {
+      if (getVelocity() > 0) {
         return true;
+      } else {
+        return false;
       }
+    }
     return false;
   }
 
-  bool MidiEvent::isNoteOff()
+  bool MidiEvent::isNoteOff() const
   {
-    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_OFF)
-      {
-        return true;
-      }
-    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_ON && (*this)[2] == 0)
-      {
+    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_OFF) {
+      return true;
+    }
+    if(getStatusNybble() == MidiFile::CHANNEL_NOTE_ON) {
+      if (getVelocity() == 0) {
         return true;
+      } else {
+        return false;
       }
+    }
     return false;
   }
 
-  bool MidiEvent::isMatchingNoteOff(MidiEvent &offEvent)
+  bool MidiEvent::matchesNoteOffEvent(const MidiEvent &offEvent) const
   {
-    if(getChannelNybble() != offEvent.getChannelNybble())
-      {
-        return false;
-      }
-    if(!isNoteOn())
-      {
-        return false;
-      }
-    if(!offEvent.isNoteOff())
-      {
-        return false;
-      }
-    if(!(offEvent.time > time))
-      {
-        return false;
-      }
-    if(getKey() != offEvent.getKey())
-      {
-        return false;
-      }
+    if(!isNoteOn()) {
+      return false;
+    }
+    if(!offEvent.isNoteOff()) {
+      return false;
+    }
+    if(getChannelNybble() != offEvent.getChannelNybble()) {
+      return false;
+    }
+    if(getKey() != offEvent.getKey()) {
+      return false;
+    }
+    if(!(offEvent.time >= time)) {
+      return false;
+    }
     return true;
   }
 
+  std::string MidiEvent::toString() const
+  {
+    std::ostringstream stream;
+    char buffer[0x100];
+    std::sprintf(buffer, "MidiEvent:  tick: %5d  sec: %8.4f  status: %3d", ticks, time, getStatus());
+    stream << buffer;
+    for (size_t i = 1, n = size(); i < n; ++i) {
+      std::sprintf(buffer, " %3d", at(i));
+      stream << buffer;
+    }
+    stream << std::endl;
+    return stream.str();
+  }
+
   MidiTrack::MidiTrack() : Chunk("MTrk")
   {
   }
@@ -371,6 +439,22 @@ namespace csound
   {
   }
 
+  MidiTrack &MidiTrack::operator = (const MidiTrack &a)
+  {
+    if (this != &a) {
+      id = a.id;
+      chunkSize = a.chunkSize;
+      chunkSizePosition = a.chunkSizePosition;
+      chunkStart = a.chunkStart;
+      chunkEnd = a.chunkEnd;
+      resize(a.size());
+      for (size_t i = 0; i < size(); i++) {
+        (*this)[i] = a[i];
+      }
+    }
+    return *this;
+  }
+
   void MidiTrack::read(std::istream &stream, MidiFile &midiFile)
   {
     Chunk::read(stream);
@@ -399,11 +483,11 @@ namespace csound
       {
         secondsPerTick = midiFile.currentSecondsPerTick;
       }
-    time = midiFile.currentTime = (midiFile.currentTime + (secondsPerTick * ticks));
+    this->time = midiFile.currentTime = (midiFile.currentTime + (secondsPerTick * double(ticks)));
     int peeked = stream.peek();
     if(stream.eof())
       {
-        std::cout << "MIDI file incorrectly read EOF." << std::endl;
+        std::cerr << "MIDI file incorrectly read EOF." << std::endl;
         return;
       }
     if(peeked < 0x80)
@@ -504,6 +588,7 @@ namespace csound
         }
         break;
       }
+    std::cerr << toString();
   }
 
   void MidiTrack::write(std::ostream &stream, MidiFile &midiFile)
@@ -545,7 +630,7 @@ namespace csound
     currentSecondsPerTick = 0;
     lastStatus = 0;
     midiHeader.clear();
-    midiTracks.erase(midiTracks.begin(), midiTracks.end());
+    midiTracks.clear();
     tempoMap.erase(tempoMap.begin(), tempoMap.end());
     microsecondsPerQuarterNote = (60.0 / 120.0) * 1000000.0;
     computeTimes();
@@ -593,6 +678,7 @@ namespace csound
       {
         int frameCode = (-midiHeader.timeFormat) >> 8;
         double framesPerSecond;
+        //cout << " frameCode:   " << frameCode;
         switch(frameCode)
           {
           case 24:
@@ -610,7 +696,9 @@ namespace csound
           default:
             framesPerSecond = 30.0;
           }
+        //cout << " framesPerSecond: " << framesPerSecond;
         int ticksPerFrame = midiHeader.timeFormat & 0xff;
+        //cout << " ticksPerFrame:   " << ticksPerFrame;
         currentSecondsPerTick = (1.0 / framesPerSecond) / ticksPerFrame;
       }
     else
@@ -618,7 +706,11 @@ namespace csound
         double ticksPerQuarterNote = double(midiHeader.timeFormat);
         double secondsPerQuarterNote = microsecondsPerQuarterNote / 1000000.0;
         currentSecondsPerTick = secondsPerQuarterNote / ticksPerQuarterNote;
+        //cout << " ticksPerQuarterNote:   " << ticksPerQuarterNote;
+        //cout << " secondsPerQuarterNote: " << secondsPerQuarterNote;
       }
+    //cout << " currentSecondsPerTick: " << currentSecondsPerTick;
+    //cout << endl;
     tempoMap[currentTick] = currentSecondsPerTick;
   }
 
@@ -645,22 +737,10 @@ namespace csound
       }
   }
 
-  void MidiFile::sort()
+  inline bool operator < (const MidiEvent &a, const MidiEvent &b)
   {
-    for(std::vector<MidiTrack>::iterator it = midiTracks.begin(); it != midiTracks.end(); ++it)
-      {
-        (*it).sort();
-      }
-  }
+      MidiEventComparator comparator;
+      return comparator(a, b);
+  };
 
-  void MidiTrack::sort()
-  {
-    std::sort(begin(), end());
-  }
-
-  bool operator < (const MidiEvent &a, MidiEvent &b)
-  {
-
-    return (a.time < b.time);
-  }
 }
