@@ -1,7 +1,5 @@
 /*
-* C S O U N D   V S T
-*
-* A VST plugin version of Csound, with Python scripting.
+* C S O U N D
 *
 * L I C E N S E
 *
@@ -22,10 +20,12 @@
 #ifndef SILENCE_PLATFORM_HPP
 #define SILENCE_PLATFORM_HPP
 
-#if (defined(WIN32) || defined(_WIN32)) && !defined(SWIG)
-#define SILENCE_PUBLIC __declspec(dllexport)
+#if (defined(WIN32) || defined(_WIN32)) && !defined(SWIG) && !defined(_MSC_VER)
+#  define SILENCE_PUBLIC __declspec(dllexport)
+#elif defined(__GNUC__) && (__GNUC__ >= 4) /* && !defined(__MACH__) */
+#  define SILENCE_PUBLIC        __attribute__ ( (visibility("default")) )
 #else
-#define SILENCE_PUBLIC
+#  define SILENCE_PUBLIC
 #endif
 
 #endif
