@@ -1,7 +1,5 @@
-/**
- * C S O U N D   V S T
- *
- * A VST plugin version of Csound, with Python scripting.
+/*
+ * C S O U N D
  *
  * L I C E N S E
  *
@@ -20,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#if defined(HAVE_UNISTD_H)
+#if defined(HAVE_UNISTD_H) || defined(MACOSX)
 #include <unistd.h>
 #endif
 
@@ -32,6 +30,7 @@
 #include "System.hpp"
 #include "CsoundFile.hpp"
 #include "Conversions.hpp"
+#include <csound.h>
 
 namespace csound
 {
@@ -46,7 +45,7 @@ namespace csound
 
   void Logger::write(const char *text)
   {
-    fprintf(stderr, text);
+    fprintf(stderr, "%s", text);
   }
 
   ThreadLock::ThreadLock() : lock(0)
@@ -244,7 +243,7 @@ namespace csound
       vfprintf(stderr, format, valist);
     }
   }
-  
+
   void System::message(CSOUND *csound, int attribute, const char *format, va_list valist)
   {
     if (logfile) {
@@ -355,7 +354,7 @@ namespace csound
   int System::shellOpen(const char *filename, const char *command)
   {
     int returnValue = 0;
-    int hInstance = (int) ShellExecute(0,
+    intptr_t hInstance = (intptr_t) ShellExecute(0,
                                        command,
                                        filename,
                                        0,
@@ -504,7 +503,7 @@ namespace csound
     if (bufsize <= 0) return 0;
     if (len >= bufsize) len = bufsize-1;
     memcpy(d, s, len);
-    d[len] = 0;
+    d[len] = '\0';
     return ret;
   }
 
@@ -660,6 +659,7 @@ namespace csound
       }
     else
       {
+        delete pthread;
         return 0;
       }
   }
@@ -675,6 +675,7 @@ namespace csound
       }
     else
       {
+        delete pthread_mutex;
         return 0;
       }
   }
