@@ -25,6 +25,9 @@
 #include "soundio.h"
 #include <math.h>
 
+#ifndef WIN32
+#include <unistd.h>
+#endif
 #define INCSDIF 1
 
 #if INCSDIF
@@ -75,34 +78,35 @@ typedef struct {
          *ph_av1, *ph_av2, *ph_av3,      /*tempor. buffers*/
          *amp_av1, *amp_av2, *amp_av3,   /* same for ampl.*/
          m_ampsum;              /* maximum amplitude at output*/
-  long   windsiz;               /* # of pts. in one per. of sample*/
-  short  hmax;                  /* max harmonics requested */
+  int32  windsiz;               /* # of pts. in one per. of sample*/
+  int16  hmax;                  /* max harmonics requested */
   int    num_pts,               /* breakpoints per harmonic */
          amp_min;               /* amplitude cutout threshold */
   int    skip,                  /* flag to stop analysis if zeros*/
          bufsiz;                /* circular buffer size */
-  long   smpsin;                /* num sampsin */
-  long   midbuf,                /* set to bufsiz / 2   */
+  int32  smpsin;                /* num sampsin */
+  int32  midbuf,                /* set to bufsiz / 2   */
          bufmask;               /* set to bufsiz - 1   */
   char   *infilnam,             /* input file name */
          *outfilnam;            /* output file name */
   MYFLT  *auxp;                 /* pointer to input file */
   MYFLT  *adp;                  /* pointer to front of sample file */
   double *c_p,*s_p;             /* pointers to space for sine and cos terms */
+  int    newformat;             /* flag for m/c independent format */
 } HET;
 
 #if INCSDIF
 static int writesdif(CSOUND*, HET*);
 #endif
-static  double  GETVAL(HET *, double *, long);
+static  double  GETVAL(HET *, double *, int32);
 static  double  sq(double);
-static  void    PUTVAL(HET *,double *, long, double);
+static  void    PUTVAL(HET *,double *, int32, double);
 static  int     hetdyn(CSOUND *csound, HET *, int);
 static  void    lpinit(HET*);
-static  void    lowpass(HET *,double *, double *, long);
-static  void    average(HET *,long, double *, double *, long);
-static  void    output(HET *,long, int, int);
-static  void    output_ph(HET *, long);
+static  void    lowpass(HET *,double *, double *, int32);
+static  void    average(HET *,int32, double *, double *, int32);
+static  void    output(HET *,int32, int, int);
+static  void    output_ph(HET *, int32);
 static  int     filedump(HET *, CSOUND *);
 static  int     quit(CSOUND *, char *);
 
@@ -110,8 +114,8 @@ static  int     quit(CSOUND *, char *);
 #define u(x)    (x>0.0 ? 1 : 0)
 
 #define FIND(MSG)   if (*s == '\0')  \
-                        if (!(--argc) || ((s = *++argv) && *s == '-'))  \
-                            return quit(csound, MSG);
+    if (UNLIKELY(!(--argc) || ((s = *++argv) && *s == '-')))    \
+      return quit(csound, MSG);
 
 static void init_het(HET *thishet)
 {
@@ -129,13 +133,14 @@ static void init_het(HET *thishet)
     thishet->amp_min   = 64;            /* amplitude cutout threshold */
     thishet->bufsiz    = 1;             /* circular buffer size */
     thishet->skip      = 0;             /* JPff: this was missing */
+    thishet->newformat = 1;
 }
 
 static int hetro(CSOUND *csound, int argc, char **argv)
 {
     SNDFILE *infd;
     int     i, hno, channel = 1, retval = 0;
-    long    nsamps, smpspc, bufspc, mgfrspc;
+    int32   nsamps, smpspc, bufspc, mgfrspc;
     char    *dsp, *dspace, *mspace;
     double  *begbufs, *endbufs;
     HET     het;
@@ -145,7 +150,7 @@ static int hetro(CSOUND *csound, int argc, char **argv)
  /* csound->dbfs_to_float = csound->e0dbfs = FL(1.0);   Needed ? */
     init_het(thishet);
 
-    if (!(--argc)) {
+    if (UNLIKELY(!(--argc))) {
       return quit(csound,Str("no arguments"));
     }
     do {
@@ -155,9 +160,9 @@ static int hetro(CSOUND *csound, int argc, char **argv)
         case 's':
           FIND(Str("no sampling rate"))
 #if defined(USE_DOUBLE)
-          sscanf(s,"%lf",&thishet->sr);
+          csound->sscanf(s,"%lf",&thishet->sr);
 #else
-          sscanf(s,"%f",&thishet->sr);
+          csound->sscanf(s,"%f",&thishet->sr);
 #endif
           break;
         case 'c':
@@ -167,34 +172,34 @@ static int hetro(CSOUND *csound, int argc, char **argv)
         case 'b':
           FIND(Str("no begin time"))
 #if defined(USE_DOUBLE)
-          sscanf(s,"%lf",&thishet->beg_time);
+          csound->sscanf(s,"%lf",&thishet->beg_time);
 #else
-          sscanf(s,"%f",&thishet->beg_time);
+          csound->sscanf(s,"%f",&thishet->beg_time);
 #endif
           break;
         case 'd':
           FIND(Str("no duration time"))
 #if defined(USE_DOUBLE)
-          sscanf(s,"%lf",&thishet->input_dur);
+          csound->sscanf(s,"%lf",&thishet->input_dur);
 #else
-          sscanf(s,"%f",&thishet->input_dur);
+          csound->sscanf(s,"%f",&thishet->input_dur);
 #endif
           break;
         case 'f':
           FIND(Str("no fundamental estimate"))
 #if defined(USE_DOUBLE)
-          sscanf(s,"%lf",&thishet->fund_est);
+          csound->sscanf(s,"%lf",&thishet->fund_est);
 #else
-          sscanf(s,"%f",&thishet->fund_est);
+          csound->sscanf(s,"%f",&thishet->fund_est);
 #endif
           break;
         case 'h':
           FIND(Str("no harmonic count"))
           sscanf(s,"%hd",&thishet->hmax);
-          if (thishet->hmax > HMAX)
+          if (UNLIKELY(thishet->hmax > HMAX))
             csound->Message(csound,Str("over %d harmonics but continuing"),
                             HMAX);
-          if (thishet->hmax < 1) {
+          if (UNLIKELY(thishet->hmax < 1)) {
             csound->Message(csound,Str("h of %d too low, reset to 1\n"),
                             thishet->hmax);
                 thishet->hmax = 1;
@@ -202,7 +207,7 @@ static int hetro(CSOUND *csound, int argc, char **argv)
           break;
         case 'M':
           FIND(Str("no amplitude maximum"))
-          sscanf(s,"%lf",&thishet->m_ampsum);
+          csound->sscanf(s,"%lf",&thishet->m_ampsum);
           break;
         case 'm':
           FIND(Str("no amplitude minimum"))
@@ -215,14 +220,20 @@ static int hetro(CSOUND *csound, int argc, char **argv)
         case 'l':
           FIND(Str("no filter cutoff"))
 #if defined(USE_DOUBLE)
-          sscanf(s,"%lf",&thishet->freq_c);
+          csound->sscanf(s,"%lf",&thishet->freq_c);
 #else
-          sscanf(s,"%f",&thishet->freq_c);
+          csound->sscanf(s,"%f",&thishet->freq_c);
 #endif
           break;
+        case 'X':
+          het.newformat = 1;
+          break;
+        case 'x':
+          het.newformat = 0;
+          break;
         case '-':
           FIND(Str("no log file"));
-          while (*s++); s--;
+          while (*s++) {}; s--;
           break;
         default:
           return quit(csound, Str("Invalid switch option"));
@@ -230,49 +241,50 @@ static int hetro(CSOUND *csound, int argc, char **argv)
       else break;
     } while (--argc);
 
-    if (argc != 2)
+    if (UNLIKELY(argc != 2))
       return quit(csound, Str("incorrect number of filenames"));
     thishet->infilnam = *argv++;
     thishet->outfilnam = *argv;
 
-    if (thishet->freq_c > 1)
+    if (UNLIKELY(thishet->freq_c > 1))
       csound->Message(csound, Str("Filter cutoff freq. = %f\n"),
                               thishet->freq_c);
 
-    if ((thishet->input_dur < 0) || (thishet->beg_time < 0))
+    if (UNLIKELY((thishet->input_dur < 0) || (thishet->beg_time < 0)))
       return quit(csound,Str("input and begin times cannot be less than zero"));
     /* open sndfil, do skiptime */
-    if ((infd = csound->SAsndgetset(csound, thishet->infilnam, &p,
+    if (UNLIKELY((infd = csound->SAsndgetset(csound, thishet->infilnam, &p,
                                     &thishet->beg_time, &thishet->input_dur,
-                                    &thishet->sr, channel)) == NULL) {
+                                             &thishet->sr, channel)) == NULL)) {
       char errmsg[256];
-      sprintf(errmsg, Str("Cannot open %s"), thishet->infilnam);
+      snprintf(errmsg, 256, Str("Cannot open %s"), thishet->infilnam);
       return quit(csound, errmsg);
     }
     nsamps = p->getframes;
     /* alloc for MYFLTs */
     thishet->auxp = (MYFLT*) csound->Malloc(csound, nsamps * sizeof(MYFLT));
     /* & read them in */
-    if ((thishet->smpsin = csound->getsndin(csound, infd,
-                                            thishet->auxp, nsamps, p)) <= 0) {
+    if (UNLIKELY((thishet->smpsin =
+                  csound->getsndin(csound, infd,
+                                   thishet->auxp, nsamps, p)) <= 0)) {
       char errmsg[256];
       csound->Message(csound, "smpsin = %ld\n", (long) thishet->smpsin);
-      sprintf(errmsg, Str("Read error on %s\n"), thishet->infilnam);
+      snprintf(errmsg, 256, Str("Read error on %s\n"), thishet->infilnam);
       return quit(csound, errmsg);
     }
     thishet->sr = (MYFLT) p->sr;                /* sr now from open  */
     /* samps in fund prd */
-    thishet->windsiz = (long)(thishet->sr / thishet->fund_est + FL(0.5));
+    thishet->windsiz = (int32)(thishet->sr / thishet->fund_est + FL(0.5));
 #if INCSDIF
     /* RWD no limit for SDIF files! */
     if (is_sdiffile(thishet->outfilnam)) {
-      if (thishet->num_pts >= nsamps - thishet->windsiz)
+      if (UNLIKELY(thishet->num_pts >= nsamps - thishet->windsiz))
         return quit(csound, Str("number of output points is too great"));
     }
     else
 #endif
-      if (thishet->num_pts > 32767 ||
-          thishet->num_pts >= nsamps - thishet->windsiz)
+      if (UNLIKELY(thishet->num_pts > 32767 ||
+                   thishet->num_pts >= nsamps - thishet->windsiz))
         return quit(csound, Str("number of output points is too great"));
     thishet->delta_t = FL(1.0)/thishet->sr;
     thishet->t = FL(1.0)/thishet->fund_est;
@@ -342,7 +354,7 @@ static int hetro(CSOUND *csound, int argc, char **argv)
 #if INCSDIF
     /* RWD if extension is .sdif, write as 1TRC frames */
     if (is_sdiffile(thishet->outfilnam)) {
-      if (!writesdif(csound,thishet)) {
+      if (UNLIKELY(!writesdif(csound,thishet))) {
         csound->Message(csound, Str("Unable to write to SDIF file\n"));
         retval = -1;
       }
@@ -354,23 +366,23 @@ static int hetro(CSOUND *csound, int argc, char **argv)
     return retval;
 }
 
-static double GETVAL(HET* thishet, double *inb, long smpl)
+static double GETVAL(HET* thishet, double *inb, int32 smpl)
 {                               /* get value at position smpl in array inb */
     if (smpl<0) return 0.0;
     return   inb[(smpl + thishet->midbuf) & thishet->bufmask];
 }
 
-static void PUTVAL(HET* thishet, double *outb, long smpl, double value)
+static void PUTVAL(HET* thishet, double *outb, int32 smpl, double value)
 {                               /* put value in array outb at postn smpl */
     outb[(smpl + thishet->midbuf) & thishet->bufmask] = value;
 }
 
 static int hetdyn(CSOUND *csound, HET* thishet, int hno) /* HETERODYNE FILTER */
 {
-    long    smplno;
+    int32   smplno;
     double  temp_a, temp_b, tpidelest;
     double  *cos_p, *sin_p, *cos_wp, *sin_wp;
-    long    n;
+    int32   n;
     int     outpnt, lastout = -1;
     MYFLT   *ptr;
 
@@ -463,7 +475,7 @@ static void lpinit(HET *thishet) /* lowpass coefficient ititializer */
     thishet->y3 = (-(MYFLT)exp(-2.0*omega_c*thishet->delta_t));
 }
 
-static void lowpass(HET *thishet, double *out, double *in, long smpl)
+static void lowpass(HET *thishet, double *out, double *in, int32 smpl)
   /* call with x1,x2,yA,y2,y3 initialised  */
   /* calls LPF function */
 {
@@ -475,7 +487,7 @@ static void lowpass(HET *thishet, double *out, double *in, long smpl)
             thishet->y3 * GETVAL(thishet,out,smpl-3)));
 }
 
-static void average(HET *thishet, long window,double *in,double *out, long smpl)
+static void average(HET *thishet, int32 window,double *in,double *out, int32 smpl)
   /* AVERAGES OVER 'WINDOW' SAMPLES */
   /* this is actually a comb filter with 'Z' */
   /* transform of (1/w *[1 - Z**-w]/[1 - Z**-1]) */
@@ -495,7 +507,7 @@ static void average(HET *thishet, long window,double *in,double *out, long smpl)
 }
 
                                  /* update phase counter */
-static void output_ph(HET *thishet,long smpl)
+static void output_ph(HET *thishet,int32 smpl)
                                 /* calculates magnitude and phase components */
                                 /* for each samples quadrature components, & */
                                 /* and unwraps the phase.  A phase difference*/
@@ -537,7 +549,7 @@ static void output_ph(HET *thishet,long smpl)
     }
 }
 
-static void output(HET *thishet, long smpl, int hno, int pnt)
+static void output(HET *thishet, int32 smpl, int hno, int pnt)
                         /* output one freq_mag pair */
                         /* when called, gets frequency change */
                         /* and adds it to current freq. stores*/
@@ -559,7 +571,7 @@ static void output(HET *thishet, long smpl, int hno, int pnt)
 }
 
 /* If this function worthwhile?  Need to coinsider recalculation */
-static double sq(double num)     /* RETURNS SQUARE OF ARGUMENT */
+inline static double sq(double num)     /* RETURNS SQUARE OF ARGUMENT */
 {
     return (num * num);
 }
@@ -576,35 +588,44 @@ static int quit(CSOUND *csound, char *msg)
 
 static int filedump(HET *thishet, CSOUND *csound)
 {
-    int     h, pnt, ofd, nbytes;
-    double  scale,x,y;
-    short   **mags, **freqs, *magout, *frqout;
+    int     h, pnt, ofd, nbytes;    double  scale,x,y;
+    int16   **mags, **freqs, *magout, *frqout;
     double  ampsum, maxampsum = 0.0;
-    long    lenfil = 0;
-    short   *TIME;
+    int32   lenfil = 0;
+    int16   *TIME;
     MYFLT   timesiz;
+    FILE    *ff;
 
-    mags = (short **) csound->Malloc(csound, thishet->hmax * sizeof(short*));
-    freqs = (short **) csound->Malloc(csound, thishet->hmax * sizeof(short*));
+    mags = (int16 **) csound->Malloc(csound, thishet->hmax * sizeof(int16*));
+    freqs = (int16 **) csound->Malloc(csound, thishet->hmax * sizeof(int16*));
     for (h = 0; h < thishet->hmax; h++) {
-      mags[h] = (short *)csound->Malloc(csound,
-                                        thishet->num_pts * sizeof(short));
-      freqs[h] = (short *)csound->Malloc(csound,
-                                         thishet->num_pts * sizeof(short));
+      mags[h] = (int16 *)csound->Malloc(csound,
+                                        thishet->num_pts * sizeof(int16));
+      freqs[h] = (int16 *)csound->Malloc(csound,
+                                         thishet->num_pts * sizeof(int16));
     }
 
-    TIME = (short *)csound->Malloc(csound, thishet->num_pts * sizeof(short));
+    TIME = (int16 *)csound->Malloc(csound, thishet->num_pts * sizeof(int16));
     timesiz = FL(1000.0) * thishet->input_dur /thishet-> num_pts;
     for (pnt = 0; pnt < thishet->num_pts; pnt++)
-      TIME[pnt] = (short)(pnt * timesiz);
+      TIME[pnt] = (int16)(pnt * timesiz);
 
     /* fullpath else cur dir */
-    if (csound->FileOpen2(csound, &ofd, CSFILE_FD_W, thishet->outfilnam,
-                                 NULL, "", CSFTYPE_HETRO, 0) == NULL)
+    if (thishet->newformat) {
+      if (UNLIKELY(csound->FileOpen2(csound, &ff, CSFILE_STD, thishet->outfilnam,
+                                     "w", "", CSFTYPE_HETROT, 0) == NULL))
       return quit(csound, Str("cannot create output file\n"));
+    } else
+      if (UNLIKELY(csound->FileOpen2(csound, &ofd, CSFILE_FD_W, thishet->outfilnam,
+                                     NULL, "", CSFTYPE_HETRO, 0) == NULL))
+        return quit(csound, Str("cannot create output file\n"));
 
-    write(ofd, (char*)&thishet->hmax, sizeof(thishet->hmax)); /* Write header */
-
+    if (thishet->newformat)
+      fprintf(ff,"HETRO %d\n", thishet->hmax);        /* Header */
+    else {
+      if (UNLIKELY(write(ofd, (char*)&thishet->hmax, sizeof(thishet->hmax))<0))
+        csound->Message(csound,Str("Write failure\n")); /* Write header */
+    }
     for (pnt=0; pnt < thishet->num_pts; pnt++) {
       ampsum = 0.0;
       for (h = 0; h < thishet->hmax; h++)
@@ -618,26 +639,26 @@ static int filedump(HET *thishet, CSOUND *csound)
     for (h = 0; h < thishet->hmax; h++) {
       for (pnt = 0; pnt < thishet->num_pts; pnt++) {
         x = thishet->MAGS[h][pnt] * scale;
-        mags[h][pnt] = (short)(x*u(x));
+        mags[h][pnt] = (int16)(x*u(x));
         y = thishet->FREQS[h][pnt];
-        freqs[h][pnt] = (short)(y*u(y));
+        freqs[h][pnt] = (int16)(y*u(y));
       }
     }
 
-    magout = (short *)csound->Malloc(csound,
-                                     (thishet->num_pts+1) * 2 * sizeof(short));
-    frqout = (short *)csound->Malloc(csound,
-                                     (thishet->num_pts+1) * 2 * sizeof(short));
+    magout = (int16 *)csound->Malloc(csound,
+                                     (thishet->num_pts+1) * 2 * sizeof(int16));
+    frqout = (int16 *)csound->Malloc(csound,
+                                     (thishet->num_pts+1) * 2 * sizeof(int16));
     for (h = 0; h < thishet->hmax; h++) {
-      short *mp = magout, *fp = frqout;
-      short *lastmag, *lastfrq, pkamp = 0;
+      int16 *mp = magout, *fp = frqout;
+      int16 *lastmag, *lastfrq, pkamp = 0;
       int mpoints, fpoints, contig = 0;
       *mp++ = -1;                      /* set brkpoint type codes  */
       *fp++ = -2;
       lastmag = mp;
       lastfrq = fp;
       for (pnt = 0; pnt < thishet->num_pts; pnt++) {
-        short tim, mag, frq;
+        int16 tim, mag, frq;
         tim = TIME[pnt];
         frq = freqs[h][pnt];
         if ((mag = mags[h][pnt]) > pkamp)
@@ -684,8 +705,16 @@ static int filedump(HET *thishet, CSOUND *csound)
       *mp++ = END;                 /* add the sequence delimiters   */
       *fp++ = END;
       mpoints = ((mp - magout) / 2) - 1;
-      nbytes = (mp - magout) * sizeof(short);
-      write(ofd, (char *)magout, nbytes);
+      nbytes = (mp - magout) * sizeof(int16);
+      if (thishet->newformat) {
+        int i;
+        for (i=0; i<(mp - magout); i++)
+          fprintf(ff,"%hd%c", magout[i], i==(mp-magout-1)?'\n':',');
+      }
+      else {
+        if (UNLIKELY(write(ofd, (char *)magout, nbytes)<0))
+          csound->Message(csound, Str("Write failure\n"));
+      }
 #ifdef DEBUG
       {
         int i;
@@ -696,8 +725,17 @@ static int filedump(HET *thishet, CSOUND *csound)
 #endif
       lenfil += nbytes;
       fpoints = ((fp - frqout) / 2) - 1;
-      nbytes = (fp - frqout) * sizeof(short);
-      write(ofd, (char *)frqout, nbytes);
+      nbytes = (fp - frqout) * sizeof(int16);
+      if (thishet->newformat) {
+        int i;
+        for (i=0; i<fp - frqout; i++)
+          fprintf(ff,"%hd%c", frqout[i], i==(fp-frqout-1)?'\n':',');
+        fprintf(ff,"\n");
+      }
+      else {
+        if (UNLIKELY(write(ofd, (char *)frqout, nbytes)<0))
+          csound->Message(csound, Str("Write failure\n"));
+      }
 #ifdef DEBUG
       {
         int i;
@@ -713,7 +751,7 @@ static int filedump(HET *thishet, CSOUND *csound)
                       h, mpoints, fpoints, pkamp);
     }
     csound->Message(csound,Str("wrote %ld bytes to %s\n"),
-                    lenfil, thishet->outfilnam);
+                    (long)lenfil, thishet->outfilnam);
     csound->Free(csound, magout);
     csound->Free(csound, frqout);
     csound->Free(csound, TIME);
@@ -742,7 +780,7 @@ static int writesdif(CSOUND *csound, HET *thishet)
     SDIF_MatrixHeader mh;
     FILE        *sdiffile = NULL;
 
-    if (SDIF_Init() != ESDIF_SUCCESS) {
+    if (UNLIKELY(SDIF_Init() != ESDIF_SUCCESS)) {
       csound->Message(csound,
                       Str("OOPS: SDIF does not work on this machine!\n"));
       return 0;
@@ -759,7 +797,7 @@ static int writesdif(CSOUND *csound, HET *thishet)
     scale = thishet->m_ampsum / maxampsum;
     /* SDIF does not specify a range, 'cos it's too clever for that sort
      * of thing, but this seems consistent with existing examples! */
-    scale *= (double) csound->dbfs_to_float;
+    scale *= (double) (1.0/csound->Get0dBFS(csound));
 
     for (h = 0; h < thishet->hmax; h++) {
       for (pnt = 0; pnt < thishet->num_pts; pnt++) {
@@ -768,7 +806,8 @@ static int writesdif(CSOUND *csound, HET *thishet)
       }
     }
 
-    if ((r = SDIF_OpenWrite(thishet->outfilnam, &sdiffile))!=ESDIF_SUCCESS) {
+    if (UNLIKELY((r =
+                  SDIF_OpenWrite(thishet->outfilnam, &sdiffile))!=ESDIF_SUCCESS)) {
       /* can get SDIF error messages, but trickly for CSTRINGS */
       csound->Message(csound,Str("Error creating %s\n"),thishet->outfilnam);
       fclose(sdiffile);
@@ -790,14 +829,14 @@ static int writesdif(CSOUND *csound, HET *thishet)
     /* no padding bytes */
     /*timesiz = 1000.0f * thishet->input_dur / thishet->num_pts;*/
     timesiz = thishet->input_dur / thishet->num_pts;
-    /* don't even need a TIME array */
+    /* do not even need a TIME array */
 
     /* main loop to write 1TRC frames */
     for (i=0; i < thishet->num_pts; i++) {
       sdif_float32 amp,freq,phase = 0.0f;
       /* cannot offer anything interesting with phase! */
       head.time = (sdif_float32) ((MYFLT)i * timesiz);
-      if ((r = SDIF_WriteFrameHeader(&head,sdiffile))!=ESDIF_SUCCESS) {
+      if (UNLIKELY((r = SDIF_WriteFrameHeader(&head,sdiffile))!=ESDIF_SUCCESS)) {
         csound->Message(csound,Str("Error writing SDIF frame header.\n"));
         return 0;
       }
@@ -806,7 +845,7 @@ static int writesdif(CSOUND *csound, HET *thishet)
       mh.columnCount = 4;
       SDIF_Copy4Bytes(mh.matrixType,"1TRC");
       mh.matrixDataType = SDIF_FLOAT32;
-      if ((r = SDIF_WriteMatrixHeader(&mh,sdiffile))!=ESDIF_SUCCESS) {
+      if (UNLIKELY((r = SDIF_WriteMatrixHeader(&mh,sdiffile))!=ESDIF_SUCCESS)) {
         csound->Message(csound,Str("Error writing SDIF matrix header.\n"));
         return 0;
       }
@@ -816,10 +855,10 @@ static int writesdif(CSOUND *csound, HET *thishet)
         index = (sdif_float32)(j+1);
         amp = (sdif_float32) thishet->MAGS[j][i];
         freq = (sdif_float32) thishet->FREQS[j][i];
-        if (((r = SDIF_Write4(&index,1,sdiffile))!= ESDIF_SUCCESS) ||
-            ((r = SDIF_Write4(&freq,1,sdiffile))!= ESDIF_SUCCESS)  ||
-            ((r = SDIF_Write4(&amp,1,sdiffile))!= ESDIF_SUCCESS)   ||
-            ((r = SDIF_Write4(&phase,1,sdiffile))!= ESDIF_SUCCESS)) {
+        if (UNLIKELY(((r = SDIF_Write4(&index,1,sdiffile))!= ESDIF_SUCCESS) ||
+                     ((r = SDIF_Write4(&freq,1,sdiffile))!= ESDIF_SUCCESS)  ||
+                     ((r = SDIF_Write4(&amp,1,sdiffile))!= ESDIF_SUCCESS)   ||
+                     ((r = SDIF_Write4(&phase,1,sdiffile))!= ESDIF_SUCCESS))) {
           csound->Message(csound,Str("Error writing SDIF data.\n"));
           return 0;
         }
@@ -827,7 +866,7 @@ static int writesdif(CSOUND *csound, HET *thishet)
       /* 64-bit alignment can be relied upon here, so no need to calc padding */
     }
     csound->Message(csound,
-                    Str("wrote %ld 1TRC frames to %s\n"),
+                    Str("wrote %d 1TRC frames to %s\n"),
                     thishet->num_pts, thishet->outfilnam);
     SDIF_CloseWrite(sdiffile);
     return 1;
@@ -855,8 +894,7 @@ int hetro_init_(CSOUND *csound)
     int retval = csound->AddUtility(csound, "hetro", hetro);
     if (!retval) {
       retval = csound->SetUtilityDescription(csound, "hetro",
-                                             "Soundfile analysis for adsyn");
+                                             Str("Soundfile analysis for adsyn"));
     }
     return retval;
 }
-
