@@ -5,23 +5,29 @@
 
     This file is part of Csound.
 
-    Csound is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    The Csound Library is free software; you can redistribute it
+    and/or modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) any later version.
 
     Csound is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    GNU Lesser General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU Lesser General Public
+    License along with Csound; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+    02111-1307 USA
 */
 
 #include "csound.h"                                    /*   SMAIN.C  */
 
+#if defined(LINUX) || defined(SGI) || defined(sol) || \
+    defined(__MACH__) || defined(__EMX__)
+#include <signal.h>
+#endif
+
 static void msg_callback(CSOUND *csound,
                          int attr, const char *fmt, va_list args)
 {
@@ -36,8 +42,11 @@ int main(void)                          /* stdio stub for standalone scsort */
     int    err;
 
     csound = csoundCreate(NULL);
+#if defined(LINUX) || defined(SGI) || defined(sol) || \
+    defined(__MACH__) || defined(__EMX__)
+    signal(SIGPIPE, SIG_DFL);
+#endif
     csoundSetMessageCallback(csound, msg_callback);
-    csoundPreCompile(csound);
     err = csoundScoreSort(csound, stdin, stdout);
     csoundDestroy(csound);
 
